package br.ufsc.fcama.ig.tableModel;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.PropertyResourceBundle;
import java.util.ResourceBundle;

import javax.swing.table.AbstractTableModel;

import br.ufsc.fcama.logica.objAux.Requisito;

public class TableModelReqImplementacao extends AbstractTableModel {

	private int tipo;
	private ArrayList reqs;
	private int nuColunas;
	private SimpleDateFormat format = new SimpleDateFormat("dd/MM/yyyy" );
	private int ciclo;
	private ResourceBundle rb = PropertyResourceBundle.getBundle("br.ufsc.fcama.internacionalizacao.ProgramProperties");
	
	public TableModelReqImplementacao(int ciclo, int tipo, ArrayList requisitos, ArrayList userStories ){
		this.tipo = tipo;
		this.ciclo = ciclo;
		reqs = new ArrayList();
		if (this.tipo == TableModelReqImplementacao.NAO_INICIADO){
			this.naoIniciado(requisitos, userStories);
         }else if(this.tipo == TableModelReqImplementacao.INICIADO){
        	 this.iniciado(requisitos, userStories);
         }else{
        	 this.concluido(requisitos, userStories);
        }
	}
	
	private void naoIniciado(ArrayList requisitos, ArrayList userStories){
		this.nuColunas = 4;
		Requisito req;
		
		Iterator itReq = requisitos.iterator();
		while (itReq.hasNext()){
			req =  (Requisito) itReq.next();
			if (req.getDtInicio() == null && this.ciclo == req.getNuCincloDeDesenvolvimento()){
				this.reqs.add(req);
			}
		}
		
		Iterator itUS = userStories.iterator();
		while(itUS.hasNext()){
			req =  (Requisito) itUS.next();
			if (req.getDtInicio() == null && this.ciclo == req.getNuCincloDeDesenvolvimento()){
				this.reqs.add(req);
			}
		}
		
	}
	private void iniciado( ArrayList requisitos, ArrayList userStories){
		this.nuColunas = 5;
		Requisito req;
		
		Iterator itReq = requisitos.iterator();
		while (itReq.hasNext()){
			req = (Requisito) itReq.next();
			if (req.getDtInicio() != null && req.getDtFim() == null && this.ciclo == req.getNuCincloDeDesenvolvimento()){
				this.reqs.add(req);
			}
		}
		
		Iterator itUS = userStories.iterator();
		while(itUS.hasNext()){
			req = (Requisito) itUS.next();
			if (req.getDtInicio() != null && req.getDtFim() == null && this.ciclo == req.getNuCincloDeDesenvolvimento()){
				this.reqs.add(req);
			}
		}
	}
	private void concluido( ArrayList requisitos, ArrayList userStories){
		this.nuColunas = 5;
		Requisito req;
		
		Iterator itReq = requisitos.iterator();
		while (itReq.hasNext()){
			req = (Requisito) itReq.next();
			if (req.getDtFim() != null && this.ciclo == req.getNuCincloDeDesenvolvimento()){
				this.reqs.add(req);
			}
		}
		
		Iterator itUS = userStories.iterator();
		while(itUS.hasNext()){
			req = (Requisito) itUS.next();
			if (req.getDtFim() != null && this.ciclo == req.getNuCincloDeDesenvolvimento()){
				this.reqs.add(req);
			}
		}
	}

	public Requisito getRequisito(int row){
		return (Requisito)this.reqs.get(row);
	}
	
	public void addRequisito(Requisito req){
		this.reqs.add(req);
	}
	
	public int getRowCount() {
		return this.reqs.size();
	}

	public int getColumnCount() {
		return this.nuColunas;
	}
	public Requisito removerRequisito(int row){
		return (Requisito) this.reqs.remove(row);
	}

	public Object getValueAt(int row, int column) {
		Requisito req = (Requisito)this.reqs.get(row);
		
		if (this.tipo == TableModelReqImplementacao.NAO_INICIADO){
        	switch(column){
            case 0 : return req.getNome();
            case 1 : return new Integer(req.getOrdem());
            case 2 : return new Float(req.getTempoEstimado());
            case 3 : return req.getDtInicioPrevisto() == null ? this.rb.getString("tableModelReqImplementacao.naoInformado") : this.format.format(req.getDtInicioPrevisto());
          }
        }else if(this.tipo == TableModelReqImplementacao.INICIADO){
        	switch(column){
            case 0 : return req.getNome();
            case 1 : return new Integer(req.getOrdem());
            case 2 : return new Float(req.getTempoEstimado());
            case 3 : return this.format.format(req.getDtInicio());
            case 4 : return req.getDtFimPrevisto() == null ? this.rb.getString("tableModelReqImplementacao.naoInformado") : this.format.format(req.getDtFimPrevisto());
          }
        }else if(this.tipo == TableModelReqImplementacao.CONCLUIDO){
        	switch(column){
            case 0 : return req.getNome();
            case 1 : return new Integer(req.getOrdem());
            case 2 : return new Float(req.getTempoEstimado());
            case 3 : return this.format.format(req.getDtInicio());
            case 4 : return this.format.format(req.getDtFim());
          }
        }
		return null;
	}
	
	public String getColumnName(int c){
        if (this.tipo == TableModelReqImplementacao.NAO_INICIADO){
        	switch(c){
            case 0 : return this.rb.getString("tableModelReqImplementacao.nome");
            case 1 : return this.rb.getString("tableModelReqImplementacao.ordem");
            case 2 : return this.rb.getString("tableModelReqImplementacao.tempo");
            case 3 : return this.rb.getString("tableModelReqImplementacao.incioPrevisto");
          }
        }else if(this.tipo == TableModelReqImplementacao.INICIADO){
        	switch(c){
            case 0 : return this.rb.getString("tableModelReqImplementacao.nome");
            case 1 : return this.rb.getString("tableModelReqImplementacao.ordem");
            case 2 : return this.rb.getString("tableModelReqImplementacao.tempo");
            case 3 : return this.rb.getString("tableModelReqImplementacao.inicioEfetivo");
            case 4 : return this.rb.getString("tableModelReqImplementacao.fimPrevisto");
          }
        }else if(this.tipo == TableModelReqImplementacao.CONCLUIDO){
        	switch(c){
            case 0 : return this.rb.getString("tableModelReqImplementacao.nome");
            case 1 : return this.rb.getString("tableModelReqImplementacao.ordem");
            case 2 : return this.rb.getString("tableModelReqImplementacao.tempo");
            case 3 : return this.rb.getString("tableModelReqImplementacao.inicioEfetivo");
            case 4 : return this.rb.getString("tableModelReqImplementacao.fimEfetivo");
          }
        }
		
		
        return "";
    }
	
	public final static int NAO_INICIADO = 1;
	public final static int INICIADO = 2;
	public final static int CONCLUIDO = 3;

}
