package br.ufsc.fcama.logica;

import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.jdom.JDOMException;

import br.ufsc.fcama.exception.ExceptionArquivoJaExiste;
import br.ufsc.fcama.exception.ExceptionExclusaoPraticaNaoPermitida;
import br.ufsc.fcama.exception.ExceptionInclusaoPraticaNaoPermitida;
import br.ufsc.fcama.exception.ExceptionPraticaNaoLiberada;
import br.ufsc.fcama.exception.ExceptionStakeholderAlocado;
import br.ufsc.fcama.logica.objAux.Anexo;
import br.ufsc.fcama.logica.objAux.DuplaDesenvolvimento;
import br.ufsc.fcama.logica.objAux.Requisito;
import br.ufsc.fcama.logica.objAux.RequisitoAnexo;
import br.ufsc.fcama.logica.objAux.Stakeholder;
import br.ufsc.fcama.logica.objAux.UserStory;
import br.ufsc.fcama.logica.pratica.Pratica;
import br.ufsc.fcama.persistencia.XMLPersistencia;

/**
 * <p>Title: FCAMA</p>
 *
 * <p>Description: </p>
 *
 * <p>Copyright: Copyright (c) 2005</p>
 *
 * <p>Company: </p>
 *
 * @author Thiago Leo Machado
 * @version 1.0
 */
public class Controlador {

    private Projeto projeto;
    private XMLPersistencia xMLPersistencia;
    //os novos anexos incluidos enquanto o programa no foi salvo
    //quando o programa  salvo os anexos so  retirados do anexos
    //se as alteraes forem canceladas o anexos da lista so excluidos fisicamente e o anexos  limpo.
    private ArrayList anexosIncluidos;
    //os anexos excluidos enquanto o projeto no foi salvo
    //caso seja cancelada as alteraes no vai ser excluido fisicamente
    //quando for salvo os anexos so excluidos fisicamente.s
    private ArrayList anexosExcluidos;
    //as iteraoes incluidas enquanto o programa no foi salvo
    private ArrayList iteracoesIncluidas;
    

    public Controlador() {
        this.anexosIncluidos = new ArrayList();
        this.anexosExcluidos = new ArrayList();
        this.iteracoesIncluidas = new ArrayList();
    }

    public void criarProjeto(Projeto projeto) throws IOException{
        this.xMLPersistencia = new XMLPersistencia(projeto.getDiretorioPorjeto(), projeto.getNomeProjeto());
        this.xMLPersistencia.criarProjeto(projeto);
        this.projeto = projeto;
    }
    
    public void salvarProjeto() throws IOException{
        this.xMLPersistencia.salvarProjeto(this.projeto);
        Iterator it = anexosExcluidos.iterator();
        while (it.hasNext()){
            this.xMLPersistencia.excluir((Anexo)it.next());
        }
        this.anexosIncluidos = new ArrayList();
        this.anexosExcluidos = new ArrayList();
        this.iteracoesIncluidas = new ArrayList();
    }
    /**
     * Exclui os anexos que foram adicionados mas no vo ser salvos
     * @throws IOException
     */
    public void cancelarAlteracoesProjeto(){
        Iterator it = anexosIncluidos.iterator();
        while (it.hasNext()){
            try {
				this.xMLPersistencia.excluir((Anexo)it.next());
			} catch (SecurityException e) {
				e.printStackTrace();
			} catch (IOException e) {
				e.printStackTrace();
			}
        }
        Iterator itI = this.iteracoesIncluidas.iterator();
        while (itI.hasNext()){
        	try {
				this.xMLPersistencia.deleteIteracao((Iteracao)itI.next());
			} catch (IOException e) {
				e.printStackTrace();
			}
        }
        this.anexosIncluidos = new ArrayList();
        this.anexosExcluidos = new ArrayList();
        this.iteracoesIncluidas = new ArrayList();
    }
    
    /**
     * Remove o anexo da atividade e colocar na lista anexosExcluidos 
     * para excluir quando for salvar o projeto 
     * @param anexo
     * @param atividade
     * @return
     */
    public void excluirAnexo(Anexo anexo, Pratica atividade){
        atividade.removeAnexo(anexo);
	    this.anexosExcluidos.add(anexo);	    
	}
    
    public void excluirAnexo(Anexo anexo, RequisitoAnexo requisitoAnexo){
    	requisitoAnexo.removeAnexo(anexo);
    	this.anexosExcluidos.add(anexo);	    
	}
    
    /**
     * Copia o arquivo para o diretorio da atividade
     * seta o caminho do arquivo
     * @param fileOrigem
     * @param obj
     * @param anexo
     * @throws IOException
     */
    public void copiarArquivo(File fileOrigem, Object[] obj, Anexo anexo) throws IOException{
    	anexo.setCaminho(this.xMLPersistencia.copiarAnexo(fileOrigem,obj));
    	this.anexosIncluidos.add(anexo);
    }
    
    public void copiarArquivo(File fileOrigem, Object[] obj, Anexo anexo, RequisitoAnexo requisitoAnexo) throws IOException{
    	anexo.setCaminho(this.xMLPersistencia.copiarAnexo(fileOrigem,obj));
    	requisitoAnexo.addAnexo(anexo);
    	this.anexosIncluidos.add(anexo);
    }
    /**
     * Cria o arquivo, seta o caminho e abri o arquivo para edio
     * @param obj
     * @param anexo
     * @throws ExceptionArquivoJaExiste 
     * @throws IOException 
     */
    public void criarArquivo(File fileModelo,Object[] obj, Anexo anexo) throws IOException, ExceptionArquivoJaExiste{
    	anexo.setCaminho(this.xMLPersistencia.criarAnexo(fileModelo,obj,anexo));
    	this.anexosIncluidos.add(anexo);
    }
    
    public void visualizarAnexo(Anexo anexo) throws IOException{
    	this.xMLPersistencia.visualizarAnexo(anexo);
    }
    
    public void visualizarAnexoNaoSalvo(Anexo anexo) throws IOException{
    	this.xMLPersistencia.visualizarAnexoNaoSalvo(anexo);
    }
    
    public void novaIteracao() throws IOException{
    	this.projeto.addIteracao();
    	Iteracao iteracao = (Iteracao)this.projeto.getIteracoes().get(this.projeto.getIteracoes().size() - 1);
    	this.xMLPersistencia.addIteracao(iteracao);
    	this.iteracoesIncluidas.add(iteracao);
    }
    
    public void fecharProjeto(){
    	this.projeto = null;
    	this.xMLPersistencia = null;
    }
    
    public Projeto abrirProjeto(File fileProjeto) throws IOException, JDOMException, ExceptionPraticaNaoLiberada, ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida{
    	this.xMLPersistencia = new XMLPersistencia(fileProjeto);
    	this.projeto = this.xMLPersistencia.getProjeto();
    	return this.projeto;
    }
    
    public Projeto getProjeto(){
    	return this.projeto;
    }
    
        
    public void excluirRequisitoAnexo(RequisitoAnexo requisitoAnexo){
    	this.projeto.getAtividadeDefinicaoDosRequisitos().getPraticaDocumentacaoDetalhada().removeRequisitoAnexo(requisitoAnexo);
    	List anexos = requisitoAnexo.getAnexos();
    	Iterator it = anexos.iterator();
    	while(it.hasNext()){
    		this.excluirAnexoDoRequisitoAnexo(requisitoAnexo, (Anexo)it.next());
    	}
    }
    
    private void excluirAnexoDoRequisitoAnexo(RequisitoAnexo requisitoAnexo, Anexo anexo){
    	requisitoAnexo.removeAnexo(anexo);
    	this.anexosExcluidos.add(anexo);
    }
    
    
    
    
    /**
     * Exclui o stakeholder caso no esteja alocado em alguma dupla ou para algum requisito
     * @param stakeholder
     * @throws ExceptionStakeholderAlocado
     */
    public void excluirStakeholder(Stakeholder stakeholder) throws ExceptionStakeholderAlocado{
        String id = stakeholder.getNome() + " " + stakeholder.getFuncao();
        //################# confere nas user stories
        List userStories = this.getProjeto().getAtividadeDefinicaoDosRequisitos().getPraticaUserStories().getUserStories();
        Iterator itUS = userStories.iterator();
        UserStory us = null;
        //percorre as userStories
        while (itUS.hasNext()){
            us = (UserStory)itUS.next();
            List responsaveis = us.getResponsaveis();
            Iterator itResp = responsaveis.iterator();
            Stakeholder sh = null;
            //percoree os responsveis pela user story
            while(itResp.hasNext()){
                sh = (Stakeholder) itResp.next();
                //caso tenha o stakeholder lana exceo
                if (id.equals(sh.getNome() + " " + sh.getFuncao())){
                    throw new ExceptionStakeholderAlocado("Stakeholder alocado na user story " + us.getNome()+".");
                }
            }
        }
        
        //################confere nos requisitos
        List requisitos = this.getProjeto().getAtividadeDefinicaoDosRequisitos().getPraticaListaDeRequisitos().getRequisitos();
        Iterator itReq = requisitos.iterator();
        Requisito req = null;
        while (itReq.hasNext()){
            req = (Requisito) itReq.next();
            List responsaveis = req.getResponsaveis();
            Iterator itResp = responsaveis.iterator();
            Stakeholder sh = null;
            //percoree os responsveis pela user story
            while(itResp.hasNext()){
                sh = (Stakeholder) itResp.next();
                //caso tenha o stakeholder lana exceo
                if (id.equals(sh.getNome() + " " + sh.getFuncao())){
                    throw new ExceptionStakeholderAlocado("Stakeholder alocado no requisito " + req.getNome()+".");
                }
            }
        }
        
        //##############confere nas duplas do lado-a-lado
        List ciclosDeDesenvolvimento = this.projeto.getIteracoes();
        Iterator itCll = ciclosDeDesenvolvimento.iterator();
        Iteracao cicloll = null;
        while (itCll.hasNext()){
            cicloll = (Iteracao) itCll.next();
            List duplas = cicloll.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDesenvolvimentoLadoALado().getDuplas();
            Iterator itDup = duplas.iterator();
            DuplaDesenvolvimento dupla = null;
            while(itDup.hasNext()){
                dupla = (DuplaDesenvolvimento) itDup.next();
                if (id.equals(dupla.getStakeholder1().getNome() +" " + dupla.getStakeholder1().getFuncao())
                        ||id.equals(dupla.getStakeholder2().getNome() +" " + dupla.getStakeholder2().getFuncao()) ){
                    throw new ExceptionStakeholderAlocado("O skakeholder compe uma dupla da atividade desenvolvimento lado-a-lado do ciclo " + cicloll.getNumero() +".");                    
                }
            }
        }
        
        //################confere nas duplas do em duplas
        List ciclosDeDesenvolvimento2 = this.projeto.getIteracoes();
        Iterator itC = ciclosDeDesenvolvimento2.iterator();
        Iteracao ciclo = null;
        while (itC.hasNext()){
            ciclo = (Iteracao) itC.next();
            List duplas = ciclo.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDesenvolvimentoEmDuplas().getDuplas();
            Iterator itDup = duplas.iterator();
            DuplaDesenvolvimento dupla = null;
            while(itDup.hasNext()){
                dupla = (DuplaDesenvolvimento) itDup.next();
                if (id.equals(dupla.getStakeholder1().getNome() +" " + dupla.getStakeholder1().getFuncao())
                        ||id.equals(dupla.getStakeholder2().getNome() +" " + dupla.getStakeholder2().getFuncao()) ){
                    throw new ExceptionStakeholderAlocado("O skakeholder compe uma dupla da atividade desenvolvimento em duplas do ciclo " + ciclo.getNumero() +".");                    
                }
            }
        }
        //###############caso ok exclui do projeto
        this.projeto.removeStakeholder(stakeholder);
    }
    

    
}
