/*
 * Created on 23/08/2005
 *
 */
package br.ufsc.fcama.logica;

import java.util.ArrayList;
import java.util.Date;
import java.util.Iterator;

import br.ufsc.fcama.exception.ExceptionPraticaNaoLiberada;
import br.ufsc.fcama.exception.ExceptionExclusaoPraticaNaoPermitida;
import br.ufsc.fcama.exception.ExceptionInclusaoPraticaNaoPermitida;
import br.ufsc.fcama.logica.atividade.AtividadeDesenvolverIncrementoDoSistema;
import br.ufsc.fcama.logica.atividade.AtividadeIntegracaoIncremento;
import br.ufsc.fcama.logica.atividade.AtividadeValidarIncremento;
import br.ufsc.fcama.logica.atividade.AtividadeValidarSistema;
import br.ufsc.fcama.logica.objAux.Constantes;
import br.ufsc.fcama.logica.objAux.Requisito;
import br.ufsc.fcama.persistencia.ObjectFCAMA;

/**
 * @author Thiago Leo Machado
 *
 */
public class Iteracao extends ObjectFCAMA {

	private int numero;
	private Date dtInicioPrevista;
	private Date dtFimPrevista;
	private Date dtInicioEfetiva;
	private Date dtFimEfetiva;
	//os requisitos do ciclo de desenvolvimento
	private ArrayList requisitos;

    private AtividadeDesenvolverIncrementoDoSistema atividadeDesenvolverIncrementoDoSistema;
    private AtividadeValidarIncremento atividadeValidarIncremento;
    private AtividadeIntegracaoIncremento atividadeIntegracaoIncremento;
    private AtividadeValidarSistema atividadeValidarSistema;

    public Iteracao(){
    	this.atividadeDesenvolverIncrementoDoSistema = new AtividadeDesenvolverIncrementoDoSistema();
    	this.atividadeValidarIncremento = new AtividadeValidarIncremento();
    	this.atividadeIntegracaoIncremento = new AtividadeIntegracaoIncremento();
    	this.atividadeValidarSistema = new AtividadeValidarSistema();
    	this.requisitos = new ArrayList();
    }
    
    public boolean isRequisitosIteracaoCompletos(){
    	if(atividadeDesenvolverIncrementoDoSistema.isRequisitosCompletos()
    		&& atividadeValidarIncremento.isRequisitosCompletos()
    		&& atividadeIntegracaoIncremento.isRequisitosCompletos()
    		&& atividadeValidarSistema.isRequisitosCompletos()){
    		return true;
    	}else{
    		return false;
    	}
    }

    /**
     *Faz o controle da incluso e excluso nas etapas do ciclo de desemvolvimento
     * @param classAtividade
     * @param operacao
     * @throws ExceptionPraticaNaoLiberada
     * @throws ExceptionInclusaoPraticaNaoPermitida
     * @throws ExceptionExclusaoPraticaNaoPermitida
     */
    public void incluindoExcluindoPratica(Class classAtividade, String operacao)throws ExceptionPraticaNaoLiberada,  ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida {
		this.atividadeDesenvolverIncrementoDoSistema.incluindoExcluindoPratica(classAtividade, operacao);
		try{
			this.atividadeValidarIncremento.incluindoExcluindoPratica(classAtividade, operacao);
		}catch(ExceptionInclusaoPraticaNaoPermitida ei){
			this.desfazAlteracaoAtividadeValidarIncremento(classAtividade, operacao);
			throw ei;
		}catch(ExceptionExclusaoPraticaNaoPermitida ee){
			this.desfazAlteracaoAtividadeValidarIncremento(classAtividade, operacao);
			throw ee;
		}catch (ExceptionPraticaNaoLiberada el){
			this.desfazAlteracaoAtividadeValidarIncremento(classAtividade, operacao);
			throw el;
		}
		try{
			this.atividadeIntegracaoIncremento.incluindoExcluindoPratica(classAtividade, operacao);
		}catch(ExceptionInclusaoPraticaNaoPermitida ei){
			this.desfazAlteracaoAtividadeIntegracaoIncremento(classAtividade, operacao);
			throw ei;
		}catch(ExceptionExclusaoPraticaNaoPermitida ee){
			this.desfazAlteracaoAtividadeIntegracaoIncremento(classAtividade, operacao);
			throw ee;
		}catch (ExceptionPraticaNaoLiberada el){
			this.desfazAlteracaoAtividadeIntegracaoIncremento(classAtividade, operacao);
			throw el;
		}
		try{
			this.atividadeValidarSistema.incluindoExcluindoPratica(classAtividade, operacao);
		}catch(ExceptionInclusaoPraticaNaoPermitida ei){
			this.desfazAlteracaoAtividadeValidarSistema(classAtividade, operacao);
			throw ei;
		}catch(ExceptionExclusaoPraticaNaoPermitida ee){
			this.desfazAlteracaoAtividadeValidarSistema(classAtividade, operacao);
			throw ee;
		}catch (ExceptionPraticaNaoLiberada el){
			this.desfazAlteracaoAtividadeValidarSistema(classAtividade, operacao);
			throw el;
		}

	}
	 private void desfazAlteracaoAtividadeValidarIncremento(Class classAtividade,  String operacao)throws ExceptionPraticaNaoLiberada, ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida{
    	if (Constantes.INCLUSAO.equalsIgnoreCase(operacao)){
    		this.atividadeDesenvolverIncrementoDoSistema.incluindoExcluindoPratica(classAtividade, Constantes.EXCLUSAO);
    	}else{//operacao EXCLUSAO
    		this.atividadeDesenvolverIncrementoDoSistema.incluindoExcluindoPratica(classAtividade, Constantes.INCLUSAO);
    	}
    }
    private void desfazAlteracaoAtividadeIntegracaoIncremento(Class classAtividade,  String operacao)throws ExceptionPraticaNaoLiberada, ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida{
    	if (Constantes.INCLUSAO.equalsIgnoreCase(operacao)){
    		this.atividadeDesenvolverIncrementoDoSistema.incluindoExcluindoPratica(classAtividade, Constantes.EXCLUSAO);
    		this.atividadeValidarIncremento.incluindoExcluindoPratica(classAtividade, Constantes.EXCLUSAO);
    	}else{//operacao EXCLUSAO
    		this.atividadeDesenvolverIncrementoDoSistema.incluindoExcluindoPratica(classAtividade, Constantes.INCLUSAO);
    		this.atividadeValidarIncremento.incluindoExcluindoPratica(classAtividade, Constantes.INCLUSAO);
    	}
    }
    private void desfazAlteracaoAtividadeValidarSistema(Class classAtividade,  String operacao)throws ExceptionPraticaNaoLiberada, ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida{
    	if (Constantes.INCLUSAO.equalsIgnoreCase(operacao)){
    		this.atividadeDesenvolverIncrementoDoSistema.incluindoExcluindoPratica(classAtividade, Constantes.EXCLUSAO);
    		this.atividadeValidarIncremento.incluindoExcluindoPratica(classAtividade, Constantes.EXCLUSAO);
    		this.atividadeIntegracaoIncremento.incluindoExcluindoPratica(classAtividade, Constantes.EXCLUSAO);
    	}else{//operacao EXCLUSAO
    		this.atividadeDesenvolverIncrementoDoSistema.incluindoExcluindoPratica(classAtividade, Constantes.INCLUSAO);
    		this.atividadeValidarIncremento.incluindoExcluindoPratica(classAtividade, Constantes.INCLUSAO);
    		this.atividadeIntegracaoIncremento.incluindoExcluindoPratica(classAtividade, Constantes.INCLUSAO);
    	}
    }



    public AtividadeDesenvolverIncrementoDoSistema getAtividadeDesenvolverIncrementoDoSistema() {
        return this.atividadeDesenvolverIncrementoDoSistema;
    }
    protected void setAtividadeDesenvolverIncrementoDoSistema(
            AtividadeDesenvolverIncrementoDoSistema etapaDesenvolvierIncrementoDoSistema) {
        this.atividadeDesenvolverIncrementoDoSistema = etapaDesenvolvierIncrementoDoSistema;
    }
    public AtividadeIntegracaoIncremento getAtividadeIntegracaoIncremento() {
        return this.atividadeIntegracaoIncremento;
    }
    protected void setAtividadeIntegracaoIncremento(AtividadeIntegracaoIncremento etapaIntegracaoIncremento) {
        this.atividadeIntegracaoIncremento = etapaIntegracaoIncremento;
    }
    public AtividadeValidarIncremento getAtividadeValidarIncremento() {
        return this.atividadeValidarIncremento;
    }
    protected void setAtividadeValidarIncremento(AtividadeValidarIncremento etapaValidarIncremento) {
        this.atividadeValidarIncremento = etapaValidarIncremento;
    }
    public AtividadeValidarSistema getAtividadeValidarSistema() {
        return this.atividadeValidarSistema;
    }
    protected void setAtividadeValidarSistema(AtividadeValidarSistema etapaValidarSistema) {
        this.atividadeValidarSistema = etapaValidarSistema;
    }

    public Iteracao copiaCicloDeDesenvolvimento(){
    	Iteracao cicloDeDesenvolvimento = new Iteracao();
    	cicloDeDesenvolvimento.setAtividadeDesenvolverIncrementoDoSistema(
    			this.atividadeDesenvolverIncrementoDoSistema.copiaAtividade());
    	cicloDeDesenvolvimento.setAtividadeIntegracaoIncremento(this.atividadeIntegracaoIncremento.copiaAtividade());
    	cicloDeDesenvolvimento.setAtividadeValidarIncremento(this.atividadeValidarIncremento.copiaAtividade());
    	cicloDeDesenvolvimento.setAtividadeValidarSistema(this.atividadeValidarSistema.copiaAtividade());
    	return cicloDeDesenvolvimento;
    }

	public Date getDtFimEfetiva() {
		return dtFimEfetiva;
	}

	public void setDtFimEfetiva(Date dtFimEfetiva) {
		this.dtFimEfetiva = dtFimEfetiva;
	}

	public Date getDtFimPrevista() {
		return dtFimPrevista;
	}

	public void setDtFimPrevista(Date dtFimPrevista) {
		this.dtFimPrevista = dtFimPrevista;
	}

	public Date getDtInicioEfetiva() {
		return dtInicioEfetiva;
	}

	public void setDtInicioEfetiva(Date dtInicioEfetiva) {
		this.dtInicioEfetiva = dtInicioEfetiva;
	}

	public Date getDtInicioPrevista() {
		return dtInicioPrevista;
	}

	public void setDtInicioPrevista(Date dtInicioPrevista) {
		this.dtInicioPrevista = dtInicioPrevista;
	}

	public ArrayList getRequisitos() {
		return this.requisitos;
	}

	public void setRequisitos(ArrayList requisitos) {
		this.requisitos = requisitos;
	}

	public void addRequisito(Requisito requisito){
		this.requisitos.add(requisito);
	}

	public void removeRequisito(Requisito requisito){
		Iterator it = this.requisitos.iterator();
		Requisito r = null;
		while(it.hasNext()){
			r = (Requisito) it.next();
			if (requisito.getNome().equals(r.getNome())){
				it.remove();
				return;
			}
		}
	}

	public int getNumero() {
		return this.numero;
	}

	public void setNumero(int numero) {
		this.numero = numero;
	}

        public String toString(){
            return "(" + this.numero + ") " +"Iterao" ;
        }


}
