/*
 * Created on 23/08/2005
 */
package br.ufsc.fcama.logica;

import java.io.File;
import java.util.ArrayList;
import java.util.Iterator;

import br.ufsc.fcama.exception.ExceptionExclusaoPraticaNaoPermitida;
import br.ufsc.fcama.exception.ExceptionInclusaoPraticaNaoPermitida;
import br.ufsc.fcama.exception.ExceptionPraticaNaoLiberada;
import br.ufsc.fcama.exception.ExceptionStakeholderJaCadastrado;
import br.ufsc.fcama.logica.atividade.AtividadeAtribuicaoDosRequisitos;
import br.ufsc.fcama.logica.atividade.AtividadeDefinicaoDosRequisitos;
import br.ufsc.fcama.logica.atividade.AtividadeEntregaFinal;
import br.ufsc.fcama.logica.atividade.AtividadeProjetoDoSistema;
import br.ufsc.fcama.logica.objAux.Constantes;
import br.ufsc.fcama.logica.objAux.Stakeholder;
import br.ufsc.fcama.persistencia.ObjectFCAMA;

/**
 * @author Thiago Leo Machado
 */
public class Projeto extends ObjectFCAMA {

	private String nomeProjeto;
	private File diretorioPorjeto;
    private AtividadeDefinicaoDosRequisitos atividadeDefinicaoDosRequisitos;
    private AtividadeAtribuicaoDosRequisitos atividadeAtribuicaoDosRequisitos;
    private AtividadeProjetoDoSistema atividadeProjetoDoSistema;
    //ciclosDeDesenvolvimento contem os CicloDeDesenvolvimento
    //pois um projeto pode e  recomendado que possua mais de um CicloDeDesenvolvimento
    //cada CicloDeDesenvolvimento  composto pelas etapas EtapaDesenvolverIncrementoDoSistema,
    //EtapaValidarIncremento, EtapaIntegracaoIncremento, EtapaValidarSistema e EtapaEntregaFinal
    private ArrayList iteracoes;
    private AtividadeEntregaFinal atividadeEntregaFinal;
    //lista de colaboradores do projeto
    private ArrayList stakeholders;

    public Projeto() {
        this.setAtividadeDefinicaoDosRequisitos(new AtividadeDefinicaoDosRequisitos());
        this.setAtividadeAtribuicaoDosRequisitos(new AtividadeAtribuicaoDosRequisitos());
        this.setAtividadeProjetoDoSistema(new AtividadeProjetoDoSistema());
        this.setIteracoes(new ArrayList());
        //cria o projeto com um cicloDeDesenvolvimento
        Iteracao ciclo = new Iteracao();
        ciclo.setNumero(1);
        this.iteracoes.add(ciclo);
        this.setAtividadeEntregaFinal(new AtividadeEntregaFinal());
        this.stakeholders = new ArrayList();
    }

    public boolean isRequisitosProjetoCompleto(){
    	
    	if(atividadeDefinicaoDosRequisitos.isRequisitosCompletos()
    	   && atividadeAtribuicaoDosRequisitos.isRequisitosCompletos()
    	   && atividadeProjetoDoSistema.isRequisitosCompletos()
    	   && ((Iteracao)this.iteracoes.get(0)).isRequisitosIteracaoCompletos()
    	   && atividadeEntregaFinal.isRequisitosCompletos()){
    		return true;
    	}else{
    		return false;
    	}
    }
    
    public void incluindoExcluindoPratica(Class classAtividade, String operacao)throws ExceptionPraticaNaoLiberada,  ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida {
		this.atividadeDefinicaoDosRequisitos.incluindoExcluindoPratica(classAtividade, operacao);
		try{
			this.atividadeAtribuicaoDosRequisitos.incluindoExcluindoPratica(classAtividade, operacao);
		}catch(ExceptionInclusaoPraticaNaoPermitida ei){
			this.desfazAlteracaoAtividadeAtribuicaoDosRequisitos(classAtividade, operacao);
			throw ei;
		}catch(ExceptionExclusaoPraticaNaoPermitida ee){
			this.desfazAlteracaoAtividadeAtribuicaoDosRequisitos(classAtividade, operacao);
			throw ee;
		}catch (ExceptionPraticaNaoLiberada el){
			this.desfazAlteracaoAtividadeAtribuicaoDosRequisitos(classAtividade, operacao);
			throw el;
		}
		try{
			this.atividadeProjetoDoSistema.incluindoExcluindoPratica(classAtividade, operacao);
		}catch(ExceptionInclusaoPraticaNaoPermitida ei){
			this.desfazAlteracaoAtividadeProjetoDoSistema(classAtividade, operacao);
			throw ei;
		}catch(ExceptionExclusaoPraticaNaoPermitida ee){
			this.desfazAlteracaoAtividadeProjetoDoSistema(classAtividade, operacao);
			throw ee;
		}catch (ExceptionPraticaNaoLiberada el){
			this.desfazAlteracaoAtividadeProjetoDoSistema(classAtividade, operacao);
			throw el;
		}
		try{
        	this.atividadeEntregaFinal.incluindoExcluindoPratica(classAtividade, operacao);
        }catch(ExceptionInclusaoPraticaNaoPermitida ei){
			this.desfazAlteracaoAtividadeEntregaFinal(classAtividade, operacao);
			throw ei;
		}catch(ExceptionExclusaoPraticaNaoPermitida ee){
			this.desfazAlteracaoAtividadeEntregaFinal(classAtividade, operacao);
			throw ee;
		}catch (ExceptionPraticaNaoLiberada el){
			this.desfazAlteracaoAtividadeEntregaFinal(classAtividade, operacao);
			throw el;
		}
        try{
			//para percorrer todos os ciclos de desenvolvimento
			Iterator it = this.iteracoes.iterator();
			Iteracao cd;
			while(it.hasNext()){
				cd = (Iteracao) it.next();
				cd.incluindoExcluindoPratica(classAtividade, operacao);
			}
        }catch(ExceptionInclusaoPraticaNaoPermitida ei){
			this.desfazAlteracaoIteracao(classAtividade, operacao);
			throw ei;
		}catch(ExceptionExclusaoPraticaNaoPermitida ee){
			this.desfazAlteracaoIteracao(classAtividade, operacao);
			throw ee;
		}catch (ExceptionPraticaNaoLiberada el){
			this.desfazAlteracaoIteracao(classAtividade, operacao);
			throw el;
		}
	}
	private void desfazAlteracaoAtividadeAtribuicaoDosRequisitos(Class classAtividade,  String operacao)throws ExceptionPraticaNaoLiberada, ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida{
    	if (Constantes.INCLUSAO.equalsIgnoreCase(operacao)){
    		this.atividadeDefinicaoDosRequisitos.incluindoExcluindoPratica(classAtividade, Constantes.EXCLUSAO);
    	}else{//operacao EXCLUSAO
    		this.atividadeDefinicaoDosRequisitos.incluindoExcluindoPratica(classAtividade, Constantes.INCLUSAO);
    	}
    }
	private void desfazAlteracaoAtividadeProjetoDoSistema(Class classAtividade,  String operacao)throws ExceptionPraticaNaoLiberada, ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida{
    	if (Constantes.INCLUSAO.equalsIgnoreCase(operacao)){
    		this.atividadeDefinicaoDosRequisitos.incluindoExcluindoPratica(classAtividade, Constantes.EXCLUSAO);
    		this.atividadeAtribuicaoDosRequisitos.incluindoExcluindoPratica(classAtividade, Constantes.EXCLUSAO);
    	}else{//operacao EXCLUSAO
    		this.atividadeDefinicaoDosRequisitos.incluindoExcluindoPratica(classAtividade, Constantes.INCLUSAO);
    		this.atividadeAtribuicaoDosRequisitos.incluindoExcluindoPratica(classAtividade, Constantes.INCLUSAO);
    	}
    }
	private void desfazAlteracaoAtividadeDefinicaoDosRequisitos(Class classAtividade,  String operacao)throws ExceptionPraticaNaoLiberada, ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida{
    	if (Constantes.INCLUSAO.equalsIgnoreCase(operacao)){
    		this.atividadeDefinicaoDosRequisitos.incluindoExcluindoPratica(classAtividade, Constantes.EXCLUSAO);
    		this.atividadeAtribuicaoDosRequisitos.incluindoExcluindoPratica(classAtividade, Constantes.EXCLUSAO);
    		this.atividadeProjetoDoSistema.incluindoExcluindoPratica(classAtividade, Constantes.EXCLUSAO);
    	}else{//operacao EXCLUSAO
    		this.atividadeDefinicaoDosRequisitos.incluindoExcluindoPratica(classAtividade, Constantes.INCLUSAO);
    		this.atividadeAtribuicaoDosRequisitos.incluindoExcluindoPratica(classAtividade, Constantes.INCLUSAO);
    		this.atividadeProjetoDoSistema.incluindoExcluindoPratica(classAtividade, Constantes.INCLUSAO);
    	}
    }
	private void desfazAlteracaoAtividadeEntregaFinal(Class classAtividade,  String operacao)throws ExceptionPraticaNaoLiberada, ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida{
    	if (Constantes.INCLUSAO.equalsIgnoreCase(operacao)){
    		this.atividadeDefinicaoDosRequisitos.incluindoExcluindoPratica(classAtividade, Constantes.EXCLUSAO);
    		this.atividadeAtribuicaoDosRequisitos.incluindoExcluindoPratica(classAtividade, Constantes.EXCLUSAO);
    		this.atividadeProjetoDoSistema.incluindoExcluindoPratica(classAtividade, Constantes.EXCLUSAO);
    		this.atividadeDefinicaoDosRequisitos.incluindoExcluindoPratica(classAtividade, Constantes.EXCLUSAO);
    	}else{//operacao EXCLUSAO
    		this.atividadeDefinicaoDosRequisitos.incluindoExcluindoPratica(classAtividade, Constantes.INCLUSAO);
    		this.atividadeAtribuicaoDosRequisitos.incluindoExcluindoPratica(classAtividade, Constantes.INCLUSAO);
    		this.atividadeProjetoDoSistema.incluindoExcluindoPratica(classAtividade, Constantes.INCLUSAO);
    		this.atividadeProjetoDoSistema.incluindoExcluindoPratica(classAtividade, Constantes.INCLUSAO);
    	}
    }
	private void desfazAlteracaoIteracao(Class classAtividade,  String operacao)throws ExceptionPraticaNaoLiberada, ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida{
    	if (Constantes.INCLUSAO.equalsIgnoreCase(operacao)){
    		this.atividadeDefinicaoDosRequisitos.incluindoExcluindoPratica(classAtividade, Constantes.EXCLUSAO);
    		this.atividadeAtribuicaoDosRequisitos.incluindoExcluindoPratica(classAtividade, Constantes.EXCLUSAO);
    		this.atividadeProjetoDoSistema.incluindoExcluindoPratica(classAtividade, Constantes.EXCLUSAO);
    		this.atividadeDefinicaoDosRequisitos.incluindoExcluindoPratica(classAtividade, Constantes.EXCLUSAO);
    		this.atividadeEntregaFinal.incluindoExcluindoPratica(classAtividade, Constantes.EXCLUSAO);
    	}else{//operacao EXCLUSAO
    		this.atividadeDefinicaoDosRequisitos.incluindoExcluindoPratica(classAtividade, Constantes.INCLUSAO);
    		this.atividadeAtribuicaoDosRequisitos.incluindoExcluindoPratica(classAtividade, Constantes.INCLUSAO);
    		this.atividadeProjetoDoSistema.incluindoExcluindoPratica(classAtividade, Constantes.INCLUSAO);
    		this.atividadeProjetoDoSistema.incluindoExcluindoPratica(classAtividade, Constantes.INCLUSAO);
    		this.atividadeEntregaFinal.incluindoExcluindoPratica(classAtividade, Constantes.INCLUSAO);
    	}
    }


    public ArrayList getIteracoes() {
        return this.iteracoes;
    }
    public void addIteracao(){
        Iteracao ciclo = ((Iteracao)this.iteracoes.get(0)).copiaCicloDeDesenvolvimento();
    	this.iteracoes.add(ciclo);
        ciclo.setNumero((this.iteracoes.size()));
    }
    public void removeUltimaIteracao(){
    	this.iteracoes.remove((this.iteracoes.size()-1));
    }
    public void addIteracao(Iteracao iteracao){
    	this.iteracoes.add(iteracao);
            iteracao.setNumero((this.iteracoes.size() ));
    }
    public void setIteracoes(ArrayList iteracoes) {
        this.iteracoes = iteracoes;
    }
    public AtividadeAtribuicaoDosRequisitos getAtividadeAtribuicaoDosRequisitos() {
        return this.atividadeAtribuicaoDosRequisitos;
    }
    public void setAtividadeAtribuicaoDosRequisitos(AtividadeAtribuicaoDosRequisitos etapaAtribuicaoDosRequisitos) {
        this.atividadeAtribuicaoDosRequisitos = etapaAtribuicaoDosRequisitos;
    }
    public AtividadeDefinicaoDosRequisitos getAtividadeDefinicaoDosRequisitos() {
        return this.atividadeDefinicaoDosRequisitos;
    }
    public void setAtividadeDefinicaoDosRequisitos(AtividadeDefinicaoDosRequisitos etapaDefinicaoDosRequisitos) {
        this.atividadeDefinicaoDosRequisitos = etapaDefinicaoDosRequisitos;
    }
    public AtividadeEntregaFinal getAtividadeEntregaFinal() {
        return this.atividadeEntregaFinal;
    }
    public void setAtividadeEntregaFinal(AtividadeEntregaFinal etapaEntregaFinal) {
        this.atividadeEntregaFinal = etapaEntregaFinal;
    }
    public AtividadeProjetoDoSistema getAtividadeProjetoDoSistema() {
        return this.atividadeProjetoDoSistema;
    }
    public void setAtividadeProjetoDoSistema(AtividadeProjetoDoSistema etapaProjetoDoSistema) {
        this.atividadeProjetoDoSistema = etapaProjetoDoSistema;
    }

	public ArrayList getStakeholders() {
		return this.stakeholders;
	}

	public void setStakeholders(ArrayList stakeholders){
		this.stakeholders = stakeholders;
	}
	
	public boolean stakeholderCadastrado(Stakeholder stakeholder){
		Iterator it = this.stakeholders.iterator();
		Stakeholder s = null;
		while (it.hasNext()){
			s = (Stakeholder) it.next();
			if ((stakeholder.getNome()+ " " + stakeholder.getFuncao()).equals(s.getNome()+ " " + s.getFuncao())){
					return true;
			}
		}
		return false;
	}

	public void addStakeholder(Stakeholder stakeholder)throws ExceptionStakeholderJaCadastrado {
		if (this.stakeholderCadastrado(stakeholder)){
			throw new ExceptionStakeholderJaCadastrado();
		}else{
			this.stakeholders.add(stakeholder);
		}
	}

	public void removeStakeholder(Stakeholder stakeholder){
		Iterator it = this.stakeholders.iterator();
		Stakeholder s = null;
		while (it.hasNext()){
			s = (Stakeholder) it.next();
			if ((stakeholder.getNome()+ " " + stakeholder.getFuncao()).equals(s.getNome()+ " " + s.getFuncao())){
				it.remove();
				return;
			}
		}
	}

	public String getNomeProjeto() {
		return this.nomeProjeto;
	}

	public void setNomeProjeto(String nomeProjeto) {
		this.nomeProjeto = nomeProjeto;
	}

	public File getDiretorioPorjeto() {
		return diretorioPorjeto;
	}

	public void setDiretorioPorjeto(File diretorioPorjeto) {
		this.diretorioPorjeto = diretorioPorjeto;
	}

	/**
	 * O projeto trabalho para a distribuio e definio do responsveis
	 * com os requisitos da listaderequisito seno userstories seno documentacaoDetalhada
	 * @return
	 */
    public ArrayList getRequisitosDoProjeto(){
    	if (this.getAtividadeDefinicaoDosRequisitos().getPraticaListaDeRequisitos().isSelecionada()){
    		return this.getAtividadeDefinicaoDosRequisitos().getPraticaListaDeRequisitos().getRequisitos();
    	}else if (this.getAtividadeDefinicaoDosRequisitos().getPraticaUserStories().isSelecionada()){
    		return this.getAtividadeDefinicaoDosRequisitos().getPraticaUserStories().getUserStories();
    	}else {
    		return this.getAtividadeDefinicaoDosRequisitos().getPraticaDocumentacaoDetalhada().getRequisitosAnexos();
    	}
    }
	
	
	public String toString(){
        return this.getNomeProjeto();
    }
}
