/*
 * Created on 23/08/2005
 *
 */
package br.ufsc.fcama.logica.atividade;

import java.util.PropertyResourceBundle;

import br.ufsc.fcama.exception.ExceptionPraticaNaoLiberada;
import br.ufsc.fcama.exception.ExceptionPraticaNaoPertenceAEtapa;
import br.ufsc.fcama.exception.ExceptionExclusaoPraticaNaoPermitida;
import br.ufsc.fcama.exception.ExceptionInclusaoPraticaNaoPermitida;
import br.ufsc.fcama.logica.objAux.Constantes;
import br.ufsc.fcama.logica.pratica.Pratica;
import br.ufsc.fcama.logica.pratica.PraticaAtualizacaoDaDocumentacao;
import br.ufsc.fcama.logica.pratica.PraticaDistribuicaoDosRequisitos;
import br.ufsc.fcama.logica.pratica.PraticaDuracaoDasIteracoes;
import br.ufsc.fcama.logica.pratica.PraticaPlanejamentoDasIteracoes;

/**
 * @author Thiago Leo Machado
 */
public class AtividadeAtribuicaoDosRequisitos extends Atividade {

	//atividade optativa
	private PraticaDistribuicaoDosRequisitos praticaDistribuicaoDosRequisitos;
	//atiivdades obrigatrias
	private PraticaPlanejamentoDasIteracoes praticaPlanejamentoDasIteracoes;
	private PraticaDuracaoDasIteracoes praticaDuracaoDasIteracoes;
	private PraticaAtualizacaoDaDocumentacao praticaAtualizacaoDaDocumentacao;

	public AtividadeAtribuicaoDosRequisitos(){
		super();
		this.praticaDistribuicaoDosRequisitos = new PraticaDistribuicaoDosRequisitos();
		this.praticaPlanejamentoDasIteracoes = new PraticaPlanejamentoDasIteracoes();
		this.praticaDuracaoDasIteracoes = new PraticaDuracaoDasIteracoes();
		this.praticaAtualizacaoDaDocumentacao = new PraticaAtualizacaoDaDocumentacao();
	}

	/* (non-Javadoc)
	 * @see br.ufsc.fcama.etapa.Etapa#isRequisitosCompletos()
	 */
	public boolean isRequisitosCompletos() {
		//confere se as atividades obrigatrias foram selecionadas
		if(this.praticaPlanejamentoDasIteracoes.isSelecionada()
		   && this.praticaDuracaoDasIteracoes.isSelecionada()
		   && this.praticaAtualizacaoDaDocumentacao.isSelecionada()){
			return true;
		}else{
			return false;
		}
	}

	/* (non-Javadoc)
	 * @see br.ufsc.fcama.etapa.Etapa#incluindaExcluindoAtividade(java.lang.Class, java.lang.String)
	 */
	public void incluindoExcluindoPratica(Class classPratica, String operacao) throws ExceptionPraticaNaoLiberada,  ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida {
		try{
			this.praticaDistribuicaoDosRequisitos.confereDependencia(classPratica, operacao);
			this.praticaPlanejamentoDasIteracoes.confereDependencia(classPratica, operacao);
			this.praticaDuracaoDasIteracoes.confereDependencia(classPratica, operacao);
			this.praticaAtualizacaoDaDocumentacao.confereDependencia(classPratica, operacao);
			//Confere se  uma das atividade da etapa, caso sim manda selecionara ou tirar a seleo
			this.selecionarPratica(classPratica, operacao);
		//Quando captura uma exceo realiza o operao inversa da que estava realizando
		//para deixar no mesmo estado as atividade
		}catch(ExceptionInclusaoPraticaNaoPermitida ei){
			this.desfazAlteracaoInclusao(classPratica, ei);
			throw ei;
		}catch(ExceptionExclusaoPraticaNaoPermitida ee){
			this.desfazAlteracaoExclusao(classPratica, ee);
			throw ee;
		}
	}

	/**
	 * Desfaz as alteraes realizadas na incluso de uma atividade caso ocorra uma exceo
	 * @param classPratica
	 * @param operacao
	 * @param ei
	 * @throws ExceptionInclusaoPraticaNaoPermitida
	 * @throws ExceptionExclusaoPraticaNaoPermitida
	 */
	private void desfazAlteracaoInclusao(Class classPratica, ExceptionInclusaoPraticaNaoPermitida ei)throws ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida{
		//como AtividadeDistribuicaoDosRequisitos  a primeira no precisa fazer nada caso ela lance uma exception
		if (ei.getClassPratica() == PraticaPlanejamentoDasIteracoes.class){
			this.praticaDistribuicaoDosRequisitos.confereDependencia(classPratica, Constantes.EXCLUSAO);
		}else if (ei.getClassPratica() == PraticaDuracaoDasIteracoes.class){
			this.praticaDistribuicaoDosRequisitos.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaPlanejamentoDasIteracoes.confereDependencia(classPratica, Constantes.EXCLUSAO);
		}else if (ei.getClassPratica() == PraticaAtualizacaoDaDocumentacao.class){
			this.praticaDistribuicaoDosRequisitos.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaPlanejamentoDasIteracoes.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaAtualizacaoDaDocumentacao.confereDependencia(classPratica, Constantes.EXCLUSAO);
		}
	}
	/**
	 * Desfaz as alteraes realizadas na excluso de uma atividade caso ocorra uma exceo
	 * @param classPratica
	 * @param operacao
	 * @param ee
	 * @throws ExceptionInclusaoPraticaNaoPermitida
	 * @throws ExceptionExclusaoPraticaNaoPermitida
	 */
	private void desfazAlteracaoExclusao(Class classPratica, ExceptionExclusaoPraticaNaoPermitida ee)throws ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida{
		//como AtividadeDistribuicaoDosRequisitos  a primeira no precisa fazer nada caso ela lance uma exception
		if (ee.getClassPratica() == PraticaPlanejamentoDasIteracoes.class){
			this.praticaDistribuicaoDosRequisitos.confereDependencia(classPratica, Constantes.INCLUSAO);
		}else if (ee.getClassPratica() == PraticaDuracaoDasIteracoes.class){
			this.praticaDistribuicaoDosRequisitos.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaPlanejamentoDasIteracoes.confereDependencia(classPratica, Constantes.INCLUSAO);
		}else if (ee.getClassPratica() == PraticaAtualizacaoDaDocumentacao.class){
			this.praticaDistribuicaoDosRequisitos.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaPlanejamentoDasIteracoes.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaAtualizacaoDaDocumentacao.confereDependencia(classPratica, Constantes.INCLUSAO);
		}
	}

	/**
	 * Confere se a atividade faz parte da etapa se sim  tenta selecionar ou liberar
	 * caso no possa selecionar lana uma exceo e arruma o estado da atividades
	 * @param classPratica
	 * @param operacao
	 * @throws ExceptionPraticaNaoLiberada
	 * @throws ExceptionInclusaoPraticaNaoPermitida
	 * @throws ExceptionExclusaoPraticaNaoPermitida
	 */
	private void selecionarPratica(Class classPratica, String operacao)throws ExceptionPraticaNaoLiberada, ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida{
		try{
			if (classPratica == PraticaPlanejamentoDasIteracoes.class
					||classPratica == PraticaDuracaoDasIteracoes.class
					||classPratica == PraticaDistribuicaoDosRequisitos.class
					||classPratica == PraticaAtualizacaoDaDocumentacao.class){
				Pratica atividade;
				atividade = this.getPratica(classPratica);
				if (operacao.equalsIgnoreCase(Constantes.EXCLUSAO)){
					atividade.tiraSelecao();
				}else{// se no  incluso
					atividade.selecionar();
				}
			}
		}catch(ExceptionPraticaNaoLiberada el){
			if (operacao.equalsIgnoreCase(Constantes.EXCLUSAO)){
				this.desfazAlteracaoExclusao(classPratica,
						new ExceptionExclusaoPraticaNaoPermitida(PraticaAtualizacaoDaDocumentacao.class));
				//tem que desfazer agora a AtividadeAtualizacaoDaDocumentacao, pois o mtodo anterior no desfaz a ltima
				this.praticaAtualizacaoDaDocumentacao.confereDependencia(classPratica, Constantes.INCLUSAO);
			}else{// se no  incluso
				this.desfazAlteracaoInclusao(classPratica,
						new ExceptionInclusaoPraticaNaoPermitida(PraticaAtualizacaoDaDocumentacao.class));
				//tem que desfazer agora a AtividadeAtualizacaoDaDocumentacao, pois o mtodo anterior no desfaz a ltima
				this.praticaAtualizacaoDaDocumentacao.confereDependencia(classPratica, Constantes.EXCLUSAO);
			}
			throw el;
		} catch (ExceptionPraticaNaoPertenceAEtapa e) {
			//Nunca vai ser lanada essa exceo pq j confere antes da execuo
		}
	}

	/* (non-Javadoc)
	 * @see br.ufsc.fcama.etapa.Etapa#getAtividade(java.lang.Class)
	 */
	public Pratica getPratica(Class classPratica) throws ExceptionPraticaNaoPertenceAEtapa {
		if (classPratica == PraticaPlanejamentoDasIteracoes.class){
			return this.praticaPlanejamentoDasIteracoes;
		}else if (classPratica == PraticaDuracaoDasIteracoes.class){
			return this.praticaDuracaoDasIteracoes;
		}else if (classPratica == PraticaDistribuicaoDosRequisitos.class){
			return this.praticaDistribuicaoDosRequisitos;
		}else if (classPratica == PraticaAtualizacaoDaDocumentacao.class){
			return this.praticaAtualizacaoDaDocumentacao;
		}else {
			throw new ExceptionPraticaNaoPertenceAEtapa(classPratica, AtividadeAtribuicaoDosRequisitos.class);
		}
	}




	/**
	 * @return Returns the atividadeAtualizacaoDaDocumentacao.
	 */
	public PraticaAtualizacaoDaDocumentacao getPraticaAtualizacaoDaDocumentacao() {
		return praticaAtualizacaoDaDocumentacao;
	}
	/**
	 * @return Returns the atividadeDistribuicaoDosRequisitos.
	 */
	public PraticaDistribuicaoDosRequisitos getPraticaDistribuicaoDosRequisitos() {
		return praticaDistribuicaoDosRequisitos;
	}
	/**
	 * @return Returns the atividadeDuracaoDasIteracoes.
	 */
	public PraticaDuracaoDasIteracoes getPraticaDuracaoDasIteracoes() {
		return praticaDuracaoDasIteracoes;
	}
	/**
	 * @return Returns the atividadePlanejamentoDasIteracoes.
	 */
	public PraticaPlanejamentoDasIteracoes getPraticaPlanejamentoDasIteracoes() {
		return praticaPlanejamentoDasIteracoes;
	}

        public String toString(){
        	return PropertyResourceBundle
    		.getBundle("br.ufsc.fcama.internacionalizacao.ProgramProperties")
    			.getString("br.ufsc.fcama.logica.atividade.AtribuicaoDosRequisitos");
       }

}
