/*
 * Created on 23/08/2005
 *
 */
package br.ufsc.fcama.logica.atividade;

import java.util.PropertyResourceBundle;

import br.ufsc.fcama.exception.ExceptionPraticaNaoLiberada;
import br.ufsc.fcama.exception.ExceptionPraticaNaoPertenceAEtapa;
import br.ufsc.fcama.exception.ExceptionExclusaoPraticaNaoPermitida;
import br.ufsc.fcama.exception.ExceptionInclusaoPraticaNaoPermitida;
import br.ufsc.fcama.logica.objAux.Constantes;
import br.ufsc.fcama.logica.pratica.Pratica;
import br.ufsc.fcama.logica.pratica.PraticaDocumentacaoDetalhada;
import br.ufsc.fcama.logica.pratica.PraticaListaDeRequisitos;
import br.ufsc.fcama.logica.pratica.PraticaOrganizacaoDaDocumentacao;
import br.ufsc.fcama.logica.pratica.PraticaUserStories;

/**
 * @author Thiago Leo Machado
 */
public class AtividadeDefinicaoDosRequisitos extends Atividade {

	//Atividades optativas
	private PraticaUserStories praticaUserStories;
	private PraticaListaDeRequisitos praticaListaDeRequisitos;
	private PraticaDocumentacaoDetalhada praticaDocumentacaoDetalhada;
	//Atividades Obrigatrias
	private PraticaOrganizacaoDaDocumentacao praticaOrganizacaoDaDocumentacao;

	public AtividadeDefinicaoDosRequisitos(){
		super();
		this.praticaUserStories = new PraticaUserStories();
		this.praticaListaDeRequisitos = new PraticaListaDeRequisitos();
		this.praticaDocumentacaoDetalhada = new PraticaDocumentacaoDetalhada();
		this.praticaOrganizacaoDaDocumentacao = new PraticaOrganizacaoDaDocumentacao();
	}

	/* (non-Javadoc)
	 * @see br.ufsc.fcama.etapa.Etapa#isRequisitosCompletos()
	 */
	public boolean isRequisitosCompletos() {
		//confere se a atividade obrigatria foi selecionada
		if (this.praticaOrganizacaoDaDocumentacao.isSelecionada()){
			return true;
		}else{
			return false;
		}
	}

	/* (non-Javadoc)
	 * @see br.ufsc.fcama.etapa.Etapa#incluindaExcluindoAtividade(java.lang.Class, java.lang.String)
	 */
	public void incluindoExcluindoPratica(Class classPratica, String operacao) throws ExceptionPraticaNaoLiberada, ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida {
		try{
			this.praticaUserStories.confereDependencia(classPratica, operacao);
			this.praticaListaDeRequisitos.confereDependencia(classPratica, operacao);
			this.praticaDocumentacaoDetalhada.confereDependencia(classPratica, operacao);
			this.praticaOrganizacaoDaDocumentacao.confereDependencia(classPratica, operacao);
			//Confere se  uma das atividade da etapa, caso sim manda selecionara ou tirar a seleo
			this.selecionarPratica(classPratica, operacao);
		//Quando captura uma exceo realiza o operao inversa da que estava realizando
		//para deixar no mesmo estado as atividade
		}catch(ExceptionInclusaoPraticaNaoPermitida ei){
			this.desfazAlteracaoInclusao(classPratica, ei);
			throw ei;
		}catch(ExceptionExclusaoPraticaNaoPermitida ee){
			this.desfazAlteracaoExclusao(classPratica, ee);
			throw ee;
		}
	}


	/**
	 * Desfaz as alteraes realizadas na incluso de uma atividade caso ocorra uma exceo
	 * @param classPratica
	 * @param operacao
	 * @param ei
	 * @throws ExceptionInclusaoPraticaNaoPermitida
	 * @throws ExceptionExclusaoPraticaNaoPermitida
	 */
	private void desfazAlteracaoInclusao(Class classPratica, ExceptionInclusaoPraticaNaoPermitida ei)throws ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida{
		//como atividadeUserStories  a primeira no precisa fazer nada caso ela lance uma exception
		if (ei.getClassPratica() == PraticaListaDeRequisitos.class){
			this.praticaUserStories.confereDependencia(classPratica, Constantes.EXCLUSAO);
		}else if (ei.getClassPratica() == PraticaDocumentacaoDetalhada.class){
			this.praticaUserStories.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaListaDeRequisitos.confereDependencia(classPratica, Constantes.EXCLUSAO);
		}else if (ei.getClassPratica() == PraticaOrganizacaoDaDocumentacao.class){
			this.praticaUserStories.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaListaDeRequisitos.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaDocumentacaoDetalhada.confereDependencia(classPratica, Constantes.EXCLUSAO);
		}
	}
	/**
	 * Desfaz as alteraes realizadas na excluso de uma atividade caso ocorra uma exceo
	 * @param classPratica
	 * @param operacao
	 * @param ee
	 * @throws ExceptionInclusaoPraticaNaoPermitida
	 * @throws ExceptionExclusaoPraticaNaoPermitida
	 */
	private void desfazAlteracaoExclusao(Class classPratica, ExceptionExclusaoPraticaNaoPermitida ee)throws ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida{
		//como atividadeUserStories  a primeira no precisa fazer nada caso ela lance uma exception
		if (ee.getClassPratica() == PraticaListaDeRequisitos.class){
			this.praticaUserStories.confereDependencia(classPratica, Constantes.INCLUSAO);
		}else if (ee.getClassPratica() == PraticaDocumentacaoDetalhada.class){
			this.praticaUserStories.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaListaDeRequisitos.confereDependencia(classPratica, Constantes.INCLUSAO);
		}else if (ee.getClassPratica() == PraticaOrganizacaoDaDocumentacao.class){
			this.praticaUserStories.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaListaDeRequisitos.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaDocumentacaoDetalhada.confereDependencia(classPratica, Constantes.INCLUSAO);
		}
	}

	/**
	 * Confere se a atividade faz parte da etapa se sim  tenta selecionar ou liberar
	 * caso no possa selecionar lana uma exceo e arruma o estado da atividades
	 * @param classPratica
	 * @param operacao
	 * @throws ExceptionPraticaNaoLiberada
	 * @throws ExceptionInclusaoPraticaNaoPermitida
	 * @throws ExceptionExclusaoPraticaNaoPermitida
	 */
	private void selecionarPratica(Class classPratica, String operacao)throws ExceptionPraticaNaoLiberada, ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida{
		try{
			if (classPratica == PraticaUserStories.class
					||classPratica == PraticaListaDeRequisitos.class
					||classPratica == PraticaDocumentacaoDetalhada.class
					||classPratica == PraticaOrganizacaoDaDocumentacao.class){
				Pratica atividade;
				atividade = this.getPratica(classPratica);
				if (operacao.equalsIgnoreCase(Constantes.EXCLUSAO)){
					atividade.tiraSelecao();
				}else{// se no  incluso
					atividade.selecionar();
				}
			}
		}catch(ExceptionPraticaNaoLiberada el){
			if (operacao.equalsIgnoreCase(Constantes.EXCLUSAO)){
				this.desfazAlteracaoExclusao(classPratica,
						new ExceptionExclusaoPraticaNaoPermitida(PraticaOrganizacaoDaDocumentacao.class));
				//tem que desfazer agora a AtividadeOrganizacaoDaDocumentacao, pois o mtodo anterior no desfaz a ltima
				this.praticaOrganizacaoDaDocumentacao.confereDependencia(classPratica, Constantes.INCLUSAO);
			}else{// se no  incluso
				this.desfazAlteracaoInclusao(classPratica,
						new ExceptionInclusaoPraticaNaoPermitida(PraticaOrganizacaoDaDocumentacao.class));
				//tem que desfazer agora a AtividadeOrganizacaoDaDocumentacao, pois o mtodo anterior no desfaz a ltima
				this.praticaOrganizacaoDaDocumentacao.confereDependencia(classPratica, Constantes.EXCLUSAO);
			}
			throw el;
		} catch (ExceptionPraticaNaoPertenceAEtapa e) {
			//Nunca vai ser lanada essa exceo pq j confere antes da execuo
		}
	}


	/* (non-Javadoc)
	 * @see br.ufsc.fcama.etapa.Etapa#getAtividade(java.lang.Class)
	 */
	public Pratica getPratica(Class classPratica) throws ExceptionPraticaNaoPertenceAEtapa {
		if (classPratica == PraticaUserStories.class){
			return this.praticaUserStories;
		}else if (classPratica == PraticaListaDeRequisitos.class){
			return this.praticaListaDeRequisitos;
		}else if (classPratica == PraticaDocumentacaoDetalhada.class){
			return this.praticaDocumentacaoDetalhada;
		}else if (classPratica == PraticaOrganizacaoDaDocumentacao.class){
			return this.praticaOrganizacaoDaDocumentacao;
		}else{
			throw new ExceptionPraticaNaoPertenceAEtapa(classPratica,AtividadeDefinicaoDosRequisitos.class );
		}
	}


	/**
	 * @return Returns the atividadeDocumentacaoDetalhada.
	 */
	public PraticaDocumentacaoDetalhada getPraticaDocumentacaoDetalhada() {
		return praticaDocumentacaoDetalhada;
	}
	/**
	 * @return Returns the atividadeListaDeRequisitos.
	 */
	public PraticaListaDeRequisitos getPraticaListaDeRequisitos() {
		return praticaListaDeRequisitos;
	}
	/**
	 * @return Returns the atividadeOrganizacaoDaDocumentacao.
	 */
	public PraticaOrganizacaoDaDocumentacao getPraticaOrganizacaoDaDocumentacao() {
		return praticaOrganizacaoDaDocumentacao;
	}
	/**
	 * @return Returns the atividadeUserStories.
	 */
	public PraticaUserStories getPraticaUserStories() {
		return praticaUserStories;
	}

        public String toString(){
        	return PropertyResourceBundle
    		.getBundle("br.ufsc.fcama.internacionalizacao.ProgramProperties")
    			.getString("br.ufsc.fcama.logica.atividade.DefinicaoDosRequisitos");
        }
}
