/*
 * Created on 23/08/2005
 *
 */
package br.ufsc.fcama.logica.atividade;

import java.util.PropertyResourceBundle;

import br.ufsc.fcama.exception.ExceptionPraticaNaoLiberada;
import br.ufsc.fcama.exception.ExceptionPraticaNaoPertenceAEtapa;
import br.ufsc.fcama.exception.ExceptionExclusaoPraticaNaoPermitida;
import br.ufsc.fcama.exception.ExceptionInclusaoPraticaNaoPermitida;
import br.ufsc.fcama.logica.objAux.Constantes;
import br.ufsc.fcama.logica.pratica.Pratica;
import br.ufsc.fcama.logica.pratica.PraticaControleDeVersoes;
import br.ufsc.fcama.logica.pratica.PraticaDesenvolvimentoColetivo;
import br.ufsc.fcama.logica.pratica.PraticaDesenvolvimentoEmDuplas;
import br.ufsc.fcama.logica.pratica.PraticaDesenvolvimentoLadoALado;
import br.ufsc.fcama.logica.pratica.PraticaDesenvolvimentoSimultaneo;
import br.ufsc.fcama.logica.pratica.PraticaDocumentacaoDoDesenvolvimento;
import br.ufsc.fcama.logica.pratica.PraticaEscritaDosTestesAntesDaImplementacao;
import br.ufsc.fcama.logica.pratica.PraticaImplementacao;
import br.ufsc.fcama.logica.pratica.PraticaIntegracaoParalela;
import br.ufsc.fcama.logica.pratica.PraticaRefactoring;
import br.ufsc.fcama.logica.pratica.PraticaReunioesDiarias;

/**
 * @author Thiago Leo Machado
 */
public class AtividadeDesenvolverIncrementoDoSistema extends Atividade {

	//atividade obrigatria
	private PraticaImplementacao praticaImplementacao;
	//atividades optativas
	private PraticaEscritaDosTestesAntesDaImplementacao praticaEscritaDosTestesAntesDaImplementacao;
	private PraticaDesenvolvimentoColetivo praticaDesenvolvimentoColetivo;
	private PraticaDesenvolvimentoEmDuplas praticaDesenvolvimentoEmDuplas;
	private PraticaDesenvolvimentoLadoALado praticaDesenvolvimentoLadoALado;
	private PraticaRefactoring praticaRefactoring;
	private PraticaReunioesDiarias praticaReunioesDiarias;
	private PraticaDesenvolvimentoSimultaneo praticaDesenvolvimentoSimultaneo;
	private PraticaIntegracaoParalela praticaIntegracaoParalela;
	private PraticaDocumentacaoDoDesenvolvimento praticaDocumentacaoDoDesenvolvimento;
	private PraticaControleDeVersoes praticaControleDeVersoes;

	public AtividadeDesenvolverIncrementoDoSistema(){
		super();
		this.praticaImplementacao = new PraticaImplementacao();
		this.praticaEscritaDosTestesAntesDaImplementacao = new PraticaEscritaDosTestesAntesDaImplementacao();
		this.praticaDesenvolvimentoColetivo = new PraticaDesenvolvimentoColetivo();
		this.praticaDesenvolvimentoEmDuplas = new PraticaDesenvolvimentoEmDuplas();
		this.praticaDesenvolvimentoLadoALado = new PraticaDesenvolvimentoLadoALado();
		this.praticaRefactoring = new PraticaRefactoring();
		this.praticaReunioesDiarias = new PraticaReunioesDiarias();
		this.praticaDesenvolvimentoSimultaneo = new PraticaDesenvolvimentoSimultaneo();
		this.praticaIntegracaoParalela = new PraticaIntegracaoParalela();
		this.praticaDocumentacaoDoDesenvolvimento = new PraticaDocumentacaoDoDesenvolvimento();
		this.praticaControleDeVersoes = new PraticaControleDeVersoes();
	}

	/* (non-Javadoc)
	 * @see br.ufsc.fcama.etapa.Etapa#isRequisitosCompletos()
	 */
	public boolean isRequisitosCompletos() {
		if (this.praticaImplementacao.isSelecionada()){
			return true;
		}else {
			return false;
		}
	}

	/* (non-Javadoc)
	 * @see br.ufsc.fcama.etapa.Etapa#incluindaExcluindoAtividade(java.lang.Class, java.lang.String)
	 */
	public void incluindoExcluindoPratica(Class classPratica, String operacao) throws ExceptionPraticaNaoLiberada,  ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida {
		try{
			this.praticaImplementacao.confereDependencia(classPratica, operacao);
			this.praticaEscritaDosTestesAntesDaImplementacao.confereDependencia(classPratica, operacao);
			this.praticaDesenvolvimentoColetivo.confereDependencia(classPratica, operacao);
			this.praticaDesenvolvimentoEmDuplas.confereDependencia(classPratica, operacao);
			this.praticaDesenvolvimentoLadoALado.confereDependencia(classPratica, operacao);
			this.praticaRefactoring.confereDependencia(classPratica, operacao);
			this.praticaReunioesDiarias.confereDependencia(classPratica, operacao);
			this.praticaDesenvolvimentoSimultaneo.confereDependencia(classPratica, operacao);
			this.praticaIntegracaoParalela.confereDependencia(classPratica, operacao);
			this.praticaDocumentacaoDoDesenvolvimento.confereDependencia(classPratica, operacao);
			this.praticaControleDeVersoes.confereDependencia(classPratica, operacao);
			//Confere se  uma das atividade da etapa, caso sim manda selecionara ou tirar a seleo
			this.selecionarPratica(classPratica, operacao);
		//Quando captura uma exceo realiza o operao inversa da que estava realizando
		//para deixar no mesmo estado as atividade
		}catch(ExceptionInclusaoPraticaNaoPermitida ei){
			this.desfazAlteracaoInclusao(classPratica, ei);
			throw ei;
		}catch(ExceptionExclusaoPraticaNaoPermitida ee){
			this.desfazAlteracaoExclusao(classPratica, ee);
			throw ee;
		}
	}

	/**
	 * Desfaz as alteraes realizadas na incluso de uma atividade caso ocorra uma exceo
	 * @param classPratica
	 * @param operacao
	 * @param ei
	 * @throws ExceptionInclusaoPraticaNaoPermitida
	 * @throws ExceptionExclusaoPraticaNaoPermitida
	 */
	private void desfazAlteracaoInclusao(Class classPratica, ExceptionInclusaoPraticaNaoPermitida ei)throws ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida{
		//como AtividadeImplementacao  a primeira no precisa fazer nada caso ela lance uma exception
		if(ei.getClassPratica() == PraticaEscritaDosTestesAntesDaImplementacao.class){
			this.praticaImplementacao.confereDependencia(classPratica, Constantes.EXCLUSAO);
		}else if(ei.getClassPratica() == PraticaEscritaDosTestesAntesDaImplementacao.class){
			this.praticaImplementacao.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaEscritaDosTestesAntesDaImplementacao.confereDependencia(classPratica, Constantes.EXCLUSAO);
		}else if(ei.getClassPratica() == PraticaDesenvolvimentoEmDuplas.class){
			this.praticaImplementacao.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaEscritaDosTestesAntesDaImplementacao.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaEscritaDosTestesAntesDaImplementacao.confereDependencia(classPratica, Constantes.EXCLUSAO);
		}else if(ei.getClassPratica() == PraticaDesenvolvimentoLadoALado.class){
			this.praticaImplementacao.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaEscritaDosTestesAntesDaImplementacao.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaEscritaDosTestesAntesDaImplementacao.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaDesenvolvimentoEmDuplas.confereDependencia(classPratica, Constantes.EXCLUSAO);
		}else if(ei.getClassPratica() == PraticaRefactoring.class){
			this.praticaImplementacao.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaEscritaDosTestesAntesDaImplementacao.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaEscritaDosTestesAntesDaImplementacao.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaDesenvolvimentoEmDuplas.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaDesenvolvimentoLadoALado.confereDependencia(classPratica, Constantes.EXCLUSAO);
		}else if(ei.getClassPratica() == PraticaReunioesDiarias.class){
			this.praticaImplementacao.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaEscritaDosTestesAntesDaImplementacao.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaEscritaDosTestesAntesDaImplementacao.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaDesenvolvimentoEmDuplas.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaDesenvolvimentoLadoALado.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaRefactoring.confereDependencia(classPratica, Constantes.EXCLUSAO);
		}else if(ei.getClassPratica() == PraticaDesenvolvimentoSimultaneo.class){
			this.praticaImplementacao.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaEscritaDosTestesAntesDaImplementacao.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaEscritaDosTestesAntesDaImplementacao.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaDesenvolvimentoEmDuplas.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaDesenvolvimentoLadoALado.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaRefactoring.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaReunioesDiarias.confereDependencia(classPratica, Constantes.EXCLUSAO);
		}else if(ei.getClassPratica() == PraticaIntegracaoParalela.class){
			this.praticaImplementacao.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaEscritaDosTestesAntesDaImplementacao.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaEscritaDosTestesAntesDaImplementacao.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaDesenvolvimentoEmDuplas.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaDesenvolvimentoLadoALado.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaRefactoring.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaReunioesDiarias.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaDesenvolvimentoSimultaneo.confereDependencia(classPratica, Constantes.EXCLUSAO);
		}else if(ei.getClassPratica() == PraticaDocumentacaoDoDesenvolvimento.class){
			this.praticaImplementacao.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaEscritaDosTestesAntesDaImplementacao.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaEscritaDosTestesAntesDaImplementacao.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaDesenvolvimentoEmDuplas.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaDesenvolvimentoLadoALado.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaRefactoring.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaReunioesDiarias.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaDesenvolvimentoSimultaneo.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaIntegracaoParalela.confereDependencia(classPratica, Constantes.EXCLUSAO);
		}else if(ei.getClassPratica() == PraticaControleDeVersoes.class){
			this.praticaImplementacao.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaEscritaDosTestesAntesDaImplementacao.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaEscritaDosTestesAntesDaImplementacao.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaDesenvolvimentoEmDuplas.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaDesenvolvimentoLadoALado.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaRefactoring.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaReunioesDiarias.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaDesenvolvimentoSimultaneo.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaIntegracaoParalela.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaDocumentacaoDoDesenvolvimento.confereDependencia(classPratica, Constantes.EXCLUSAO);
		}
	}
	/**
	 * Desfaz as alteraes realizadas na excluso de uma atividade caso ocorra uma exceo
	 * @param classPratica
	 * @param operacao
	 * @param ee
	 * @throws ExceptionInclusaoPraticaNaoPermitida
	 * @throws ExceptionExclusaoPraticaNaoPermitida
	 */
	private void desfazAlteracaoExclusao(Class classPratica, ExceptionExclusaoPraticaNaoPermitida ee)throws ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida{
		//como AtividadeImplementacao  a primeira no precisa fazer nada caso ela lance uma exception
		if(ee.getClassPratica() == PraticaEscritaDosTestesAntesDaImplementacao.class){
			this.praticaImplementacao.confereDependencia(classPratica, Constantes.INCLUSAO);
		}else if(ee.getClassPratica() == PraticaEscritaDosTestesAntesDaImplementacao.class){
			this.praticaImplementacao.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaEscritaDosTestesAntesDaImplementacao.confereDependencia(classPratica, Constantes.INCLUSAO);
		}else if(ee.getClassPratica() == PraticaDesenvolvimentoEmDuplas.class){
			this.praticaImplementacao.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaEscritaDosTestesAntesDaImplementacao.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaEscritaDosTestesAntesDaImplementacao.confereDependencia(classPratica, Constantes.INCLUSAO);
		}else if(ee.getClassPratica() == PraticaDesenvolvimentoLadoALado.class){
			this.praticaImplementacao.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaEscritaDosTestesAntesDaImplementacao.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaEscritaDosTestesAntesDaImplementacao.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaDesenvolvimentoEmDuplas.confereDependencia(classPratica, Constantes.INCLUSAO);
		}else if(ee.getClassPratica() == PraticaRefactoring.class){
			this.praticaImplementacao.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaEscritaDosTestesAntesDaImplementacao.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaEscritaDosTestesAntesDaImplementacao.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaDesenvolvimentoEmDuplas.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaDesenvolvimentoLadoALado.confereDependencia(classPratica, Constantes.INCLUSAO);
		}else if(ee.getClassPratica() == PraticaReunioesDiarias.class){
			this.praticaImplementacao.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaEscritaDosTestesAntesDaImplementacao.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaEscritaDosTestesAntesDaImplementacao.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaDesenvolvimentoEmDuplas.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaDesenvolvimentoLadoALado.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaRefactoring.confereDependencia(classPratica, Constantes.INCLUSAO);
		}else if(ee.getClassPratica() == PraticaDesenvolvimentoSimultaneo.class){
			this.praticaImplementacao.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaEscritaDosTestesAntesDaImplementacao.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaEscritaDosTestesAntesDaImplementacao.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaDesenvolvimentoEmDuplas.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaDesenvolvimentoLadoALado.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaRefactoring.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaReunioesDiarias.confereDependencia(classPratica, Constantes.INCLUSAO);
		}else if(ee.getClassPratica() == PraticaIntegracaoParalela.class){
			this.praticaImplementacao.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaEscritaDosTestesAntesDaImplementacao.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaEscritaDosTestesAntesDaImplementacao.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaDesenvolvimentoEmDuplas.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaDesenvolvimentoLadoALado.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaRefactoring.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaReunioesDiarias.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaDesenvolvimentoSimultaneo.confereDependencia(classPratica, Constantes.INCLUSAO);
		}else if(ee.getClassPratica() == PraticaDocumentacaoDoDesenvolvimento.class){
			this.praticaImplementacao.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaEscritaDosTestesAntesDaImplementacao.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaEscritaDosTestesAntesDaImplementacao.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaDesenvolvimentoEmDuplas.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaDesenvolvimentoLadoALado.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaRefactoring.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaReunioesDiarias.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaDesenvolvimentoSimultaneo.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaIntegracaoParalela.confereDependencia(classPratica, Constantes.INCLUSAO);
		}else if(ee.getClassPratica() == PraticaControleDeVersoes.class){
			this.praticaImplementacao.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaEscritaDosTestesAntesDaImplementacao.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaEscritaDosTestesAntesDaImplementacao.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaDesenvolvimentoEmDuplas.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaDesenvolvimentoLadoALado.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaRefactoring.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaReunioesDiarias.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaDesenvolvimentoSimultaneo.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaIntegracaoParalela.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaDocumentacaoDoDesenvolvimento.confereDependencia(classPratica, Constantes.INCLUSAO);
		}
	}

	/**
	 * Confere se a atividade faz parte da etapa se sim  tenta selecionar ou liberar
	 * caso no possa selecionar lana uma exceo e arruma o estado da atividades
	 * @param classPratica
	 * @param operacao
	 * @throws ExceptionPraticaNaoLiberada
	 * @throws ExceptionInclusaoPraticaNaoPermitida
	 * @throws ExceptionExclusaoPraticaNaoPermitida
	 */
	private void selecionarPratica(Class classPratica, String operacao)throws ExceptionPraticaNaoLiberada, ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida{
		try{
			if (classPratica == PraticaImplementacao.class
					||classPratica == PraticaEscritaDosTestesAntesDaImplementacao.class
					||classPratica == PraticaDesenvolvimentoColetivo.class
					||classPratica == PraticaDesenvolvimentoEmDuplas.class
					||classPratica == PraticaDesenvolvimentoLadoALado.class
					||classPratica == PraticaRefactoring.class
					||classPratica == PraticaReunioesDiarias.class
					||classPratica == PraticaDesenvolvimentoSimultaneo.class
					||classPratica == PraticaIntegracaoParalela.class
					||classPratica == PraticaDocumentacaoDoDesenvolvimento.class
					||classPratica == PraticaControleDeVersoes.class){
				Pratica atividade;
				atividade = this.getPratica(classPratica);
				if (operacao.equalsIgnoreCase(Constantes.EXCLUSAO)){
					atividade.tiraSelecao();
				}else{// se no  incluso
					atividade.selecionar();
				}
			}
		}catch(ExceptionPraticaNaoLiberada el){
			if (operacao.equalsIgnoreCase(Constantes.EXCLUSAO)){
				this.desfazAlteracaoExclusao(classPratica,
						new ExceptionExclusaoPraticaNaoPermitida(PraticaControleDeVersoes.class));
				//tem que desfazer agora a AtividadeControleDeVersoes, pois o mtodo anterior no desfaz a ltima
				this.praticaControleDeVersoes.confereDependencia(classPratica, Constantes.INCLUSAO);
			}else{// se no  incluso
				this.desfazAlteracaoInclusao(classPratica,
						new ExceptionInclusaoPraticaNaoPermitida(PraticaControleDeVersoes.class));
				//tem que desfazer agora a AtividadeControleDeVersoes, pois o mtodo anterior no desfaz a ltima
				this.praticaControleDeVersoes.confereDependencia(classPratica, Constantes.EXCLUSAO);
			}
			throw el;
		} catch (ExceptionPraticaNaoPertenceAEtapa e) {
			//Nunca vai ser lanada essa exceo pq j confere antes da execuo
		}
	}


	/* (non-Javadoc)
	 * @see br.ufsc.fcama.etapa.Etapa#getAtividade(java.lang.Class)
	 */
	public Pratica getPratica(Class classPratica) throws ExceptionPraticaNaoPertenceAEtapa {
		if (classPratica == PraticaImplementacao.class){
			return this.praticaImplementacao;
		}else if(classPratica == PraticaEscritaDosTestesAntesDaImplementacao.class){
			return this.praticaEscritaDosTestesAntesDaImplementacao;
		}else if(classPratica == PraticaEscritaDosTestesAntesDaImplementacao.class){
			return this.praticaEscritaDosTestesAntesDaImplementacao;
		}else if(classPratica == PraticaDesenvolvimentoEmDuplas.class){
			return this.praticaDesenvolvimentoEmDuplas;
		}else if(classPratica == PraticaDesenvolvimentoLadoALado.class){
			return this.praticaDesenvolvimentoLadoALado;
		}else if(classPratica == PraticaRefactoring.class){
			return this.praticaRefactoring;
		}else if(classPratica == PraticaReunioesDiarias.class){
			return this.praticaReunioesDiarias;
		}else if(classPratica == PraticaDesenvolvimentoSimultaneo.class){
			return this.praticaDesenvolvimentoSimultaneo;
		}else if(classPratica == PraticaIntegracaoParalela.class){
			return this.praticaIntegracaoParalela;
		}else if(classPratica == PraticaDocumentacaoDoDesenvolvimento.class){
			return this.praticaDocumentacaoDoDesenvolvimento;
		}else if(classPratica == PraticaControleDeVersoes.class){
			return this.praticaControleDeVersoes;
		}else {
			throw new ExceptionPraticaNaoPertenceAEtapa(classPratica, AtividadeDesenvolverIncrementoDoSistema.class );
		}
	}

	/**
	 * @return Returns the atividadeControleDeVersoes.
	 */
	public PraticaControleDeVersoes getPraticaControleDeVersoes() {
		return praticaControleDeVersoes;
	}
	/**
	 * @return Returns the atividadeDesenvolvimentoColetivo.
	 */
	public PraticaDesenvolvimentoColetivo getPraticaDesenvolvimentoColetivo() {
		return praticaDesenvolvimentoColetivo;
	}
	/**
	 * @return Returns the atividadeDesenvolvimentoEmDuplas.
	 */
	public PraticaDesenvolvimentoEmDuplas getPraticaDesenvolvimentoEmDuplas() {
		return praticaDesenvolvimentoEmDuplas;
	}
	/**
	 * @return Returns the atividadeDesenvolvimentoLadoALado.
	 */
	public PraticaDesenvolvimentoLadoALado getPraticaDesenvolvimentoLadoALado() {
		return praticaDesenvolvimentoLadoALado;
	}
	/**
	 * @return Returns the atividadeDesenvolvimentoSimultaneo.
	 */
	public PraticaDesenvolvimentoSimultaneo getPraticaDesenvolvimentoSimultaneo() {
		return praticaDesenvolvimentoSimultaneo;
	}
	/**
	 * @return Returns the atividadeDocumentacaoDoDesenvolvimento.
	 */
	public PraticaDocumentacaoDoDesenvolvimento getPraticaDocumentacaoDoDesenvolvimento() {
		return praticaDocumentacaoDoDesenvolvimento;
	}
	/**
	 * @return Returns the atividadeEscritaDosTestesAntesDaImplementacao.
	 */
	public PraticaEscritaDosTestesAntesDaImplementacao getPraticaEscritaDosTestesAntesDaImplementacao() {
		return praticaEscritaDosTestesAntesDaImplementacao;
	}
	/**
	 * @return Returns the atividadeImplementacao.
	 */
	public PraticaImplementacao getPraticaImplementacao() {
		return praticaImplementacao;
	}
	/**
	 * @return Returns the atividadeIntegracaoParalela.
	 */
	public PraticaIntegracaoParalela getPraticaIntegracaoParalela() {
		return praticaIntegracaoParalela;
	}
	/**
	 * @return Returns the atividadeRefactoring.
	 */
	public PraticaRefactoring getPraticaRefactoring() {
		return praticaRefactoring;
	}
	/**
	 * @return Returns the atividadeReunioesDiarias.
	 */
	public PraticaReunioesDiarias getPraticaReunioesDiarias() {
		return praticaReunioesDiarias;
	}

	/**
	 * @param atividadeControleDeVersoes The atividadeControleDeVersoes to set.
	 */
	protected void setPraticaControleDeVersoes(
			PraticaControleDeVersoes atividadeControleDeVersoes) {
		this.praticaControleDeVersoes = atividadeControleDeVersoes;
	}
	/**
	 * @param atividadeDesenvolvimentoColetivo The atividadeDesenvolvimentoColetivo to set.
	 */
	protected void setPraticaDesenvolvimentoColetivo(
			PraticaDesenvolvimentoColetivo atividadeDesenvolvimentoColetivo) {
		this.praticaDesenvolvimentoColetivo = atividadeDesenvolvimentoColetivo;
	}
	/**
	 * @param atividadeDesenvolvimentoEmDuplas The atividadeDesenvolvimentoEmDuplas to set.
	 */
	protected void setPraticaDesenvolvimentoEmDuplas(
			PraticaDesenvolvimentoEmDuplas atividadeDesenvolvimentoEmDuplas) {
		this.praticaDesenvolvimentoEmDuplas = atividadeDesenvolvimentoEmDuplas;
	}
	/**
	 * @param atividadeDesenvolvimentoLadoALado The atividadeDesenvolvimentoLadoALado to set.
	 */
	protected void setPraticaDesenvolvimentoLadoALado(
			PraticaDesenvolvimentoLadoALado atividadeDesenvolvimentoLadoALado) {
		this.praticaDesenvolvimentoLadoALado = atividadeDesenvolvimentoLadoALado;
	}
	/**
	 * @param atividadeDesenvolvimentoSimultaneo The atividadeDesenvolvimentoSimultaneo to set.
	 */
	protected void setPraticaDesenvolvimentoSimultaneo(
			PraticaDesenvolvimentoSimultaneo atividadeDesenvolvimentoSimultaneo) {
		this.praticaDesenvolvimentoSimultaneo = atividadeDesenvolvimentoSimultaneo;
	}
	/**
	 * @param atividadeDocumentacaoDoDesenvolvimento The atividadeDocumentacaoDoDesenvolvimento to set.
	 */
	protected void setPraticaDocumentacaoDoDesenvolvimento(
			PraticaDocumentacaoDoDesenvolvimento atividadeDocumentacaoDoDesenvolvimento) {
		this.praticaDocumentacaoDoDesenvolvimento = atividadeDocumentacaoDoDesenvolvimento;
	}
	/**
	 * @param atividadeEscritaDosTestesAntesDaImplementacao The atividadeEscritaDosTestesAntesDaImplementacao to set.
	 */
	protected void setPraticaEscritaDosTestesAntesDaImplementacao(
			PraticaEscritaDosTestesAntesDaImplementacao atividadeEscritaDosTestesAntesDaImplementacao) {
		this.praticaEscritaDosTestesAntesDaImplementacao = atividadeEscritaDosTestesAntesDaImplementacao;
	}
	/**
	 * @param atividadeImplementacao The atividadeImplementacao to set.
	 */
	protected void setPraticaImplementacao(
			PraticaImplementacao atividadeImplementacao) {
		this.praticaImplementacao = atividadeImplementacao;
	}
	/**
	 * @param atividadeIntegracaoParalela The atividadeIntegracaoParalela to set.
	 */
	protected void setPraticaIntegracaoParalela(
			PraticaIntegracaoParalela atividadeIntegracaoParalela) {
		this.praticaIntegracaoParalela = atividadeIntegracaoParalela;
	}
	/**
	 * @param atividadeRefactoring The atividadeRefactoring to set.
	 */
	protected void setPraticaRefactoring(
			PraticaRefactoring atividadeRefactoring) {
		this.praticaRefactoring = atividadeRefactoring;
	}
	/**
	 * @param atividadeReunioesDiarias The atividadeReunioesDiarias to set.
	 */
	protected void setPraticaReunioesDiarias(
			PraticaReunioesDiarias atividadeReunioesDiarias) {
		this.praticaReunioesDiarias = atividadeReunioesDiarias;
	}

	public AtividadeDesenvolverIncrementoDoSistema copiaAtividade(){
		AtividadeDesenvolverIncrementoDoSistema atividade = new AtividadeDesenvolverIncrementoDoSistema();
		atividade.setPraticaImplementacao((PraticaImplementacao)
				this.praticaImplementacao.copiaAtividade(new PraticaImplementacao()));
		atividade.setPraticaEscritaDosTestesAntesDaImplementacao((PraticaEscritaDosTestesAntesDaImplementacao)
				this.praticaEscritaDosTestesAntesDaImplementacao.copiaAtividade(new PraticaEscritaDosTestesAntesDaImplementacao()));
		atividade.setPraticaDesenvolvimentoColetivo((PraticaDesenvolvimentoColetivo)
				this.praticaDesenvolvimentoColetivo.copiaAtividade(new PraticaDesenvolvimentoColetivo()));
		atividade.setPraticaDesenvolvimentoEmDuplas((PraticaDesenvolvimentoEmDuplas)
				this.praticaDesenvolvimentoEmDuplas.copiaAtividade(new PraticaDesenvolvimentoEmDuplas()));
		atividade.setPraticaDesenvolvimentoLadoALado((PraticaDesenvolvimentoLadoALado)
				this.praticaDesenvolvimentoLadoALado.copiaAtividade(new PraticaDesenvolvimentoLadoALado()));
		atividade.setPraticaRefactoring((PraticaRefactoring)
				this.praticaRefactoring.copiaAtividade(new PraticaRefactoring()));
		atividade.setPraticaReunioesDiarias((PraticaReunioesDiarias)
				this.praticaReunioesDiarias.copiaAtividade(new PraticaReunioesDiarias()));
		atividade.setPraticaDesenvolvimentoSimultaneo((PraticaDesenvolvimentoSimultaneo)
				this.praticaDesenvolvimentoSimultaneo.copiaAtividade(new PraticaDesenvolvimentoSimultaneo()));
		atividade.setPraticaIntegracaoParalela((PraticaIntegracaoParalela)
				this.praticaIntegracaoParalela.copiaAtividade(new PraticaIntegracaoParalela()));
		atividade.setPraticaDocumentacaoDoDesenvolvimento((PraticaDocumentacaoDoDesenvolvimento)
				this.praticaDocumentacaoDoDesenvolvimento.copiaAtividade(new PraticaDocumentacaoDoDesenvolvimento()));
		atividade.setPraticaControleDeVersoes((PraticaControleDeVersoes)
				this.praticaControleDeVersoes.copiaAtividade(new PraticaControleDeVersoes()));
		return atividade;
	}

        public String toString(){
        	return PropertyResourceBundle
    		.getBundle("br.ufsc.fcama.internacionalizacao.ProgramProperties")
    			.getString("br.ufsc.fcama.logica.atividade.DesenvolverIncrementoDoSistema");
        }

}
