/*
 * Created on 23/08/2005
 *
 */
package br.ufsc.fcama.logica.atividade;

import java.util.PropertyResourceBundle;

import br.ufsc.fcama.exception.ExceptionPraticaNaoLiberada;
import br.ufsc.fcama.exception.ExceptionPraticaNaoPertenceAEtapa;
import br.ufsc.fcama.exception.ExceptionExclusaoPraticaNaoPermitida;
import br.ufsc.fcama.exception.ExceptionInclusaoPraticaNaoPermitida;
import br.ufsc.fcama.logica.objAux.Constantes;
import br.ufsc.fcama.logica.pratica.Pratica;
import br.ufsc.fcama.logica.pratica.PraticaBreveDocumentacao;
import br.ufsc.fcama.logica.pratica.PraticaElaboracaoDoManual;
import br.ufsc.fcama.logica.pratica.PraticaEntregaDoSistema;
import br.ufsc.fcama.logica.pratica.PraticaRefinamentoDaDocumentacao;

/**
 * @author Thiago Leo Machado
 */
public class AtividadeEntregaFinal extends Atividade {

	//Atividade obrigatria
	private PraticaEntregaDoSistema praticaEntregaDoSistema;
	//Atividades optativas
	private PraticaBreveDocumentacao praticaBreveDocumentacao;
	private PraticaRefinamentoDaDocumentacao praticaRefinamentoDaDocumentacao;
	private PraticaElaboracaoDoManual atividadeElaboracaoDoManual;

	public AtividadeEntregaFinal(){
		super();
		this.praticaEntregaDoSistema = new PraticaEntregaDoSistema();
		this.praticaBreveDocumentacao = new PraticaBreveDocumentacao();
		this.praticaRefinamentoDaDocumentacao = new PraticaRefinamentoDaDocumentacao();
		this.atividadeElaboracaoDoManual = new PraticaElaboracaoDoManual();
	}

	/* (non-Javadoc)
	 * @see br.ufsc.fcama.etapa.Etapa#isRequisitosCompletos()
	 */
	public boolean isRequisitosCompletos() {
		if (this.praticaEntregaDoSistema.isSelecionada()){
			return true;
		}else {
			return false;
		}
	}

	/* (non-Javadoc)
	 * @see br.ufsc.fcama.etapa.Etapa#incluindaExcluindoAtividade(java.lang.Class, java.lang.String)
	 */
	public void incluindoExcluindoPratica(Class classPratica, String operacao) throws ExceptionPraticaNaoLiberada,  ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida {
		try{
			this.praticaEntregaDoSistema.confereDependencia(classPratica, operacao);
			this.praticaBreveDocumentacao.confereDependencia(classPratica, operacao);
			this.praticaRefinamentoDaDocumentacao.confereDependencia(classPratica, operacao);
			this.atividadeElaboracaoDoManual.confereDependencia(classPratica, operacao);
			//Confere se  uma das atividade da etapa, caso sim manda selecionara ou tirar a seleo
			this.selecionarPratica(classPratica, operacao);
		//Quando captura uma exceo realiza o operao inversa da que estava realizando
		//para deixar no mesmo estado as atividade
		}catch(ExceptionInclusaoPraticaNaoPermitida ei){
			this.desfazAlteracaoInclusao(classPratica, ei);
			throw ei;
		}catch(ExceptionExclusaoPraticaNaoPermitida ee){
			this.desfazAlteracaoExclusao(classPratica, ee);
			throw ee;
		}
	}

	/**
	 * Desfaz as alteraes realizadas na incluso de uma atividade caso ocorra uma exceo
	 * @param classPratica
	 * @param operacao
	 * @param ei
	 * @throws ExceptionInclusaoPraticaNaoPermitida
	 * @throws ExceptionExclusaoPraticaNaoPermitida
	 */
	private void desfazAlteracaoInclusao(Class classPratica, ExceptionInclusaoPraticaNaoPermitida ei)throws ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida{
		//como AtividadeEntregaDoSistema  a primeira no precisa fazer nada caso ela lance uma exception
		if (ei.getClassPratica() == PraticaBreveDocumentacao.class){
			this.praticaEntregaDoSistema.confereDependencia(classPratica, Constantes.EXCLUSAO);
		}else if (ei.getClassPratica() == PraticaRefinamentoDaDocumentacao.class){
			this.praticaEntregaDoSistema.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaBreveDocumentacao.confereDependencia(classPratica, Constantes.EXCLUSAO);
		}else if (ei.getClassPratica() == PraticaElaboracaoDoManual.class){
			this.praticaEntregaDoSistema.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaBreveDocumentacao.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.atividadeElaboracaoDoManual.confereDependencia(classPratica, Constantes.EXCLUSAO);
		}
	}
	/**
	 * Desfaz as alteraes realizadas na excluso de uma atividade caso ocorra uma exceo
	 * @param classPratica
	 * @param operacao
	 * @param ee
	 * @throws ExceptionInclusaoPraticaNaoPermitida
	 * @throws ExceptionExclusaoPraticaNaoPermitida
	 */
	private void desfazAlteracaoExclusao(Class classPratica, ExceptionExclusaoPraticaNaoPermitida ee)throws ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida{
		//como AtividadeEntregaDoSistema  a primeira no precisa fazer nada caso ela lance uma exception
		if (ee.getClassPratica() == PraticaBreveDocumentacao.class){
			this.praticaEntregaDoSistema.confereDependencia(classPratica, Constantes.INCLUSAO);
		}else if (ee.getClassPratica() == PraticaRefinamentoDaDocumentacao.class){
			this.praticaEntregaDoSistema.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaBreveDocumentacao.confereDependencia(classPratica, Constantes.INCLUSAO);
		}else if (ee.getClassPratica() == PraticaElaboracaoDoManual.class){
			this.praticaEntregaDoSistema.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaBreveDocumentacao.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.atividadeElaboracaoDoManual.confereDependencia(classPratica, Constantes.INCLUSAO);
		}
	}

	/**
	 * Confere se a atividade faz parte da etapa se sim  tenta selecionar ou liberar
	 * caso no possa selecionar lana uma exceo e arruma o estado da atividades
	 * @param classPratica
	 * @param operacao
	 * @throws ExceptionPraticaNaoLiberada
	 * @throws ExceptionInclusaoPraticaNaoPermitida
	 * @throws ExceptionExclusaoPraticaNaoPermitida
	 */
	private void selecionarPratica(Class classPratica, String operacao)throws ExceptionPraticaNaoLiberada, ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida{
		try{
			if (classPratica == PraticaEntregaDoSistema.class
					||classPratica == PraticaBreveDocumentacao.class
					||classPratica == PraticaRefinamentoDaDocumentacao.class
					||classPratica == PraticaElaboracaoDoManual.class){
				Pratica atividade;
				atividade = this.getPratica(classPratica);
				if (operacao.equalsIgnoreCase(Constantes.EXCLUSAO)){
					atividade.tiraSelecao();
				}else{// se no  incluso
					atividade.selecionar();
				}
			}
		}catch(ExceptionPraticaNaoLiberada el){
			if (operacao.equalsIgnoreCase(Constantes.EXCLUSAO)){
				this.desfazAlteracaoExclusao(classPratica,
						new ExceptionExclusaoPraticaNaoPermitida(PraticaElaboracaoDoManual.class));
				//tem que desfazer agora a AtividadeElaboracaoDoManual, pois o mtodo anterior no desfaz a ltima
				this.atividadeElaboracaoDoManual.confereDependencia(classPratica, Constantes.INCLUSAO);
			}else{// se no  incluso
				this.desfazAlteracaoInclusao(classPratica,
						new ExceptionInclusaoPraticaNaoPermitida(PraticaElaboracaoDoManual.class));
				//tem que desfazer agora a AtividadeElaboracaoDoManual, pois o mtodo anterior no desfaz a ltima
				this.atividadeElaboracaoDoManual.confereDependencia(classPratica, Constantes.EXCLUSAO);
			}
			throw el;
		} catch (ExceptionPraticaNaoPertenceAEtapa e) {
			//Nunca vai ser lanada essa exceo pq j confere antes da execuo
		}
	}

	/* (non-Javadoc)
	 * @see br.ufsc.fcama.etapa.Etapa#getAtividade(java.lang.Class)
	 */
	public Pratica getPratica(Class classPratica) throws ExceptionPraticaNaoPertenceAEtapa {
		if (classPratica == PraticaEntregaDoSistema.class){
			return this.praticaEntregaDoSistema;
		}else if (classPratica == PraticaBreveDocumentacao.class){
			return this.praticaBreveDocumentacao;
		}else if (classPratica == PraticaRefinamentoDaDocumentacao.class){
			return this.praticaRefinamentoDaDocumentacao;
		}else if (classPratica == PraticaElaboracaoDoManual.class){
			return this.atividadeElaboracaoDoManual;
		}else{
			throw new ExceptionPraticaNaoPertenceAEtapa(classPratica, AtividadeEntregaFinal.class);
		}
	}

	/**
	 * @return Returns the atividadeBreveDocumentacao.
	 */
	public PraticaBreveDocumentacao getPraticaBreveDocumentacao() {
		return praticaBreveDocumentacao;
	}
	/**
	 * @return Returns the atividadeElaboracaoDoManual.
	 */
	public PraticaElaboracaoDoManual getPraticaElaboracaoDoManual() {
		return atividadeElaboracaoDoManual;
	}
	/**
	 * @return Returns the atividadeEntregaDoSistema.
	 */
	public PraticaEntregaDoSistema getPraticaEntregaDoSistema() {
		return praticaEntregaDoSistema;
	}
	/**
	 * @return Returns the atividadeRefinamentoDaDocumentacao.
	 */
	public PraticaRefinamentoDaDocumentacao getPraticaRefinamentoDaDocumentacao() {
		return praticaRefinamentoDaDocumentacao;
	}

        public String toString(){
        	return PropertyResourceBundle
    		.getBundle("br.ufsc.fcama.internacionalizacao.ProgramProperties")
    			.getString("br.ufsc.fcama.logica.atividade.EntregaFinal");
        }
}
