/*
 * Created on 23/08/2005
 *
 */
package br.ufsc.fcama.logica.atividade;

import java.util.PropertyResourceBundle;
import java.util.ResourceBundle;

import br.ufsc.fcama.exception.ExceptionPraticaNaoLiberada;
import br.ufsc.fcama.exception.ExceptionPraticaNaoPertenceAEtapa;
import br.ufsc.fcama.exception.ExceptionExclusaoPraticaNaoPermitida;
import br.ufsc.fcama.exception.ExceptionInclusaoPraticaNaoPermitida;
import br.ufsc.fcama.logica.objAux.Constantes;
import br.ufsc.fcama.logica.pratica.Pratica;
import br.ufsc.fcama.logica.pratica.PraticaDocumentacaoDoProjeto;
import br.ufsc.fcama.logica.pratica.PraticaProjetoDetalhado;
import br.ufsc.fcama.logica.pratica.PraticaProjetoGeral;

/**
 * @author Thiago Leo Machado
 */
public class AtividadeProjetoDoSistema extends Atividade{

	//Atividade obrigatria
	private PraticaProjetoGeral praticaProjetoGeral;
	//Atividades opcionais
	private PraticaProjetoDetalhado praticaProjetoDetalhado;
	private PraticaDocumentacaoDoProjeto praticaDocumentacaoDoProjeto;

	public AtividadeProjetoDoSistema(){
		super();
		this.praticaProjetoGeral = new PraticaProjetoGeral();
		this.praticaProjetoDetalhado = new PraticaProjetoDetalhado();
		this.praticaDocumentacaoDoProjeto = new PraticaDocumentacaoDoProjeto();
	}

	/* (non-Javadoc)
	 * @see br.ufsc.fcama.etapa.Etapa#isRequisitosCompletos()
	 */
	public boolean isRequisitosCompletos() {
		if (this.praticaProjetoGeral.isSelecionada()){
			return true;
		}else{
			return false;
		}
	}

	/* (non-Javadoc)
	 * @see br.ufsc.fcama.etapa.Etapa#incluindaExcluindoAtividade(java.lang.Class, java.lang.String)
	 */
	public void incluindoExcluindoPratica(Class classPratica, String operacao) throws ExceptionPraticaNaoLiberada,  ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida {
		try{
			this.praticaProjetoGeral.confereDependencia(classPratica, operacao);
			this.praticaProjetoDetalhado.confereDependencia(classPratica, operacao);
			this.praticaDocumentacaoDoProjeto.confereDependencia(classPratica, operacao);
			//Confere se  uma das atividade da etapa, caso sim manda selecionara ou tirar a seleo
			this.selecionarAtividade(classPratica, operacao);
		//Quando captura uma exceo realiza o operao inversa da que estava realizando
		//para deixar no mesmo estado as atividade
		}catch(ExceptionInclusaoPraticaNaoPermitida ei){
			this.desfazAlteracaoInclusao(classPratica, ei);
			throw ei;
		}catch(ExceptionExclusaoPraticaNaoPermitida ee){
			this.desfazAlteracaoExclusao(classPratica, ee);
			throw ee;
		}
	}

	/**
	 * Desfaz as alteraes realizadas na incluso de uma atividade caso ocorra uma exceo
	 * @param classPratica
	 * @param operacao
	 * @param ei
	 * @throws ExceptionInclusaoPraticaNaoPermitida
	 * @throws ExceptionExclusaoPraticaNaoPermitida
	 */
	private void desfazAlteracaoInclusao(Class classPratica, ExceptionInclusaoPraticaNaoPermitida ei)throws ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida{
		//como AtividadeProtejoGeral  a primeira no precisa fazer nada caso ela lance uma exception
		if (ei.getClassPratica() == PraticaProjetoDetalhado.class){
			this.praticaProjetoGeral.confereDependencia(classPratica, Constantes.EXCLUSAO);
		}else if (ei.getClassPratica() == PraticaDocumentacaoDoProjeto.class){
			this.praticaProjetoGeral.confereDependencia(classPratica, Constantes.EXCLUSAO);
			this.praticaProjetoDetalhado.confereDependencia(classPratica, Constantes.EXCLUSAO);
		}
	}
	/**
	 * Desfaz as alteraes realizadas na excluso de uma atividade caso ocorra uma exceo
	 * @param classPratica
	 * @param operacao
	 * @param ee
	 * @throws ExceptionInclusaoPraticaNaoPermitida
	 * @throws ExceptionExclusaoPraticaNaoPermitida
	 */
	private void desfazAlteracaoExclusao(Class classPratica, ExceptionExclusaoPraticaNaoPermitida ee)throws ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida{
		//como AtividadeProtejoGeral  a primeira no precisa fazer nada caso ela lance uma exception
		if (ee.getClassPratica() == PraticaProjetoDetalhado.class){
			this.praticaProjetoGeral.confereDependencia(classPratica, Constantes.INCLUSAO);
		}else if (ee.getClassPratica() == PraticaDocumentacaoDoProjeto.class){
			this.praticaProjetoGeral.confereDependencia(classPratica, Constantes.INCLUSAO);
			this.praticaProjetoDetalhado.confereDependencia(classPratica, Constantes.INCLUSAO);
		}
	}

	/**
	 * Confere se a atividade faz parte da etapa se sim  tenta selecionar ou liberar
	 * caso no possa selecionar lana uma exceo e arruma o estado da atividades
	 * @param classPratica
	 * @param operacao
	 * @throws ExceptionPraticaNaoLiberada
	 * @throws ExceptionInclusaoPraticaNaoPermitida
	 * @throws ExceptionExclusaoPraticaNaoPermitida
	 */
	private void selecionarAtividade(Class classPratica, String operacao)throws ExceptionPraticaNaoLiberada, ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida{
		try{
			if (classPratica == PraticaProjetoGeral.class
					||classPratica == PraticaProjetoDetalhado.class
					||classPratica == PraticaDocumentacaoDoProjeto.class){
				Pratica atividade;
				atividade = this.getPratica(classPratica);
				if (operacao.equalsIgnoreCase(Constantes.EXCLUSAO)){
					atividade.tiraSelecao();
				}else{// se no  incluso
					atividade.selecionar();
				}
			}
		}catch(ExceptionPraticaNaoLiberada el){
			if (operacao.equalsIgnoreCase(Constantes.EXCLUSAO)){
				this.desfazAlteracaoExclusao(classPratica,
						new ExceptionExclusaoPraticaNaoPermitida(PraticaDocumentacaoDoProjeto.class));
				//tem que desfazer agora a AtividadeDocumentacaoDoProjeto, pois o mtodo anterior no desfaz a ltima
				this.praticaDocumentacaoDoProjeto.confereDependencia(classPratica, Constantes.INCLUSAO);
			}else{// se no  incluso
				this.desfazAlteracaoInclusao(classPratica,
						new ExceptionInclusaoPraticaNaoPermitida(PraticaDocumentacaoDoProjeto.class));
				//tem que desfazer agora a AtividadeColocarSistemaEmOperacao, pois o mtodo anterior no desfaz a ltima
				this.praticaDocumentacaoDoProjeto.confereDependencia(classPratica, Constantes.EXCLUSAO);

			}
			throw el;
		} catch (ExceptionPraticaNaoPertenceAEtapa e) {
			//Nunca vai ser lanada essa exceo pq j confere antes da execuo
		}
	}


	/* (non-Javadoc)
	 * @see br.ufsc.fcama.etapa.Etapa#getAtividade(java.lang.Class)
	 */
	public Pratica getPratica(Class classPratica) throws ExceptionPraticaNaoPertenceAEtapa {
		if (classPratica == PraticaProjetoGeral.class){
			return this.praticaProjetoGeral;
		}else if (classPratica == PraticaProjetoDetalhado.class){
			return this.praticaProjetoDetalhado;
		}else if (classPratica == PraticaDocumentacaoDoProjeto.class){
			return this.praticaDocumentacaoDoProjeto;
		}else{
			throw new ExceptionPraticaNaoPertenceAEtapa(classPratica, AtividadeProjetoDoSistema.class);
		}
	}

		/**
	 * @return Returns the atividadeDocumentacaoDoProjeto.
	 */
	public PraticaDocumentacaoDoProjeto getPraticaDocumentacaoDoProjeto() {
		return praticaDocumentacaoDoProjeto;
	}
	/**
	 * @return Returns the atividadeProjetoDetalhado.
	 */
	public PraticaProjetoDetalhado getPraticaProjetoDetalhado() {
		return praticaProjetoDetalhado;
	}
	/**
	 * @return Returns the atividadeProjetoGeral.
	 */
	public PraticaProjetoGeral getPraticaProjetoGeral() {
		return praticaProjetoGeral;
	}

    public String toString(){
    	return PropertyResourceBundle
    		.getBundle("br.ufsc.fcama.internacionalizacao.ProgramProperties")
    			.getString("br.ufsc.fcama.logica.atividade.ProjetoDoSistema");
        
   }

}
