/*
 * Created on 23/08/2005
 *
 */
package br.ufsc.fcama.logica.atividade;

import java.util.PropertyResourceBundle;

import br.ufsc.fcama.exception.ExceptionPraticaNaoLiberada;
import br.ufsc.fcama.exception.ExceptionPraticaNaoPertenceAEtapa;
import br.ufsc.fcama.exception.ExceptionExclusaoPraticaNaoPermitida;
import br.ufsc.fcama.exception.ExceptionInclusaoPraticaNaoPermitida;
import br.ufsc.fcama.logica.objAux.Constantes;
import br.ufsc.fcama.logica.pratica.Pratica;
import br.ufsc.fcama.logica.pratica.PraticaExecucaoDosTestes;
import br.ufsc.fcama.logica.pratica.PraticaInspecaoDeCodigo;
import br.ufsc.fcama.logica.pratica.PraticaIntegracaoAntesDaValidacao;

/**
 * @author Thiago Leo Machado
 */
public class AtividadeValidarIncremento extends Atividade {

	//atividade obrigatria
	private PraticaExecucaoDosTestes praticaExecucaoDosTestes;
	//atividades optativas
	private PraticaIntegracaoAntesDaValidacao praticaIntegracaoAntesDaValidacao;
	private PraticaInspecaoDeCodigo praticaInspecaoDeCodigo;

	public AtividadeValidarIncremento(){
		super();
		this.praticaExecucaoDosTestes = new PraticaExecucaoDosTestes();
		this.praticaIntegracaoAntesDaValidacao = new PraticaIntegracaoAntesDaValidacao();
		this.praticaInspecaoDeCodigo = new PraticaInspecaoDeCodigo();
	}

	/* (non-Javadoc)
	 * @see br.ufsc.fcama.etapa.Etapa#isRequisitosCompletos()
	 */
	public boolean isRequisitosCompletos() {
		if (this.praticaExecucaoDosTestes.isSelecionada()){
			return true;
		}else{
			return false;
		}
	}

	/* (non-Javadoc)
	 * @see br.ufsc.fcama.etapa.Etapa#incluindaExcluindoAtividade(java.lang.Class, java.lang.String)
	 */
	public void incluindoExcluindoPratica(Class classPratica, String operacao)throws ExceptionPraticaNaoLiberada,  ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida {
			try{
				this.praticaExecucaoDosTestes.confereDependencia(classPratica, operacao);
				this.praticaIntegracaoAntesDaValidacao.confereDependencia(classPratica, operacao);
				this.praticaInspecaoDeCodigo.confereDependencia(classPratica, operacao);
				//Confere se  uma das atividade da etapa, caso sim manda selecionara ou tirar a seleo
				this.selecionarPratica(classPratica, operacao);
			//Quando captura uma exceo realiza o operao inversa da que estava realizando
			//para deixar no mesmo estado as atividade
			}catch(ExceptionInclusaoPraticaNaoPermitida ei){
				this.desfazAlteracaoInclusao(classPratica, ei);
				throw ei;
			}catch(ExceptionExclusaoPraticaNaoPermitida ee){
				this.desfazAlteracaoExclusao(classPratica, ee);
				throw ee;
			}
		}

		/**
		 * Desfaz as alteraes realizadas na incluso de uma atividade caso ocorra uma exceo
		 * @param classAtividade
		 * @param operacao
		 * @param ei
		 * @throws ExceptionInclusaoPraticaNaoPermitida
		 * @throws ExceptionExclusaoPraticaNaoPermitida
		 */
		private void desfazAlteracaoInclusao(Class classAtividade, ExceptionInclusaoPraticaNaoPermitida ei)throws ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida{
			//como AtividadeExecucaoDosTestes  a primeira no precisa fazer nada caso ela lance uma exception
			if (ei.getClassPratica() == PraticaIntegracaoAntesDaValidacao.class){
				this.praticaExecucaoDosTestes.confereDependencia(classAtividade, Constantes.EXCLUSAO);
			}else if (ei.getClassPratica() == PraticaInspecaoDeCodigo.class){
				this.praticaExecucaoDosTestes.confereDependencia(classAtividade, Constantes.EXCLUSAO);
				this.praticaIntegracaoAntesDaValidacao.confereDependencia(classAtividade, Constantes.EXCLUSAO);
			}
		}
		/**
		 * Desfaz as alteraes realizadas na excluso de uma atividade caso ocorra uma exceo
		 * @param classAtividade
		 * @param operacao
		 * @param ee
		 * @throws ExceptionInclusaoPraticaNaoPermitida
		 * @throws ExceptionExclusaoPraticaNaoPermitida
		 */
		private void desfazAlteracaoExclusao(Class classAtividade, ExceptionExclusaoPraticaNaoPermitida ee)throws ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida{
			//como AtividadeExecucaoDosTestes  a primeira no precisa fazer nada caso ela lance uma exception
			if (ee.getClassPratica() == PraticaIntegracaoAntesDaValidacao.class){
				this.praticaExecucaoDosTestes.confereDependencia(classAtividade, Constantes.INCLUSAO);
			}else if (ee.getClassPratica() == PraticaInspecaoDeCodigo.class){
				this.praticaExecucaoDosTestes.confereDependencia(classAtividade, Constantes.INCLUSAO);
				this.praticaIntegracaoAntesDaValidacao.confereDependencia(classAtividade, Constantes.INCLUSAO);
			}
		}

		/**
		 * Confere se a atividade faz parte da etapa se sim  tenta selecionar ou liberar
		 * caso no possa selecionar lana uma exceo e arruma o estado da atividades
		 * @param classPratica
		 * @param operacao
		 * @throws ExceptionPraticaNaoLiberada
		 * @throws ExceptionInclusaoPraticaNaoPermitida
		 * @throws ExceptionExclusaoPraticaNaoPermitida
		 */
		private void selecionarPratica(Class classPratica, String operacao)throws ExceptionPraticaNaoLiberada, ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida{
			try{
				if (classPratica == PraticaExecucaoDosTestes.class
						||classPratica == PraticaIntegracaoAntesDaValidacao.class
						||classPratica == PraticaInspecaoDeCodigo.class){
					Pratica atividade;
					atividade = this.getPratica(classPratica);
					if (operacao.equalsIgnoreCase(Constantes.EXCLUSAO)){
						atividade.tiraSelecao();
					}else{// se no  incluso
						atividade.selecionar();
					}
				}
			}catch(ExceptionPraticaNaoLiberada el){
				if (operacao.equalsIgnoreCase(Constantes.EXCLUSAO)){
					this.desfazAlteracaoExclusao(classPratica,
							new ExceptionExclusaoPraticaNaoPermitida(PraticaInspecaoDeCodigo.class));
					//tem que desfazer agora a AtividadeInspecaoDeCodigo, pois o mtodo anterior no desfaz a ltima
					this.praticaInspecaoDeCodigo.confereDependencia(classPratica, Constantes.INCLUSAO);
				}else{// se no  incluso
					this.desfazAlteracaoInclusao(classPratica,
							new ExceptionInclusaoPraticaNaoPermitida(PraticaInspecaoDeCodigo.class));
					//tem que desfazer agora a AtividadeColocarSistemaEmOperacao, pois o mtodo anterior no desfaz a ltima
					this.praticaInspecaoDeCodigo.confereDependencia(classPratica, Constantes.EXCLUSAO);
				}
				throw el;
			} catch (ExceptionPraticaNaoPertenceAEtapa e) {
				//Nunca vai ser lanada essa exceo pq j confere antes da execuo
			}
		}

	/* (non-Javadoc)
	 * @see br.ufsc.fcama.etapa.Etapa#getAtividade(java.lang.Class)
	 */
	public Pratica getPratica(Class classPratica) throws ExceptionPraticaNaoPertenceAEtapa {
		if (classPratica == PraticaExecucaoDosTestes.class){
			return this.praticaExecucaoDosTestes;
		}else if (classPratica == PraticaIntegracaoAntesDaValidacao.class){
			return this.praticaIntegracaoAntesDaValidacao;
		}else if (classPratica == PraticaInspecaoDeCodigo.class){
			return this.praticaInspecaoDeCodigo;
		}else {
			throw new ExceptionPraticaNaoPertenceAEtapa(classPratica, AtividadeValidarIncremento.class);
		}
	}

	/**
	 * @return Returns the atividadeExecucaoDosTestes.
	 */
	public PraticaExecucaoDosTestes getPraticaExecucaoDosTestes() {
		return praticaExecucaoDosTestes;
	}
	/**
	 * @return Returns the atividadeInspecaoDeCodigo.
	 */
	public PraticaInspecaoDeCodigo getPraticaInspecaoDeCodigo() {
		return praticaInspecaoDeCodigo;
	}
	/**
	 * @return Returns the atividadeIntegracaoAntesDaValidacao.
	 */
	public PraticaIntegracaoAntesDaValidacao getPraticaIntegracaoAntesDaValidacao() {
		return praticaIntegracaoAntesDaValidacao;
	}

	/**
	 * @param atividadeExecucaoDosTestes The atividadeExecucaoDosTestes to set.
	 */
	protected void setPraticaExecucaoDosTestes(
			PraticaExecucaoDosTestes atividadeExecucaoDosTestes) {
		this.praticaExecucaoDosTestes = atividadeExecucaoDosTestes;
	}
	/**
	 * @param atividadeInspecaoDeCodigo The atividadeInspecaoDeCodigo to set.
	 */
	protected void setPraticaInspecaoDeCodigo(
			PraticaInspecaoDeCodigo atividadeInspecaoDeCodigo) {
		this.praticaInspecaoDeCodigo = atividadeInspecaoDeCodigo;
	}
	/**
	 * @param atividadeIntegracaoAntesDaValidacao The atividadeIntegracaoAntesDaValidacao to set.
	 */
	protected void setPraticaIntegracaoAntesDaValidacao(
			PraticaIntegracaoAntesDaValidacao atividadeIntegracaoAntesDaValidacao) {
		this.praticaIntegracaoAntesDaValidacao = atividadeIntegracaoAntesDaValidacao;
	}

	public AtividadeValidarIncremento copiaAtividade(){
		AtividadeValidarIncremento atividadeValidarIncremento = new AtividadeValidarIncremento();
		atividadeValidarIncremento.setPraticaExecucaoDosTestes((PraticaExecucaoDosTestes)
				this.praticaExecucaoDosTestes.copiaAtividade(new PraticaExecucaoDosTestes()));
		atividadeValidarIncremento.setPraticaInspecaoDeCodigo((PraticaInspecaoDeCodigo)
				this.praticaExecucaoDosTestes.copiaAtividade(new PraticaInspecaoDeCodigo()));
		atividadeValidarIncremento.setPraticaIntegracaoAntesDaValidacao((PraticaIntegracaoAntesDaValidacao)
				this.praticaIntegracaoAntesDaValidacao.copiaAtividade(new PraticaIntegracaoAntesDaValidacao()));
		return atividadeValidarIncremento;
	}

        public String toString(){
        	return PropertyResourceBundle
    		.getBundle("br.ufsc.fcama.internacionalizacao.ProgramProperties")
    			.getString("br.ufsc.fcama.logica.atividade.ValidarIncremento");
       }

}
