/*
 * Created on 23/08/2005
 *
 */
package br.ufsc.fcama.logica.atividade;

import java.util.PropertyResourceBundle;

import br.ufsc.fcama.exception.ExceptionPraticaNaoLiberada;
import br.ufsc.fcama.exception.ExceptionPraticaNaoPertenceAEtapa;
import br.ufsc.fcama.exception.ExceptionExclusaoPraticaNaoPermitida;
import br.ufsc.fcama.exception.ExceptionInclusaoPraticaNaoPermitida;
import br.ufsc.fcama.logica.objAux.Constantes;
import br.ufsc.fcama.logica.pratica.Pratica;
import br.ufsc.fcama.logica.pratica.PraticaColocarSistemaEmOperacao;
import br.ufsc.fcama.logica.pratica.PraticaReuniaoDeRevisao;

/**
 * @author Thiago Leo Machado
 */
public class AtividadeValidarSistema extends Atividade {

	//Atividade obrigatria
	private PraticaReuniaoDeRevisao praticaReuniaoDeRevisao;
	//Atividade optativa
	private PraticaColocarSistemaEmOperacao praticaColocarSistemaEmOperacao;

	public AtividadeValidarSistema(){
		super();
		this.praticaReuniaoDeRevisao = new PraticaReuniaoDeRevisao();
		this.praticaColocarSistemaEmOperacao = new PraticaColocarSistemaEmOperacao();
	}

	/* (non-Javadoc)
	 * @see br.ufsc.fcama.etapa.Etapa#isRequisitosCompletos()
	 */
	public boolean isRequisitosCompletos() {
		if (this.praticaReuniaoDeRevisao.isSelecionada()){
			return true;
		}else{
			return false;
		}
	}

	/* (non-Javadoc)
	 * @see br.ufsc.fcama.etapa.Etapa#incluindaExcluindoAtividade(java.lang.Class, java.lang.String)
	 */
	public void incluindoExcluindoPratica(Class classPratica, String operacao)throws ExceptionPraticaNaoLiberada,  ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida {
		try{
			this.praticaReuniaoDeRevisao.confereDependencia(classPratica, operacao);
			this.praticaColocarSistemaEmOperacao.confereDependencia(classPratica, operacao);
			//Confere se  uma das atividade da etapa, caso sim manda selecionara ou tirar a seleo
			this.selecionarPratica(classPratica, operacao);
		//Quando captura uma exceo realiza o operao inversa da que estava realizando
		//para deixar no mesmo estado as atividade
		}catch(ExceptionInclusaoPraticaNaoPermitida ei){
			this.desfazAlteracaoInclusao(classPratica, ei);
			throw ei;
		}catch(ExceptionExclusaoPraticaNaoPermitida ee){
			this.desfazAlteracaoExclusao(classPratica, ee);
			throw ee;
		}
	}

	/**
	 * Desfaz as alteraes realizadas na incluso de uma atividade caso ocorra uma exceo
	 * @param classPratica
	 * @param operacao
	 * @param ei
	 * @throws ExceptionInclusaoPraticaNaoPermitida
	 * @throws ExceptionExclusaoPraticaNaoPermitida
	 */
	private void desfazAlteracaoInclusao(Class classPratica, ExceptionInclusaoPraticaNaoPermitida ei)throws ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida{
		//como AtividadeReuniaoDeRevisao  a primeira no precisa fazer nada caso ela lance uma exception
		if (ei.getClassPratica() == PraticaColocarSistemaEmOperacao.class){
			this.praticaReuniaoDeRevisao.confereDependencia(classPratica, Constantes.EXCLUSAO);
		}
	}
	/**
	 * Desfaz as alteraes realizadas na excluso de uma atividade caso ocorra uma exceo
	 * @param classPratica
	 * @param operacao
	 * @param ee
	 * @throws ExceptionInclusaoPraticaNaoPermitida
	 * @throws ExceptionExclusaoPraticaNaoPermitida
	 */
	private void desfazAlteracaoExclusao(Class classPratica, ExceptionExclusaoPraticaNaoPermitida ee)throws ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida{
		//como AtividadeReuniaoDeRevisao  a primeira no precisa fazer nada caso ela lance uma exception
		if (ee.getClassPratica() == PraticaColocarSistemaEmOperacao.class){
			this.praticaReuniaoDeRevisao.confereDependencia(classPratica, Constantes.INCLUSAO);
		}
	}

	/**
	 * Confere se a atividade faz parte da etapa se sim  tenta selecionar ou liberar
	 * caso no possa selecionar lana uma exceo e arruma o estado da atividades
	 * @param classPratica
	 * @param operacao
	 * @throws ExceptionPraticaNaoLiberada
	 * @throws ExceptionInclusaoPraticaNaoPermitida
	 * @throws ExceptionExclusaoPraticaNaoPermitida
	 */
	private void selecionarPratica(Class classPratica, String operacao)throws ExceptionPraticaNaoLiberada, ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida{
		try{
			if (classPratica == PraticaReuniaoDeRevisao.class
					||classPratica == PraticaColocarSistemaEmOperacao.class){
				Pratica atividade;
				atividade = this.getPratica(classPratica);
				if (operacao.equalsIgnoreCase(Constantes.EXCLUSAO)){
					atividade.tiraSelecao();
				}else{// se no  incluso
					atividade.selecionar();
				}
			}
		}catch(ExceptionPraticaNaoLiberada el){
			if (operacao.equalsIgnoreCase(Constantes.EXCLUSAO)){
				this.desfazAlteracaoExclusao(classPratica,
						new ExceptionExclusaoPraticaNaoPermitida(PraticaColocarSistemaEmOperacao.class));
				//tem que desfazer agora a AtividadeColocarSistemaEmOperacao, pois o mtodo anterior no desfaz a ltima
				this.praticaReuniaoDeRevisao.confereDependencia(classPratica, Constantes.INCLUSAO);
			}else{// se no  incluso
				this.desfazAlteracaoInclusao(classPratica,
						new ExceptionInclusaoPraticaNaoPermitida(PraticaColocarSistemaEmOperacao.class));
				//tem que desfazer agora a AtividadeColocarSistemaEmOperacao, pois o mtodo anterior no desfaz a ltima
				this.praticaReuniaoDeRevisao.confereDependencia(classPratica, Constantes.EXCLUSAO);
			}
			throw el;
		} catch (ExceptionPraticaNaoPertenceAEtapa e) {
			//Nunca vai ser lanada essa exceo pq j confere antes da execuo
		}
	}

	/* (non-Javadoc)
	 * @see br.ufsc.fcama.etapa.Etapa#getAtividade(java.lang.Class)
	 */
	public Pratica getPratica(Class classPratica) throws ExceptionPraticaNaoPertenceAEtapa {
		if (classPratica == PraticaReuniaoDeRevisao.class){
			return this.praticaReuniaoDeRevisao;
		}else if (classPratica == PraticaColocarSistemaEmOperacao.class){
			return this.praticaColocarSistemaEmOperacao;
		}else{
			throw new ExceptionPraticaNaoPertenceAEtapa(classPratica, AtividadeValidarSistema.class);
		}
	}

	/**
	 * @return Returns the atividadeColocarSistemaEmOperacao.
	 */
	public PraticaColocarSistemaEmOperacao getPraticaColocarSistemaEmOperacao() {
		return praticaColocarSistemaEmOperacao;
	}
	/**
	 * @return Returns the atividadeReuniaoDeRevisao.
	 */
	public PraticaReuniaoDeRevisao getPraticaReuniaoDeRevisao() {
		return praticaReuniaoDeRevisao;
	}
	/**
	 * @param atividadeColocarSistemaEmOperacao The atividadeColocarSistemaEmOperacao to set.
	 */
	protected void setPraticaColocarSistemaEmOperacao(
			PraticaColocarSistemaEmOperacao atividadeColocarSistemaEmOperacao) {
		this.praticaColocarSistemaEmOperacao = atividadeColocarSistemaEmOperacao;
	}
	/**
	 * @param atividadeReuniaoDeRevisao The atividadeReuniaoDeRevisao to set.
	 */
	protected void setPraticaReuniaoDeRevisao(
			PraticaReuniaoDeRevisao atividadeReuniaoDeRevisao) {
		this.praticaReuniaoDeRevisao = atividadeReuniaoDeRevisao;
	}

	public AtividadeValidarSistema copiaAtividade(){
		AtividadeValidarSistema atividadeValidarSistema = new AtividadeValidarSistema();
		atividadeValidarSistema.setPraticaColocarSistemaEmOperacao((PraticaColocarSistemaEmOperacao)
				this.praticaColocarSistemaEmOperacao.copiaAtividade(new PraticaColocarSistemaEmOperacao()));
		atividadeValidarSistema.setPraticaReuniaoDeRevisao((PraticaReuniaoDeRevisao)
				this.praticaReuniaoDeRevisao.copiaAtividade(new PraticaReuniaoDeRevisao()));
		return atividadeValidarSistema;
	}

    public String toString(){
    	return PropertyResourceBundle
		.getBundle("br.ufsc.fcama.internacionalizacao.ProgramProperties")
			.getString("br.ufsc.fcama.logica.atividade.ValidarSistema");
       }

}
