/*
 * Created on 23/08/2005
 *
 */
package br.ufsc.fcama.logica.pratica;

import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;

import br.ufsc.fcama.exception.ExceptionPraticaNaoLiberada;
import br.ufsc.fcama.exception.ExceptionExclusaoPraticaNaoPermitida;
import br.ufsc.fcama.exception.ExceptionInclusaoPraticaNaoPermitida;
import br.ufsc.fcama.logica.objAux.Anexo;
import br.ufsc.fcama.persistencia.ObjectFCAMA;

/**
 * @author Thiago Leo Machado
 */
public abstract class Pratica extends ObjectFCAMA {
    
	//Comentrios sobre a execuo das atividades
	public String observacao;
	//informa se a atividade foi selececionada
    private boolean selecionada;
    //contm as atividades que caso selecionados impede a execuo da atividade
    //a chave para o hash sempre ser (nome).class e o objeto q ser colocado tbm (nome).class
    //(E)
    protected HashMap excludentes; 
    //contm as atividades que obrigatoriamente devem ser selecionadas para que essa atividade possa ser executada
    //a chave para o hash sempre ser (nome).class e o objeto ser um Boolean true ou false
    //(D)
    protected HashMap obrigatorias; 
    //tem que conter pelo menos uma atividade para que a atividade esteja leberada 
    //a chave para o hash sempre ser (nome).class e o objeto q ser colocado tbm (nome).class
    //(D*)
    protected HashMap outras;
    //Lista de anexos da atividade
    protected ArrayList anexos;
    
    public Pratica(){
        //por default as atividades no esto selecionada
        //caso queira ao contrario tem que sobscrever o contrutor nas classes filhas
        this.selecionada = false;
        this.excludentes = new HashMap(5);
        this.obrigatorias = new HashMap(5);
        this.outras = new HashMap(5); 
        this.anexos = new ArrayList();
        
    }
    
    public String getObservacao() {
		return this.observacao;
	}
	public void setObservacao(String observacao) {
		this.observacao = observacao;
	}

	/**
     * Informa se a atividade est selecionada
     * returnando true se est selecionada e false se no est selecionada
     * @return
     */
    public boolean isSelecionada() {
        return this.selecionada;
    }
    
    /**
     * Informa se a atividade est liberada para ser selecionada
     * caso esteja liberada returna true se no retorna false
     * @return
     */
    public boolean isLiberada(){
    	// para saber se pode selecionar a atividade ou no ... seta por default sim
    	boolean pode = true;
    	// outras tem que ter pelo menos uma atividade e excludentes no pode ter atividades
    	if (this.outras.size() > 0 && this.excludentes.size() == 0){
    		//confere se as atividades obrigatrias foram executadas
    		Collection c = this.obrigatorias.values();
    		Iterator it = c.iterator();
    		//confere se todas as atividades  obrigatrias foram executadas
    		while (it.hasNext()){
    			//caso aguma atividade no tenha sido executada seta pode = false
    			if(!((Boolean)it.next()).booleanValue()){
    				pode = false;
    			}
    		}
        }else {//caso no seta pode = false
        	pode = false;
        }
    	return pode;
    }
    
    /**
     * Veridica se atividade est liberada para ser selecionada
     * Caso no estej liberada lana uma exception
     */
    public void selecionar() throws ExceptionPraticaNaoLiberada{
        
    	//caso esteja liberada  seleciona a atividade
    	if (this.isLiberada()){
            this.selecionada = true;
        }else{//caso pode = false lana exceo
        	throw new ExceptionPraticaNaoLiberada(this.getClass());
        }
    }
    
    /**
     *Tira a seleo da atividade 
     *
     */
    public void tiraSelecao(){
    	this.selecionada = false;
    }
    
    /**
     * cria uma atividade com os valores dos atributos this. 
     * criado para o ciclo de desenvolvimento que
     * todas as atividades iguais dos ciclos de desenvolvimento deve ter
     * o mesmos valores para  selecionada,excludentes,obrigatorias e outras
     * @return
     */
    public Pratica copiaAtividade(Pratica atividade){
    	atividade.selecionada = this.selecionada;
    	atividade.excludentes = new HashMap (this.excludentes);
    	atividade.obrigatorias = new HashMap (this.obrigatorias);
    	atividade.outras = new HashMap (this.outras);
    	atividade.selecionada = this.selecionada;
    	return atividade;
    }
    
    public ArrayList getAnexos() {
		return this.anexos;
	}

	public void setAnexos(ArrayList anexos) {
		this.anexos = anexos;
	}
	
	public void addAnexo(Anexo anexo){
		this.anexos.add(anexo);
	}
	
	public void removeAnexo(Anexo anexo){
		Iterator it = this.anexos.iterator();
		Anexo a = null;
		while (it.hasNext()){
			a = (Anexo) it.next();
			if (anexo.getNome().equals(a.getNome())){
				it.remove();
				return;
			}
		}
	}

	/**
     * Cada subclasse deve implementar seu criterio para conferir se
     * a incluso ou excluso interfere na atividade como bloquear sua execuo ou liberar
     * @param classAtividade
     * @param operacao
     */
    public abstract void confereDependencia(Class classAtividade, String operacao)throws ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida;
    
    
    
}
