package br.ufsc.fcama.persistencia;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;

import org.jdom.Document;
import org.jdom.Element;
import org.jdom.JDOMException;
import org.jdom.input.SAXBuilder;
import org.jdom.output.XMLOutputter;

import br.ufsc.fcama.exception.ExceptionArquivoJaExiste;
import br.ufsc.fcama.exception.ExceptionExclusaoPraticaNaoPermitida;
import br.ufsc.fcama.exception.ExceptionInclusaoPraticaNaoPermitida;
import br.ufsc.fcama.exception.ExceptionPraticaNaoLiberada;
import br.ufsc.fcama.logica.Iteracao;
import br.ufsc.fcama.logica.Projeto;
import br.ufsc.fcama.logica.objAux.Constantes;
import br.ufsc.fcama.logica.pratica.PraticaAtualizacaoDaDocumentacao;
import br.ufsc.fcama.logica.pratica.PraticaBreveDocumentacao;
import br.ufsc.fcama.logica.pratica.PraticaColocarSistemaEmOperacao;
import br.ufsc.fcama.logica.pratica.PraticaControleDeVersoes;
import br.ufsc.fcama.logica.pratica.PraticaDesenvolvimentoColetivo;
import br.ufsc.fcama.logica.pratica.PraticaDesenvolvimentoEmDuplas;
import br.ufsc.fcama.logica.pratica.PraticaDesenvolvimentoLadoALado;
import br.ufsc.fcama.logica.pratica.PraticaDesenvolvimentoSimultaneo;
import br.ufsc.fcama.logica.pratica.PraticaDistribuicaoDosRequisitos;
import br.ufsc.fcama.logica.pratica.PraticaDocumentacaoDetalhada;
import br.ufsc.fcama.logica.pratica.PraticaDocumentacaoDoDesenvolvimento;
import br.ufsc.fcama.logica.pratica.PraticaDocumentacaoDoProjeto;
import br.ufsc.fcama.logica.pratica.PraticaDuracaoDasIteracoes;
import br.ufsc.fcama.logica.pratica.PraticaElaboracaoDoManual;
import br.ufsc.fcama.logica.pratica.PraticaEntregaDoSistema;
import br.ufsc.fcama.logica.pratica.PraticaEscritaDosTestesAntesDaImplementacao;
import br.ufsc.fcama.logica.pratica.PraticaExecucaoDosTestes;
import br.ufsc.fcama.logica.pratica.PraticaImplementacao;
import br.ufsc.fcama.logica.pratica.PraticaInspecaoDeCodigo;
import br.ufsc.fcama.logica.pratica.PraticaIntegracaoAntesDaValidacao;
import br.ufsc.fcama.logica.pratica.PraticaIntegracaoDepoisDaValidacao;
import br.ufsc.fcama.logica.pratica.PraticaIntegracaoParalela;
import br.ufsc.fcama.logica.pratica.PraticaListaDeRequisitos;
import br.ufsc.fcama.logica.pratica.PraticaOrganizacaoDaDocumentacao;
import br.ufsc.fcama.logica.pratica.PraticaPlanejamentoDasIteracoes;
import br.ufsc.fcama.logica.pratica.PraticaProjetoDetalhado;
import br.ufsc.fcama.logica.pratica.PraticaProjetoGeral;
import br.ufsc.fcama.logica.pratica.PraticaRefactoring;
import br.ufsc.fcama.logica.pratica.PraticaRefinamentoDaDocumentacao;
import br.ufsc.fcama.logica.pratica.PraticaReuniaoDeRevisao;
import br.ufsc.fcama.logica.pratica.PraticaReunioesDiarias;
import br.ufsc.fcama.logica.pratica.PraticaUserStories;

public class PersistenciaAplicacao {
	
	
	public String[] getModelos(){
		File fileModelos = new File("modelos" + File.separator + "documentos" );
		String[] modelos = fileModelos.list();
		return modelos;
	}
	
	public File getModelo(String modelo){
		return new File("modelos" + File.separator + "documentos" + File.separator + modelo );
	}
	
	
	public HashMap getMensagens() throws JDOMException, IOException{
		HashMap  mensagens = new HashMap();

		SAXBuilder parser = new SAXBuilder();
	   	Document bDoc = parser.build(new File("modelos" + File.separator + "mensagens.fcama"));
	   	Element root = bDoc.getRootElement();

		//<atividadeUserStories />
		Element atividadeUserStories = root.getChild("atividadeUserStories");
		mensagens.put(PraticaUserStories.class, atividadeUserStories.getValue());
		
		 //<atividadeListaDeRequisitos "/>
		Element atividadeListaDeRequisitos = root.getChild("atividadeListaDeRequisitos");
		mensagens.put(PraticaListaDeRequisitos.class, atividadeListaDeRequisitos.getValue());
		
		//<atividadeDocumentacaoDetalhada/>
		Element atividadeDocumentacaoDetalhada = root.getChild("atividadeDocumentacaoDetalhada");
		mensagens.put(PraticaListaDeRequisitos.class, atividadeDocumentacaoDetalhada.getValue());
		
		//<atividadeOrganizacaoDaDocumentacao />
		Element atividadeOrganizacaoDaDocumentacao = root.getChild("atividadeOrganizacaoDaDocumentacao");
		mensagens.put(PraticaOrganizacaoDaDocumentacao.class, atividadeOrganizacaoDaDocumentacao.getValue());
		
		  //<atividadeDistribuicaoDosRequisitos />
		Element atividadeDistribuicaoDosRequisitos = root.getChild("atividadeDistribuicaoDosRequisitos");
		mensagens.put(PraticaDistribuicaoDosRequisitos.class, atividadeDistribuicaoDosRequisitos.getValue());
		
		 //<atividadePlanejamentoDasIteracoes />
		Element atividadePlanejamentoDasIteracoes = root.getChild("atividadePlanejamentoDasIteracoes");
		mensagens.put(PraticaPlanejamentoDasIteracoes.class, atividadePlanejamentoDasIteracoes.getValue());
		
		//<atividadeDuracaoDasIteracoes />
		Element atividadeDuracaoDasIteracoes = root.getChild("atividadeDuracaoDasIteracoes");
		mensagens.put(PraticaDuracaoDasIteracoes.class, atividadeDuracaoDasIteracoes.getValue());
		
		//<atividadeAtualizacaoDaDocumentacao />
		Element atividadeAtualizacaoDaDocumentacao = root.getChild("atividadeAtualizacaoDaDocumentacao");
		mensagens.put(PraticaAtualizacaoDaDocumentacao.class, atividadeAtualizacaoDaDocumentacao.getValue());
		
		  //<atividadeProjetoGeral "/>
		Element atividadeProjetoGeral = root.getChild("atividadeProjetoGeral");
		mensagens.put(PraticaProjetoGeral.class, atividadeProjetoGeral.getValue());
		
		//<atividadeProjetoDetalhado/>
		Element atividadeProjetoDetalhado = root.getChild("atividadeProjetoDetalhado");
		mensagens.put(PraticaProjetoDetalhado.class, atividadeProjetoDetalhado.getValue());
		
		 //<atividadeDocumentacaoDoProjeto />
		Element atividadeDocumentacaoDoProjeto = root.getChild("atividadeDocumentacaoDoProjeto");
		mensagens.put(PraticaDocumentacaoDoProjeto.class, atividadeDocumentacaoDoProjeto.getValue());
		
			//<atividadeImplementacao />
		  Element atividadeImplementacao = root.getChild("atividadeImplementacao");
		  mensagens.put(PraticaImplementacao.class, atividadeImplementacao.getValue());
		  
		 //<atividadeEscritaDosTestesAntesDaImplementacao />
		  Element atividadeEscritaDosTestesAntesDaImplementacao = root.getChild("atividadeEscritaDosTestesAntesDaImplementacao");
		  mensagens.put(PraticaEscritaDosTestesAntesDaImplementacao.class, atividadeEscritaDosTestesAntesDaImplementacao.getValue());
		  
		   //<atividadeDesenvolvimentoColetivo />
		  Element atividadeDesenvolvimentoColetivo = root.getChild("atividadeDesenvolvimentoColetivo");
		  mensagens.put(PraticaDesenvolvimentoColetivo.class, atividadeDesenvolvimentoColetivo.getValue());
		  
		  //<atividadeDesenvolvimentoEmDuplas />
		  Element atividadeDesenvolvimentoEmDuplas = root.getChild("atividadeDesenvolvimentoEmDuplas");
		  mensagens.put(PraticaDesenvolvimentoEmDuplas.class, atividadeDesenvolvimentoEmDuplas.getValue());
		  
		  //<atividadeDesenvolvimentoLadoALado />
		  Element atividadeDesenvolvimentoLadoALado = root.getChild("atividadeDesenvolvimentoLadoALado");
		  mensagens.put(PraticaDesenvolvimentoLadoALado.class, atividadeDesenvolvimentoLadoALado.getValue());
		  
		  //<atividadeRefactoring />
		  Element atividadeRefactoring = root.getChild("atividadeRefactoring");
		  mensagens.put(PraticaRefactoring.class, atividadeRefactoring.getValue());
		  
		   //<atividadeReunioesDiarias />
		  Element atividadeReunioesDiarias = root.getChild("atividadeReunioesDiarias");
		  mensagens.put(PraticaReunioesDiarias.class, atividadeReunioesDiarias.getValue());
		  
		  //<atividadeDesenvolvimentoSimultaneo />
		  Element atividadeDesenvolvimentoSimultaneo = root.getChild("atividadeDesenvolvimentoSimultaneo");
		  mensagens.put(PraticaDesenvolvimentoSimultaneo.class, atividadeDesenvolvimentoSimultaneo.getValue());
		  
		  //<atividadeIntegracaoParalela />
		  Element atividadeIntegracaoParalela = root.getChild("atividadeIntegracaoParalela");
		  mensagens.put(PraticaIntegracaoParalela.class, atividadeIntegracaoParalela.getValue());
		  
		   //<atividadeDocumentacaoDoDesenvolvimento "/>
		  Element atividadeDocumentacaoDoDesenvolvimento = root.getChild("atividadeDocumentacaoDoDesenvolvimento");
		  mensagens.put(PraticaDocumentacaoDoDesenvolvimento.class, atividadeDocumentacaoDoDesenvolvimento.getValue());
		  
		  //<atividadeControleDeVersoes />
		  Element atividadeControleDeVersoes = root.getChild("atividadeControleDeVersoes");
		  mensagens.put(PraticaControleDeVersoes.class, atividadeControleDeVersoes.getValue());
		  
	    //<atividadeExecucaoDosTestes />
		  Element atividadeExecucaoDosTestes = root.getChild("atividadeExecucaoDosTestes");
		  mensagens.put(PraticaExecucaoDosTestes.class, atividadeExecucaoDosTestes.getValue());
		  
		   //<atividadeIntegracaoAntesDaValidacao />
		  Element atividadeIntegracaoAntesDaValidacao = root.getChild("atividadeIntegracaoAntesDaValidacao");
		  mensagens.put(PraticaIntegracaoAntesDaValidacao.class, atividadeIntegracaoAntesDaValidacao.getValue());
		  
		 //<atividadeInspecaoDeCodigo/>
		  Element atividadeInspecaoDeCodigo = root.getChild("atividadeInspecaoDeCodigo");
		  mensagens.put(PraticaInspecaoDeCodigo.class, atividadeInspecaoDeCodigo.getValue());
		  
		    //<atividadeIntegracaoDepoisDaValidacao />
		  Element atividadeIntegracaoDepoisDaValidacao = root.getChild("atividadeIntegracaoDepoisDaValidacao");
		  mensagens.put(PraticaIntegracaoDepoisDaValidacao.class, atividadeIntegracaoDepoisDaValidacao.getValue());
		  
		  //<atividadeReuniaoDeRevisao =""/>
		  Element atividadeReuniaoDeRevisao = root.getChild("atividadeReuniaoDeRevisao");
		  mensagens.put(PraticaReuniaoDeRevisao.class, atividadeReuniaoDeRevisao.getValue());
		  
		  //<atividadeColocarSistemaEmOperacao />
		  Element atividadeColocarSistemaEmOperacao = root.getChild("atividadeColocarSistemaEmOperacao");
		  mensagens.put(PraticaColocarSistemaEmOperacao.class, atividadeColocarSistemaEmOperacao.getValue());
		  
		  //<atividadeEntregaDoSistema />
		  Element atividadeEntregaDoSistema  = root.getChild("atividadeEntregaDoSistema");
		  mensagens.put(PraticaEntregaDoSistema.class, atividadeEntregaDoSistema.getValue());
		  
		  //<atividadeBreveDocumentacao />
		  Element atividadeBreveDocumentacao  = root.getChild("atividadeBreveDocumentacao");
		  mensagens.put(PraticaBreveDocumentacao.class, atividadeBreveDocumentacao.getValue());
		  
		  //<atividadeRefinamentoDaDocumentacao />
		  Element atividadeRefinamentoDaDocumentacao  = root.getChild("atividadeRefinamentoDaDocumentacao");
		  mensagens.put(PraticaRefinamentoDaDocumentacao.class, atividadeRefinamentoDaDocumentacao.getValue());
		  
		 //<atividadeElaboracaoDoManual />
		  Element atividadeElaboracaoDoManual  = root.getChild("atividadeElaboracaoDoManual");
		  mensagens.put(PraticaElaboracaoDoManual.class, atividadeElaboracaoDoManual.getValue());
		  
		  //</mensagens>

		return mensagens;
	}

	public String[] getModelosDeProjeto(){
		File fileModelos = new File("modelos" + File.separator +"projetos");
		String[] modelos = fileModelos.list();
		return modelos;
	}
	
	public void criarModelo(Projeto projeto, String nomeModelo) throws IOException, ExceptionArquivoJaExiste{
		
		File fileProjetoXML = new File("modelos" + File.separator +"projetos"+ File.separator + nomeModelo +".fcama");
		if(fileProjetoXML.exists()){
			throw new ExceptionArquivoJaExiste(fileProjetoXML.getName());
		}
		//<projeto nomeProjeto="">
		Element rootProjeto = new Element("projeto");
		rootProjeto.setAttribute("nomeProjeto", nomeModelo);
			// <atividadeDefinicaoDosRequisitos>
			Element etapaDefinicaoDosRequisitos = new Element("atividadeDefinicaoDosRequisitos");
				//<praticaUserStories selecionada=""/>
				Element atividadeUserStories = new Element("praticaUserStories");
				atividadeUserStories.setAttribute("selecionada", String.valueOf(projeto.getAtividadeDefinicaoDosRequisitos().getPraticaUserStories().isSelecionada()));
				etapaDefinicaoDosRequisitos.addContent(atividadeUserStories);
				 //<praticaListaDeRequisitos selecionada=""/>
				Element atividadeListaDeRequisitos = new Element("praticaListaDeRequisitos");
				atividadeListaDeRequisitos.setAttribute("selecionada", String.valueOf(projeto.getAtividadeDefinicaoDosRequisitos().getPraticaListaDeRequisitos().isSelecionada()));
				etapaDefinicaoDosRequisitos.addContent(atividadeListaDeRequisitos);
				  //<praticaDocumentacaoDetalhada selecionada=""/>
				Element atividadeDocumentacaoDetalhada = new Element("praticaDocumentacaoDetalhada");
				atividadeDocumentacaoDetalhada.setAttribute("selecionada",String.valueOf(projeto.getAtividadeDefinicaoDosRequisitos().getPraticaDocumentacaoDetalhada().isSelecionada()));
				etapaDefinicaoDosRequisitos.addContent(atividadeDocumentacaoDetalhada);
				 //<praticaOrganizacaoDaDocumentacao selecionada=""/>
				Element atividadeOrganizacaoDaDocumentacao = new Element("praticaOrganizacaoDaDocumentacao");
				atividadeOrganizacaoDaDocumentacao.setAttribute("selecionada", String.valueOf(projeto.getAtividadeDefinicaoDosRequisitos().getPraticaDocumentacaoDetalhada().isSelecionada()));
				etapaDefinicaoDosRequisitos.addContent(atividadeOrganizacaoDaDocumentacao);
			 //</atividadeDefinicaoDosRequisitos>
			rootProjeto.addContent(etapaDefinicaoDosRequisitos);

		 //<atividadeAtribuicaoDosRequisitos>
			Element etapaAtribuicaoDosRequisitos = new Element("atividadeAtribuicaoDosRequisitos");
			   //<praticaDistribuicaoDosRequisitos selecionada=""/>
				Element atividadeDistribuicaoDosRequisitos = new Element("praticaDistribuicaoDosRequisitos");
				atividadeDistribuicaoDosRequisitos.setAttribute("selecionada", String.valueOf(projeto.getAtividadeAtribuicaoDosRequisitos().getPraticaDistribuicaoDosRequisitos().isSelecionada()));
				etapaAtribuicaoDosRequisitos.addContent(atividadeDistribuicaoDosRequisitos);
				 //<praticaPlanejamentoDasIteracoes selecionada=""/>
				Element atividadePlanejamentoDasIteracoes = new Element("praticaPlanejamentoDasIteracoes");
				atividadePlanejamentoDasIteracoes.setAttribute("selecionada", String.valueOf(projeto.getAtividadeAtribuicaoDosRequisitos().getPraticaPlanejamentoDasIteracoes().isSelecionada()));
				etapaAtribuicaoDosRequisitos.addContent(atividadePlanejamentoDasIteracoes);
				//<praticaDuracaoDasIteracoes selecionada=""/>
				Element atividadeDuracaoDasIteracoes = new Element("praticaDuracaoDasIteracoes");
				atividadeDuracaoDasIteracoes.setAttribute("selecionada", String.valueOf(projeto.getAtividadeAtribuicaoDosRequisitos().getPraticaDuracaoDasIteracoes().isSelecionada()));
				etapaAtribuicaoDosRequisitos.addContent(atividadeDuracaoDasIteracoes);
				//<praticaAtualizacaoDaDocumentacao selecionada=""/>
				Element atividadeAtualizacaoDaDocumentacao = new Element("praticaAtualizacaoDaDocumentacao");
				atividadeAtualizacaoDaDocumentacao.setAttribute("selecionada", String.valueOf(projeto.getAtividadeAtribuicaoDosRequisitos().getPraticaAtualizacaoDaDocumentacao().isSelecionada()));
				etapaAtribuicaoDosRequisitos.addContent(atividadeAtualizacaoDaDocumentacao);
		 //</atividadeAtribuicaoDosRequisitos>
			rootProjeto.addContent(etapaAtribuicaoDosRequisitos);

		 //<atividadeProjetoDoSistema>
			Element etapaProjetoDoSistema = new Element("atividadeProjetoDoSistema");
			   //<praticaProjetoGeral selecionada=""/>
				Element atividadeProjetoGeral = new Element("praticaProjetoGeral");
				atividadeProjetoGeral.setAttribute("selecionada", String.valueOf(projeto.getAtividadeProjetoDoSistema().getPraticaProjetoGeral().isSelecionada()));
				etapaProjetoDoSistema.addContent(atividadeProjetoGeral);
				//<praticaProjetoDetalhado selecionada=""/>
				Element atividadeProjetoDetalhado = new Element("praticaProjetoDetalhado");
				atividadeProjetoDetalhado.setAttribute("selecionada", String.valueOf(projeto.getAtividadeProjetoDoSistema().getPraticaProjetoDetalhado().isSelecionada()));
				etapaProjetoDoSistema.addContent(atividadeProjetoDetalhado);
				//<praticaDocumentacaoDoProjeto selecionada=""/>
				Element atividadeDocumentacaoDoProjeto = new Element("praticaDocumentacaoDoProjeto");
				atividadeDocumentacaoDoProjeto.setAttribute("selecionada", String.valueOf(projeto.getAtividadeProjetoDoSistema().getPraticaDocumentacaoDoProjeto().isSelecionada()));
				etapaProjetoDoSistema.addContent(atividadeDocumentacaoDoProjeto);
		 //</atividadeProjetoDoSistema>
			rootProjeto.addContent(etapaProjetoDoSistema);

		 //<iteraes>
		  Element ciclosDeDesenvolvimento = new Element("iteracao");
		  List ciclosDeDesenvolvimentoList = projeto.getIteracoes();
		  Iterator it = ciclosDeDesenvolvimentoList.iterator();
		  Iteracao cd = null;
		  while (it.hasNext()){
			  cd = (Iteracao) it.next();

			  //<iteracao numero="">
			  Element cicloDeDesenvolvimento = new Element("iteracao");
			  cicloDeDesenvolvimento.setAttribute("numero", String.valueOf(cd.getNumero()));
			  
			  //<atividadeDesenvolverIncrementoDoSistema>
			  Element etapaDesenvolvierIncrementoDoSistema = new Element("atividadeDesenvolvierIncrementoDoSistema");
			      //<praticaImplementacao selecionada=""/>
				  Element atividadeImplementacao = new Element("praticaImplementacao");
				  atividadeImplementacao.setAttribute("selecionada", String.valueOf(cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaImplementacao().isSelecionada()));
				  etapaDesenvolvierIncrementoDoSistema.addContent(atividadeImplementacao);
				  //<praticaEscritaDosTestesAntesDaImplementacao selecionada=""/>
				  Element atividadeEscritaDosTestesAntesDaImplementacao = new Element("praticaEscritaDosTestesAntesDaImplementacao");
				  atividadeEscritaDosTestesAntesDaImplementacao.setAttribute("selecionada", String.valueOf(cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaEscritaDosTestesAntesDaImplementacao().isSelecionada()));
				  etapaDesenvolvierIncrementoDoSistema.addContent(atividadeEscritaDosTestesAntesDaImplementacao);
				  //<praticaDesenvolvimentoColetivo selecionada=""/>
				  Element atividadeDesenvolvimentoColetivo = new Element("praticaDesenvolvimentoColetivo");
				  atividadeDesenvolvimentoColetivo.setAttribute("selecionada", String.valueOf(cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDesenvolvimentoColetivo().isSelecionada()));
				  etapaDesenvolvierIncrementoDoSistema.addContent(atividadeDesenvolvimentoColetivo);
				  //<praticaDesenvolvimentoEmDuplas selecionada=""/>
				  Element atividadeDesenvolvimentoEmDuplas = new Element("praticaDesenvolvimentoEmDuplas");
				  atividadeDesenvolvimentoEmDuplas.setAttribute("selecionada", String.valueOf(cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDesenvolvimentoEmDuplas().isSelecionada()));
				  etapaDesenvolvierIncrementoDoSistema.addContent(atividadeDesenvolvimentoEmDuplas);
				  //<praticaDesenvolvimentoLadoALado selecionada=""/>
				  Element atividadeDesenvolvimentoLadoALado = new Element("praticaDesenvolvimentoLadoALado");
				  atividadeDesenvolvimentoLadoALado.setAttribute("selecionada", String.valueOf(cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDesenvolvimentoLadoALado().isSelecionada()));
				  etapaDesenvolvierIncrementoDoSistema.addContent(atividadeDesenvolvimentoLadoALado);
				  //<praticaRefactoring selecionada=""/>
				  Element atividadeRefactoring = new Element("praticaRefactoring");
				  atividadeRefactoring.setAttribute("selecionada", String.valueOf(cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaRefactoring().isSelecionada()));
				  etapaDesenvolvierIncrementoDoSistema.addContent(atividadeRefactoring);
				  //<praticaReunioesDiarias selecionada=""/>
				  Element atividadeReunioesDiarias = new Element("praticaReunioesDiarias");
				  atividadeReunioesDiarias.setAttribute("selecionada", String.valueOf(cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaReunioesDiarias().isSelecionada()));
				  etapaDesenvolvierIncrementoDoSistema.addContent(atividadeReunioesDiarias);
				  //<praticaDesenvolvimentoSimultaneo selecionada=""/>
				  Element atividadeDesenvolvimentoSimultaneo = new Element("praticaDesenvolvimentoSimultaneo");
				  atividadeDesenvolvimentoSimultaneo.setAttribute("selecionada", String.valueOf(cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDesenvolvimentoSimultaneo().isSelecionada()));
				  etapaDesenvolvierIncrementoDoSistema.addContent(atividadeDesenvolvimentoSimultaneo);
				  //<praticaIntegracaoParalela selecionada=""/>
				  Element atividadeIntegracaoParalela = new Element("praticaIntegracaoParalela");
				  atividadeIntegracaoParalela.setAttribute("selecionada", String.valueOf(cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaIntegracaoParalela().isSelecionada()));
				  etapaDesenvolvierIncrementoDoSistema.addContent(atividadeIntegracaoParalela);
				  //<praticaDocumentacaoDoDesenvolvimento selecionada=""/>
				  Element atividadeDocumentacaoDoDesenvolvimento  = new Element("praticaDocumentacaoDoDesenvolvimento");
				  atividadeDocumentacaoDoDesenvolvimento.setAttribute("selecionada", String.valueOf(cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDocumentacaoDoDesenvolvimento().isSelecionada()));
				  etapaDesenvolvierIncrementoDoSistema.addContent(atividadeDocumentacaoDoDesenvolvimento);
				  //<praticaControleDeVersoes selecionada=""/>
				  Element atividadeControleDeVersoes = new Element("praticaControleDeVersoes");
				  atividadeControleDeVersoes.setAttribute("selecionada", String.valueOf(cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaControleDeVersoes().isSelecionada()));
				  etapaDesenvolvierIncrementoDoSistema.addContent(atividadeControleDeVersoes);
				//</atividadeDesenvolvierIncrementoDoSistema>
			  cicloDeDesenvolvimento.addContent(etapaDesenvolvierIncrementoDoSistema);

			   //<atividadeValidarIncremento>
			  Element etapaValidarIncremento = new Element("atividadeValidarIncremento");
			      //<praticaExecucaoDosTestes selecionada=""/>
				  Element atividadeExecucaoDosTestes = new Element("praticaExecucaoDosTestes");
				  atividadeExecucaoDosTestes.setAttribute("selecionada", String.valueOf(cd.getAtividadeValidarIncremento().getPraticaExecucaoDosTestes().isSelecionada()));
				  etapaValidarIncremento.addContent(atividadeExecucaoDosTestes);
				  //<praticaIntegracaoAntesDaValidacao selecionada=""/>
				  Element atividadeIntegracaoAntesDaValidacao  = new Element("praticaIntegracaoAntesDaValidacao");
				  atividadeIntegracaoAntesDaValidacao.setAttribute("selecionada", String.valueOf(cd.getAtividadeValidarIncremento().getPraticaIntegracaoAntesDaValidacao().isSelecionada()));
				  etapaValidarIncremento.addContent(atividadeIntegracaoAntesDaValidacao);
				  //<praticaInspecaoDeCodigo selecionada=""/>
				  Element atividadeInspecaoDeCodigo  = new Element("praticaInspecaoDeCodigo");
				  atividadeInspecaoDeCodigo.setAttribute("selecionada", String.valueOf(cd.getAtividadeValidarIncremento().getPraticaInspecaoDeCodigo().isSelecionada()));
				  etapaValidarIncremento.addContent(atividadeInspecaoDeCodigo);
			//</atividadeValidarIncremento>
			  cicloDeDesenvolvimento.addContent(etapaValidarIncremento);

			  //<atividadeIntegracaoIncremento>
			  Element etapaIntegracaoIncremento = new Element("atividadeIntegracaoIncremento");
			      //<praticaIntegracaoDepoisDaValidacao selecionada=""/>
				  Element atividadeIntegracaoDepoisDaValidacao = new Element("praticaIntegracaoDepoisDaValidacao");
				  atividadeIntegracaoDepoisDaValidacao.setAttribute("selecionada", String.valueOf(cd.getAtividadeIntegracaoIncremento().getPraticaIntegracaoDepoisDaValidacao().isSelecionada()));
				  etapaIntegracaoIncremento.addContent(atividadeIntegracaoDepoisDaValidacao);
			  //</atividadeIntegracaoIncremento>
			  cicloDeDesenvolvimento.addContent(etapaIntegracaoIncremento);

			   //<atividadeValidarSistema>
			  Element etapaValidarSistema = new Element("atividadeValidarSistema");
			      //<praticaReuniaoDeRevisao selecionada=""/>
				  Element atividadeReuniaoDeRevisao = new Element("praticaReuniaoDeRevisao");
				  atividadeReuniaoDeRevisao.setAttribute("selecionada", String.valueOf(cd.getAtividadeValidarSistema().getPraticaReuniaoDeRevisao().isSelecionada()));
				  etapaValidarSistema.addContent(atividadeReuniaoDeRevisao);
				  //<praticaColocarSistemaEmOperacao selecionada=""/>
				  Element atividadeColocarSistemaEmOperacao = new Element("praticaColocarSistemaEmOperacao");
				  atividadeColocarSistemaEmOperacao.setAttribute("selecionada", String.valueOf(cd.getAtividadeValidarSistema().getPraticaColocarSistemaEmOperacao().isSelecionada()));
				  etapaValidarSistema.addContent(atividadeColocarSistemaEmOperacao);
			//</atividadeValidarSistema>
			  cicloDeDesenvolvimento.addContent(etapaValidarSistema);

			  //</iteracao>
			  ciclosDeDesenvolvimento.addContent(cicloDeDesenvolvimento);
		  }
		 //</iteracoes>
		  rootProjeto.addContent(ciclosDeDesenvolvimento);

		 //<atividadeEntregaFinal>
		  Element etapaEntregaFinal = new Element("atividadeEntregaFinal");
		     //<praticaEntregaDoSistema selecionada=""/>
			  Element atividadeEntregaDoSistema  = new Element("praticaEntregaDoSistema");
			  atividadeEntregaDoSistema.setAttribute("selecionada", String.valueOf(projeto.getAtividadeEntregaFinal().getPraticaEntregaDoSistema().isSelecionada()));
			  etapaEntregaFinal.addContent(atividadeEntregaDoSistema);
			  //<praticaBreveDocumentacao selecionada=""/>
			  Element atividadeBreveDocumentacao  = new Element("praticaBreveDocumentacao");
			  atividadeBreveDocumentacao.setAttribute("selecionada", String.valueOf(projeto.getAtividadeEntregaFinal().getPraticaBreveDocumentacao().isSelecionada()));
			  etapaEntregaFinal.addContent(atividadeBreveDocumentacao);
			  //<praticaRefinamentoDaDocumentacao selecionada=""/>
			  Element atividadeRefinamentoDaDocumentacao  = new Element("praticaRefinamentoDaDocumentacao");
			  atividadeRefinamentoDaDocumentacao.setAttribute("selecionada", String.valueOf(projeto.getAtividadeEntregaFinal().getPraticaRefinamentoDaDocumentacao().isSelecionada()));
			  etapaEntregaFinal.addContent(atividadeRefinamentoDaDocumentacao);
			  //<praticaElaboracaoDoManual selecionada=""/>
			  Element atividadeElaboracaoDoManual  = new Element("praticaElaboracaoDoManual");
			  atividadeElaboracaoDoManual.setAttribute("selecionada", String.valueOf(projeto.getAtividadeEntregaFinal().getPraticaElaboracaoDoManual().isSelecionada()));
			  etapaEntregaFinal.addContent(atividadeElaboracaoDoManual);
		//</atividadeEntregaFinal>
		  rootProjeto.addContent(etapaEntregaFinal);

		//</projeto>
		  Document doc = new Document(rootProjeto);
		  XMLOutputter outputter = new XMLOutputter();
		  outputter.output(doc, new FileOutputStream(fileProjetoXML));


	}

	public Projeto getProjetoDoModelo(String modelo) throws ExceptionPraticaNaoLiberada, ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida, JDOMException, IOException{
		Projeto projeto = new Projeto();
		
		SAXBuilder parser = new SAXBuilder();
	   	Document bDoc = parser.build(new File("modelos" + File.separator +"projetos"+ File.separator + modelo));

		//<projeto nomeProjeto="">
		Element rootProjeto = bDoc.getRootElement();
		projeto.setNomeProjeto(rootProjeto.getAttributeValue("nomeProjeto"));
		
			// <atividadeDefinicaoDosRequisitos>
			Element etapaDefinicaoDosRequisitos = rootProjeto.getChild("atividadeDefinicaoDosRequisitos");
			
				//<praticaUserStories selecionada=""/>
				Element atividadeUserStories = etapaDefinicaoDosRequisitos.getChild("praticaUserStories");
				if (Boolean.valueOf(atividadeUserStories.getAttributeValue("selecionada")).booleanValue()){
					projeto.incluindoExcluindoPratica(PraticaUserStories.class,Constantes.INCLUSAO);
				}

				 //<praticaListaDeRequisitos selecionada=""/>
				Element atividadeListaDeRequisitos = etapaDefinicaoDosRequisitos.getChild("praticaListaDeRequisitos");
				if (Boolean.valueOf(atividadeListaDeRequisitos.getAttributeValue("selecionada")).booleanValue()){
					projeto.incluindoExcluindoPratica(PraticaListaDeRequisitos.class,Constantes.INCLUSAO);
				}

				//<praticaDocumentacaoDetalhada selecionada=""/>
				Element atividadeDocumentacaoDetalhada = etapaDefinicaoDosRequisitos.getChild("praticaDocumentacaoDetalhada");
				if (Boolean.valueOf(atividadeDocumentacaoDetalhada.getAttributeValue("selecionada")).booleanValue()){
					projeto.incluindoExcluindoPratica(PraticaDocumentacaoDetalhada.class,Constantes.INCLUSAO);
				}

				 //<praticaOrganizacaoDaDocumentacao selecionada=""/>
				Element atividadeOrganizacaoDaDocumentacao = etapaDefinicaoDosRequisitos.getChild("praticaOrganizacaoDaDocumentacao");
				if (Boolean.valueOf(atividadeOrganizacaoDaDocumentacao.getAttributeValue("selecionada")).booleanValue()){
					projeto.incluindoExcluindoPratica(PraticaOrganizacaoDaDocumentacao.class,Constantes.INCLUSAO);
				}

				 //</atividadeDefinicaoDosRequisitos>

		 //<atividadeAtribuicaoDosRequisitos>
			Element etapaAtribuicaoDosRequisitos = rootProjeto.getChild("atividadeAtribuicaoDosRequisitos");
			
				  //<praticaDistribuicaoDosRequisitos selecionada=""/>
				Element atividadeDistribuicaoDosRequisitos = etapaAtribuicaoDosRequisitos.getChild("praticaDistribuicaoDosRequisitos");
				if (Boolean.valueOf(atividadeDistribuicaoDosRequisitos.getAttributeValue("selecionada")).booleanValue()){
					projeto.incluindoExcluindoPratica(PraticaDistribuicaoDosRequisitos.class,Constantes.INCLUSAO);
				}
				 //<praticaPlanejamentoDasIteracoes selecionada=""/>
				Element atividadePlanejamentoDasIteracoes = etapaAtribuicaoDosRequisitos.getChild("praticaPlanejamentoDasIteracoes");
				if (Boolean.valueOf(atividadePlanejamentoDasIteracoes.getAttributeValue("selecionada")).booleanValue()){
					projeto.incluindoExcluindoPratica(PraticaPlanejamentoDasIteracoes.class,Constantes.INCLUSAO);
				}

				//<praticaDuracaoDasIteracoes selecionada=""/>
				Element atividadeDuracaoDasIteracoes = etapaAtribuicaoDosRequisitos.getChild("praticaDuracaoDasIteracoes");
				if (Boolean.valueOf(atividadeDuracaoDasIteracoes.getAttributeValue("selecionada")).booleanValue()){
					projeto.incluindoExcluindoPratica(PraticaDuracaoDasIteracoes.class,Constantes.INCLUSAO);
				}

				//<praticaAtualizacaoDaDocumentacao selecionada=""/>
				Element atividadeAtualizacaoDaDocumentacao = etapaAtribuicaoDosRequisitos.getChild("praticaAtualizacaoDaDocumentacao");
				if (Boolean.valueOf(atividadeAtualizacaoDaDocumentacao.getAttributeValue("selecionada")).booleanValue()){
					projeto.incluindoExcluindoPratica(PraticaAtualizacaoDaDocumentacao.class,Constantes.INCLUSAO);
				}

		 //</atividadeAtribuicaoDosRequisitos>

		 //<atividadeProjetoDoSistema>
			Element etapaProjetoDoSistema = rootProjeto.getChild("atividadeProjetoDoSistema");
			
				//<praticaProjetoGeral selecionada=""/>
				Element atividadeProjetoGeral = etapaProjetoDoSistema.getChild("praticaProjetoGeral");
				if (Boolean.valueOf(atividadeProjetoGeral.getAttributeValue("selecionada")).booleanValue()){
					projeto.incluindoExcluindoPratica(PraticaProjetoGeral.class,Constantes.INCLUSAO);
				}

				//<praticaProjetoDetalhado selecionada=""/>
				Element atividadeProjetoDetalhado = etapaProjetoDoSistema.getChild("praticaProjetoDetalhado");
				if (Boolean.valueOf(atividadeProjetoDetalhado.getAttributeValue("selecionada")).booleanValue()){
					projeto.incluindoExcluindoPratica(PraticaProjetoDetalhado.class,Constantes.INCLUSAO);
				}

				 //<praticaDocumentacaoDoProjeto selecionada=""/>
				Element atividadeDocumentacaoDoProjeto = etapaProjetoDoSistema.getChild("praticaDocumentacaoDoProjeto");
				if (Boolean.valueOf(atividadeDocumentacaoDoProjeto.getAttributeValue("selecionada")).booleanValue()){
					projeto.incluindoExcluindoPratica(PraticaDocumentacaoDoProjeto.class,Constantes.INCLUSAO);
				}

		 //</atividadeProjetoDoSistema>

		 //<iteracao>
		  Element ciclosDeDesenvolvimento = rootProjeto.getChild("iteracao");
		  List ciclosDeDesenvolvimentoList = ciclosDeDesenvolvimento.getChildren("iteracao");
		  Iterator it = ciclosDeDesenvolvimentoList.iterator();
		  Iteracao cd = null;
		  while (it.hasNext()){
			  if (cd == null){//entra no primeiro ciclo, pois nesse no precisa fazer o add e tem que dizer quais atividades esto selecionadas
				  cd = (Iteracao)projeto.getIteracoes().iterator().next();

				  //<cicloDeDesenvolvimento numero="">
				  Element cicloDeDesenvolvimento = (Element) it.next();
				  cd.setNumero(Integer.valueOf(cicloDeDesenvolvimento.getAttributeValue("numero")).intValue());
				 
				   //<atividadeDesenvolvierIncrementoDoSistema>
				  Element etapaDesenvolvierIncrementoDoSistema = cicloDeDesenvolvimento.getChild("atividadeDesenvolvierIncrementoDoSistema");
				  
				  	//<praticaImplementacao selecionada=""/>
					  Element atividadeImplementacao = etapaDesenvolvierIncrementoDoSistema.getChild("praticaImplementacao");
					  if (Boolean.valueOf(atividadeImplementacao.getAttributeValue("selecionada")).booleanValue()){
						  projeto.incluindoExcluindoPratica(PraticaImplementacao.class,Constantes.INCLUSAO);
					  }
					 //<praticaEscritaDosTestesAntesDaImplementacao selecionada=""/>
					  Element atividadeEscritaDosTestesAntesDaImplementacao = etapaDesenvolvierIncrementoDoSistema.getChild("praticaEscritaDosTestesAntesDaImplementacao");
					  if (Boolean.valueOf(atividadeEscritaDosTestesAntesDaImplementacao.getAttributeValue("selecionada")).booleanValue()){
						  projeto.incluindoExcluindoPratica(PraticaEscritaDosTestesAntesDaImplementacao.class,Constantes.INCLUSAO);
					  }

					   //<praticaDesenvolvimentoColetivo selecionada=""/>
					  Element atividadeDesenvolvimentoColetivo = etapaDesenvolvierIncrementoDoSistema.getChild("praticaDesenvolvimentoColetivo");
					  if (Boolean.valueOf(atividadeDesenvolvimentoColetivo.getAttributeValue("selecionada")).booleanValue()){
						  projeto.incluindoExcluindoPratica(PraticaDesenvolvimentoColetivo.class,Constantes.INCLUSAO);
					  }

					  //<praticaDesenvolvimentoEmDuplas selecionada=""/>
					  Element atividadeDesenvolvimentoEmDuplas = etapaDesenvolvierIncrementoDoSistema.getChild("praticaDesenvolvimentoEmDuplas");
					  if (Boolean.valueOf(atividadeDesenvolvimentoEmDuplas.getAttributeValue("selecionada")).booleanValue()){
						  projeto.incluindoExcluindoPratica(PraticaDesenvolvimentoEmDuplas.class,Constantes.INCLUSAO);
					  }

					  //<praticaDesenvolvimentoLadoALado selecionada=""/>
					  Element atividadeDesenvolvimentoLadoALado = etapaDesenvolvierIncrementoDoSistema.getChild("praticaDesenvolvimentoLadoALado");
					  if (Boolean.valueOf(atividadeDesenvolvimentoLadoALado.getAttributeValue("selecionada")).booleanValue()){
						  projeto.incluindoExcluindoPratica(PraticaDesenvolvimentoLadoALado.class,Constantes.INCLUSAO);
					  }

					  //<praticaRefactoring selecionada=""/>
					  Element atividadeRefactoring = etapaDesenvolvierIncrementoDoSistema.getChild("praticaRefactoring");
					  if (Boolean.valueOf(atividadeRefactoring.getAttributeValue("selecionada")).booleanValue()){
						  projeto.incluindoExcluindoPratica(PraticaRefactoring.class,Constantes.INCLUSAO);
					  }

					   //<praticaReunioesDiarias selecionada=""/>
					  Element atividadeReunioesDiarias = etapaDesenvolvierIncrementoDoSistema.getChild("praticaReunioesDiarias");
					  if (Boolean.valueOf(atividadeReunioesDiarias.getAttributeValue("selecionada")).booleanValue()){
						  projeto.incluindoExcluindoPratica(PraticaReunioesDiarias.class,Constantes.INCLUSAO);
					  }

					  //<praticaDesenvolvimentoSimultaneo selecionada=""/>
					  Element atividadeDesenvolvimentoSimultaneo = etapaDesenvolvierIncrementoDoSistema.getChild("praticaDesenvolvimentoSimultaneo");
					  if (Boolean.valueOf(atividadeDesenvolvimentoSimultaneo.getAttributeValue("selecionada")).booleanValue()){
						  projeto.incluindoExcluindoPratica(PraticaDesenvolvimentoSimultaneo.class,Constantes.INCLUSAO);
					  }

					  //<praticaIntegracaoParalela selecionada=""/>
					  Element atividadeIntegracaoParalela = etapaDesenvolvierIncrementoDoSistema.getChild("praticaIntegracaoParalela");
					  if (Boolean.valueOf(atividadeIntegracaoParalela.getAttributeValue("selecionada")).booleanValue()){
						  projeto.incluindoExcluindoPratica(PraticaIntegracaoParalela.class,Constantes.INCLUSAO);
					  }

					   //<praticaDocumentacaoDoDesenvolvimento selecionada=""/>
					  Element atividadeDocumentacaoDoDesenvolvimento = etapaDesenvolvierIncrementoDoSistema.getChild("praticaDocumentacaoDoDesenvolvimento");
					  if (Boolean.valueOf(atividadeDocumentacaoDoDesenvolvimento.getAttributeValue("selecionada")).booleanValue()){
						  projeto.incluindoExcluindoPratica(PraticaDocumentacaoDoDesenvolvimento.class,Constantes.INCLUSAO);
					  }

					  //<praticaControleDeVersoes selecionada=""/>
					  Element atividadeControleDeVersoes = etapaDesenvolvierIncrementoDoSistema.getChild("praticaControleDeVersoes");
					  if (Boolean.valueOf(atividadeControleDeVersoes.getAttributeValue("selecionada")).booleanValue()){
						  projeto.incluindoExcluindoPratica(PraticaControleDeVersoes.class,Constantes.INCLUSAO);
					  }

				//</atividadeDesenvolvierIncrementoDoSistema>

				   //<atividadeValidarIncremento>
				  Element etapaValidarIncremento = cicloDeDesenvolvimento.getChild("atividadeValidarIncremento");
				 
					    //<praticaExecucaoDosTestes selecionada=""/>
					  Element atividadeExecucaoDosTestes = etapaValidarIncremento.getChild("praticaExecucaoDosTestes");
					  if (Boolean.valueOf(atividadeExecucaoDosTestes.getAttributeValue("selecionada")).booleanValue()){
						  projeto.incluindoExcluindoPratica(PraticaExecucaoDosTestes.class,Constantes.INCLUSAO);
					  }

					   //<praticaIntegracaoAntesDaValidacao selecionada=""/>
					  Element atividadeIntegracaoAntesDaValidacao = etapaValidarIncremento.getChild("praticaIntegracaoAntesDaValidacao");
					  if (Boolean.valueOf(atividadeIntegracaoAntesDaValidacao.getAttributeValue("selecionada")).booleanValue()){
						  projeto.incluindoExcluindoPratica(PraticaIntegracaoAntesDaValidacao.class,Constantes.INCLUSAO);
					  }

					 //<praticaInspecaoDeCodigo selecionada=""/>
					  Element atividadeInspecaoDeCodigo = etapaValidarIncremento.getChild("praticaInspecaoDeCodigo");
					  if (Boolean.valueOf(atividadeInspecaoDeCodigo.getAttributeValue("selecionada")).booleanValue()){
						  projeto.incluindoExcluindoPratica(PraticaInspecaoDeCodigo.class,Constantes.INCLUSAO);
					  }
					//</atividadeValidarIncremento>

				   //<atividadeIntegracaoIncremento>
				  Element etapaIntegracaoIncremento = cicloDeDesenvolvimento.getChild("atividadeIntegracaoIncremento");
				  
					   //<praticaIntegracaoDepoisDaValidacao selecionada=""/>
					  Element atividadeIntegracaoDepoisDaValidacao = etapaIntegracaoIncremento.getChild("praticaIntegracaoDepoisDaValidacao");
					  if (Boolean.valueOf(atividadeIntegracaoDepoisDaValidacao.getAttributeValue("selecionada")).booleanValue()){
						  projeto.incluindoExcluindoPratica(PraticaIntegracaoDepoisDaValidacao.class,Constantes.INCLUSAO);
					  }
					 //</atividadeIntegracaoIncremento>

				   //<atividadeValidarSistema>
				  Element etapaValidarSistema = cicloDeDesenvolvimento.getChild("atividadeValidarSistema");
				  
					   //<praticaReuniaoDeRevisao selecionada=""/>
					  Element atividadeReuniaoDeRevisao = etapaValidarSistema.getChild("praticaReuniaoDeRevisao");
					  if (Boolean.valueOf(atividadeReuniaoDeRevisao.getAttributeValue("selecionada")).booleanValue()){
						  projeto.incluindoExcluindoPratica(PraticaReuniaoDeRevisao.class,Constantes.INCLUSAO);
					  }
					  //<praticaColocarSistemaEmOperacao selecionada=""/>
					  Element atividadeColocarSistemaEmOperacao = etapaValidarSistema.getChild("praticaColocarSistemaEmOperacao");
					  if (Boolean.valueOf(atividadeColocarSistemaEmOperacao.getAttributeValue("selecionada")).booleanValue()){
						  projeto.incluindoExcluindoPratica(PraticaColocarSistemaEmOperacao.class,Constantes.INCLUSAO);
					  }
				 //</atividadeValidarSistema>

				  //</cicloDeDesenvolvimento>




			  }else{
				  cd = cd.copiaCicloDeDesenvolvimento();
				  //<cicloDeDesenvolvimento numero="">
				  Element cicloDeDesenvolvimento = (Element) it.next();
				  cd.setNumero(Integer.valueOf(cicloDeDesenvolvimento.getAttributeValue("numero")).intValue());
				  projeto.addIteracao(cd);
			  }


		  }
		 //</iteraes>

		 //<atividadeEntregaFinal>
		  Element etapaEntregaFinal = rootProjeto.getChild("atividadeEntregaFinal");
		  
			  //<praticaEntregaDoSistema selecionada=""/>
			  Element atividadeEntregaDoSistema  = etapaEntregaFinal.getChild("praticaEntregaDoSistema");
			  if (Boolean.valueOf(atividadeEntregaDoSistema.getAttributeValue("selecionada")).booleanValue()){
					projeto.incluindoExcluindoPratica(PraticaEntregaDoSistema.class,Constantes.INCLUSAO);
			  }

			  //<praticaBreveDocumentacao selecionada=""/>
			  Element atividadeBreveDocumentacao  = etapaEntregaFinal.getChild("praticaBreveDocumentacao");
			  if (Boolean.valueOf(atividadeBreveDocumentacao.getAttributeValue("selecionada")).booleanValue()){
					projeto.incluindoExcluindoPratica(PraticaBreveDocumentacao.class,Constantes.INCLUSAO);
			  }

			  //<praticaRefinamentoDaDocumentacao selecionada=""/>
			  Element atividadeRefinamentoDaDocumentacao  = etapaEntregaFinal.getChild("praticaRefinamentoDaDocumentacao");
			  if (Boolean.valueOf(atividadeRefinamentoDaDocumentacao.getAttributeValue("selecionada")).booleanValue()){
					projeto.incluindoExcluindoPratica(PraticaRefinamentoDaDocumentacao.class,Constantes.INCLUSAO);
			  }

			 //<praticaElaboracaoDoManual selecionada=""/>
			  Element atividadeElaboracaoDoManual  = etapaEntregaFinal.getChild("praticaElaboracaoDoManual");
			  if (Boolean.valueOf(atividadeElaboracaoDoManual.getAttributeValue("selecionada")).booleanValue()){
					projeto.incluindoExcluindoPratica(PraticaElaboracaoDoManual.class,Constantes.INCLUSAO);
			  }

		//</etapaEntregaFinal>

		//</projeto>

		return projeto;
	}
}
