package br.ufsc.fcama.persistencia;


import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;

import org.jdom.Document;
import org.jdom.Element;
import org.jdom.JDOMException;
import org.jdom.input.SAXBuilder;
import org.jdom.output.XMLOutputter;

import br.ufsc.fcama.exception.ExceptionArquivoJaExiste;
import br.ufsc.fcama.exception.ExceptionExclusaoPraticaNaoPermitida;
import br.ufsc.fcama.exception.ExceptionInclusaoPraticaNaoPermitida;
import br.ufsc.fcama.exception.ExceptionPraticaNaoLiberada;
import br.ufsc.fcama.exception.ExceptionStakeholderJaCadastrado;
import br.ufsc.fcama.logica.Iteracao;
import br.ufsc.fcama.logica.Projeto;
import br.ufsc.fcama.logica.atividade.Atividade;
import br.ufsc.fcama.logica.objAux.Anexo;
import br.ufsc.fcama.logica.objAux.Constantes;
import br.ufsc.fcama.logica.objAux.DuplaDesenvolvimento;
import br.ufsc.fcama.logica.objAux.Requisito;
import br.ufsc.fcama.logica.objAux.RequisitoAnexo;
import br.ufsc.fcama.logica.objAux.Stakeholder;
import br.ufsc.fcama.logica.objAux.UserStory;
import br.ufsc.fcama.logica.pratica.Pratica;
import br.ufsc.fcama.logica.pratica.PraticaAtualizacaoDaDocumentacao;
import br.ufsc.fcama.logica.pratica.PraticaBreveDocumentacao;
import br.ufsc.fcama.logica.pratica.PraticaColocarSistemaEmOperacao;
import br.ufsc.fcama.logica.pratica.PraticaControleDeVersoes;
import br.ufsc.fcama.logica.pratica.PraticaDesenvolvimentoColetivo;
import br.ufsc.fcama.logica.pratica.PraticaDesenvolvimentoEmDuplas;
import br.ufsc.fcama.logica.pratica.PraticaDesenvolvimentoLadoALado;
import br.ufsc.fcama.logica.pratica.PraticaDesenvolvimentoSimultaneo;
import br.ufsc.fcama.logica.pratica.PraticaDistribuicaoDosRequisitos;
import br.ufsc.fcama.logica.pratica.PraticaDocumentacaoDetalhada;
import br.ufsc.fcama.logica.pratica.PraticaDocumentacaoDoDesenvolvimento;
import br.ufsc.fcama.logica.pratica.PraticaDocumentacaoDoProjeto;
import br.ufsc.fcama.logica.pratica.PraticaDuracaoDasIteracoes;
import br.ufsc.fcama.logica.pratica.PraticaElaboracaoDoManual;
import br.ufsc.fcama.logica.pratica.PraticaEntregaDoSistema;
import br.ufsc.fcama.logica.pratica.PraticaEscritaDosTestesAntesDaImplementacao;
import br.ufsc.fcama.logica.pratica.PraticaExecucaoDosTestes;
import br.ufsc.fcama.logica.pratica.PraticaImplementacao;
import br.ufsc.fcama.logica.pratica.PraticaInspecaoDeCodigo;
import br.ufsc.fcama.logica.pratica.PraticaIntegracaoAntesDaValidacao;
import br.ufsc.fcama.logica.pratica.PraticaIntegracaoDepoisDaValidacao;
import br.ufsc.fcama.logica.pratica.PraticaIntegracaoParalela;
import br.ufsc.fcama.logica.pratica.PraticaListaDeRequisitos;
import br.ufsc.fcama.logica.pratica.PraticaOrganizacaoDaDocumentacao;
import br.ufsc.fcama.logica.pratica.PraticaPlanejamentoDasIteracoes;
import br.ufsc.fcama.logica.pratica.PraticaProjetoDetalhado;
import br.ufsc.fcama.logica.pratica.PraticaProjetoGeral;
import br.ufsc.fcama.logica.pratica.PraticaRefactoring;
import br.ufsc.fcama.logica.pratica.PraticaRefinamentoDaDocumentacao;
import br.ufsc.fcama.logica.pratica.PraticaReuniaoDeRevisao;
import br.ufsc.fcama.logica.pratica.PraticaReunioesDiarias;
import br.ufsc.fcama.logica.pratica.PraticaUserStories;

public class XMLPersistencia {

	private File fileProjeto;

	public XMLPersistencia(File fileCaminho, String nomeProjeto){
		try {
			this.fileProjeto = new File(fileCaminho.getCanonicalPath() + File.separator + nomeProjeto);
			//caso no exista o diretorio cria uma
			if (!this.fileProjeto.exists()){
				this.fileProjeto.mkdir();
			}
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
	
	public XMLPersistencia(File fileCaminho){
		this.fileProjeto = fileCaminho;
		this.fileProjeto.mkdir();
	}

	public  void criarProjeto(Projeto projeto)throws IOException{
			this.salvarStakeholder(this.fileProjeto, projeto);
			//criar o arquivo xml Projeto.xml
			File fileProjetoXML = new File(this.fileProjeto.getCanonicalPath()+ File.separator + "projeto.fcama");
			//<projeto nomeProjeto="">
			Element rootProjeto = new Element("projeto");
			rootProjeto.setAttribute("nomeProjeto", projeto.getNomeProjeto());
				// <etapaDefinicaoDosRequisitos>
				Element etapaDefinicaoDosRequisitos = new Element("atividadeDefinicaoDosRequisitos");
				File fileEtapaDefinicaoDosRequisitos = new File(this.fileProjeto.getCanonicalPath()+ File.separator + "atividadeDefinicaoDosRequisitos");
				fileEtapaDefinicaoDosRequisitos.mkdir();
					//<atividadeUserStories selecionada=""/>
					Element atividadeUserStories = new Element("praticaUserStories");
					atividadeUserStories.setAttribute("selecionada", String.valueOf(projeto.getAtividadeDefinicaoDosRequisitos().getPraticaUserStories().isSelecionada()));
					etapaDefinicaoDosRequisitos.addContent(atividadeUserStories);
					this.salvarPratica(fileEtapaDefinicaoDosRequisitos,projeto.getAtividadeDefinicaoDosRequisitos().getPraticaUserStories(), "praticaUserStories" );
					 //<atividadeListaDeRequisitos selecionada=""/>
					Element atividadeListaDeRequisitos = new Element("praticaListaDeRequisitos");
					atividadeListaDeRequisitos.setAttribute("selecionada", String.valueOf(projeto.getAtividadeDefinicaoDosRequisitos().getPraticaListaDeRequisitos().isSelecionada()));
					etapaDefinicaoDosRequisitos.addContent(atividadeListaDeRequisitos);
					this.salvarPratica(fileEtapaDefinicaoDosRequisitos,projeto.getAtividadeDefinicaoDosRequisitos().getPraticaListaDeRequisitos(),"praticaListaDeRequisitos" );
					  //<atividadeDocumentacaoDetalhada selecionada=""/>
					Element atividadeDocumentacaoDetalhada = new Element("praticaDocumentacaoDetalhada");
					atividadeDocumentacaoDetalhada.setAttribute("selecionada",String.valueOf(projeto.getAtividadeDefinicaoDosRequisitos().getPraticaDocumentacaoDetalhada().isSelecionada()));
					etapaDefinicaoDosRequisitos.addContent(atividadeDocumentacaoDetalhada);
					this.salvarPratica(fileEtapaDefinicaoDosRequisitos,projeto.getAtividadeDefinicaoDosRequisitos().getPraticaDocumentacaoDetalhada(), "praticaDocumentacaoDetalhada" );
					  //<atividadeOrganizacaoDaDocumentacao selecionada=""/>
					Element atividadeOrganizacaoDaDocumentacao = new Element("praticaOrganizacaoDaDocumentacao");
					atividadeOrganizacaoDaDocumentacao.setAttribute("selecionada", String.valueOf(projeto.getAtividadeDefinicaoDosRequisitos().getPraticaDocumentacaoDetalhada().isSelecionada()));
					etapaDefinicaoDosRequisitos.addContent(atividadeOrganizacaoDaDocumentacao);
					this.salvarPratica(fileEtapaDefinicaoDosRequisitos,projeto.getAtividadeDefinicaoDosRequisitos().getPraticaDocumentacaoDetalhada(),"praticaOrganizacaoDaDocumentacao" );
				 //</etapaDefinicaoDosRequisitos>
				rootProjeto.addContent(etapaDefinicaoDosRequisitos);

			 //<etapaAtribuicaoDosRequisitos>
				Element etapaAtribuicaoDosRequisitos = new Element("atividadeAtribuicaoDosRequisitos");
				File fileEtapaAtribuicaoDosRequisitos = new File(this.fileProjeto.getCanonicalPath()+ File.separator + "atividadeAtribuicaoDosRequisitos");
				fileEtapaAtribuicaoDosRequisitos.mkdir();
					  //<atividadeDistribuicaoDosRequisitos selecionada=""/>
					Element atividadeDistribuicaoDosRequisitos = new Element("praticaDistribuicaoDosRequisitos");
					atividadeDistribuicaoDosRequisitos.setAttribute("selecionada", String.valueOf(projeto.getAtividadeAtribuicaoDosRequisitos().getPraticaDistribuicaoDosRequisitos().isSelecionada()));
					etapaAtribuicaoDosRequisitos.addContent(atividadeDistribuicaoDosRequisitos);
					this.salvarPratica(fileEtapaAtribuicaoDosRequisitos, projeto.getAtividadeAtribuicaoDosRequisitos().getPraticaDistribuicaoDosRequisitos(), "praticaDistribuicaoDosRequisitos");
					  //<atividadePlanejamentoDasIteracoes selecionada=""/>
					Element atividadePlanejamentoDasIteracoes = new Element("praticaPlanejamentoDasIteracoes");
					atividadePlanejamentoDasIteracoes.setAttribute("selecionada", String.valueOf(projeto.getAtividadeAtribuicaoDosRequisitos().getPraticaPlanejamentoDasIteracoes().isSelecionada()));
					etapaAtribuicaoDosRequisitos.addContent(atividadePlanejamentoDasIteracoes);
					this.salvarPratica(fileEtapaAtribuicaoDosRequisitos,projeto.getAtividadeAtribuicaoDosRequisitos().getPraticaPlanejamentoDasIteracoes(), "praticaPlanejamentoDasIteracoes");
					  //<atividadeDuracaoDasIteracoes selecionada=""/>
					Element atividadeDuracaoDasIteracoes = new Element("praticaDuracaoDasIteracoes");
					atividadeDuracaoDasIteracoes.setAttribute("selecionada", String.valueOf(projeto.getAtividadeAtribuicaoDosRequisitos().getPraticaDuracaoDasIteracoes().isSelecionada()));
					etapaAtribuicaoDosRequisitos.addContent(atividadeDuracaoDasIteracoes);
					this.salvarPratica(fileEtapaAtribuicaoDosRequisitos,projeto.getAtividadeAtribuicaoDosRequisitos().getPraticaDuracaoDasIteracoes(), "praticaDuracaoDasIteracoes");
					  //<atividadeAtualizacaoDaDocumentacao selecionada=""/>
					Element atividadeAtualizacaoDaDocumentacao = new Element("praticaAtualizacaoDaDocumentacao");
					atividadeAtualizacaoDaDocumentacao.setAttribute("selecionada", String.valueOf(projeto.getAtividadeAtribuicaoDosRequisitos().getPraticaAtualizacaoDaDocumentacao().isSelecionada()));
					etapaAtribuicaoDosRequisitos.addContent(atividadeAtualizacaoDaDocumentacao);
					this.salvarPratica(fileEtapaAtribuicaoDosRequisitos,projeto.getAtividadeAtribuicaoDosRequisitos().getPraticaAtualizacaoDaDocumentacao(), "praticaAtualizacaoDaDocumentacao");
			 //</etapaAtribuicaoDosRequisitos>
				rootProjeto.addContent(etapaAtribuicaoDosRequisitos);

			 //<etapaProjetoDoSistema>
				Element etapaProjetoDoSistema = new Element("atividadeProjetoDoSistema");
				File fileEtapaProjetoDoSistema = new File (this.fileProjeto.getCanonicalPath()+ File.separator + "atividadeProjetoDoSistema");
				fileEtapaProjetoDoSistema.mkdir();
					  //<atividadeProjetoGeral selecionada=""/>
					Element atividadeProjetoGeral = new Element("praticaProjetoGeral");
					atividadeProjetoGeral.setAttribute("selecionada", String.valueOf(projeto.getAtividadeProjetoDoSistema().getPraticaProjetoGeral().isSelecionada()));
					etapaProjetoDoSistema.addContent(atividadeProjetoGeral);
					this.salvarPratica(fileEtapaProjetoDoSistema,projeto.getAtividadeProjetoDoSistema().getPraticaProjetoGeral(), "praticaProjetoGeral");
					  //<atividadeProjetoDetalhado selecionada=""/>
					Element atividadeProjetoDetalhado = new Element("praticaProjetoDetalhado");
					atividadeProjetoDetalhado.setAttribute("selecionada", String.valueOf(projeto.getAtividadeProjetoDoSistema().getPraticaProjetoDetalhado().isSelecionada()));
					etapaProjetoDoSistema.addContent(atividadeProjetoDetalhado);
					this.salvarPratica(fileEtapaProjetoDoSistema, projeto.getAtividadeProjetoDoSistema().getPraticaProjetoDetalhado(), "praticaProjetoDetalhado");
					  //<atividadeDocumentacaoDoProjeto selecionada=""/>
					Element atividadeDocumentacaoDoProjeto = new Element("praticaDocumentacaoDoProjeto");
					atividadeDocumentacaoDoProjeto.setAttribute("selecionada", String.valueOf(projeto.getAtividadeProjetoDoSistema().getPraticaDocumentacaoDoProjeto().isSelecionada()));
					etapaProjetoDoSistema.addContent(atividadeDocumentacaoDoProjeto);
					this.salvarPratica(fileEtapaProjetoDoSistema, projeto.getAtividadeProjetoDoSistema().getPraticaDocumentacaoDoProjeto(), "praticaDocumentacaoDoProjeto");
			 //</etapaProjetoDoSistema>
				rootProjeto.addContent(etapaProjetoDoSistema);

			 //<ciclosDeDesenvolvimento>
			  Element ciclosDeDesenvolvimento = new Element("iteracao");
			  List ciclosDeDesenvolvimentoList = projeto.getIteracoes();
			  Iterator it = ciclosDeDesenvolvimentoList.iterator();
			  Iteracao cd = null;
			  while (it.hasNext()){
				  cd = (Iteracao) it.next();

				  //<cicloDeDesenvolvimento numero="">
				  Element cicloDeDesenvolvimento = new Element("iteracao");
				  cicloDeDesenvolvimento.setAttribute("numero", String.valueOf(cd.getNumero()));
				  File fileCicloDeDesenvolvimento = new File(this.fileProjeto.getCanonicalPath()+ File.separator + "iteracao" + cd.getNumero());
				  fileCicloDeDesenvolvimento.mkdir();
				  this.salvarIteracao(fileCicloDeDesenvolvimento, cd);

				   //<etapaDesenvolverIncrementoDoSistema>
				  Element etapaDesenvolvierIncrementoDoSistema = new Element("atividadeDesenvolvierIncrementoDoSistema");
				  File fileEtapaDesenvolvierIncrementoDoSistema = new File(fileCicloDeDesenvolvimento.getCanonicalPath() + File.separator + "atividadeDesenvolverIncrementoDoSistema");
				  fileEtapaDesenvolvierIncrementoDoSistema.mkdir();
					    //<atividadeImplementacao selecionada=""/>
					  Element atividadeImplementacao = new Element("praticaImplementacao");
					  atividadeImplementacao.setAttribute("selecionada", String.valueOf(cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaImplementacao().isSelecionada()));
					  etapaDesenvolvierIncrementoDoSistema.addContent(atividadeImplementacao);
					  this.salvarPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaImplementacao(), "praticaImplementacao");
					    //<atividadeEscritaDosTestesAntesDaImplementacao selecionada=""/>
					  Element atividadeEscritaDosTestesAntesDaImplementacao = new Element("praticaEscritaDosTestesAntesDaImplementacao");
					  atividadeEscritaDosTestesAntesDaImplementacao.setAttribute("selecionada", String.valueOf(cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaEscritaDosTestesAntesDaImplementacao().isSelecionada()));
					  etapaDesenvolvierIncrementoDoSistema.addContent(atividadeEscritaDosTestesAntesDaImplementacao);
					  this.salvarPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaEscritaDosTestesAntesDaImplementacao(), "praticaEscritaDosTestesAntesDaImplementacao");
					    //<atividadeDesenvolvimentoColetivo selecionada=""/>
					  Element atividadeDesenvolvimentoColetivo = new Element("praticaDesenvolvimentoColetivo");
					  atividadeDesenvolvimentoColetivo.setAttribute("selecionada", String.valueOf(cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDesenvolvimentoColetivo().isSelecionada()));
					  etapaDesenvolvierIncrementoDoSistema.addContent(atividadeDesenvolvimentoColetivo);
					  this.salvarPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDesenvolvimentoColetivo(), "praticaDesenvolvimentoColetivo");
					    //<atividadeDesenvolvimentoEmDuplas selecionada=""/>
					  Element atividadeDesenvolvimentoEmDuplas = new Element("praticaDesenvolvimentoEmDuplas");
					  atividadeDesenvolvimentoEmDuplas.setAttribute("selecionada", String.valueOf(cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDesenvolvimentoEmDuplas().isSelecionada()));
					  etapaDesenvolvierIncrementoDoSistema.addContent(atividadeDesenvolvimentoEmDuplas);
					  this.salvarPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDesenvolvimentoEmDuplas(), "praticaDesenvolvimentoEmDuplas");
					    //<atividadeDesenvolvimentoLadoALado selecionada=""/>
					  Element atividadeDesenvolvimentoLadoALado = new Element("praticaDesenvolvimentoLadoALado");
					  atividadeDesenvolvimentoLadoALado.setAttribute("selecionada", String.valueOf(cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDesenvolvimentoLadoALado().isSelecionada()));
					  etapaDesenvolvierIncrementoDoSistema.addContent(atividadeDesenvolvimentoLadoALado);
					  this.salvarPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDesenvolvimentoLadoALado(), "praticaDesenvolvimentoLadoALado");
					    //<atividadeRefactoring selecionada=""/>
					  Element atividadeRefactoring = new Element("praticaRefactoring");
					  atividadeRefactoring.setAttribute("selecionada", String.valueOf(cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaRefactoring().isSelecionada()));
					  etapaDesenvolvierIncrementoDoSistema.addContent(atividadeRefactoring);
					  this.salvarPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaRefactoring(), "praticaRefactoring");
					    //<atividadeReunioesDiarias selecionada=""/>
					  Element atividadeReunioesDiarias = new Element("praticaReunioesDiarias");
					  atividadeReunioesDiarias.setAttribute("selecionada", String.valueOf(cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaReunioesDiarias().isSelecionada()));
					  etapaDesenvolvierIncrementoDoSistema.addContent(atividadeReunioesDiarias);
					  this.salvarPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaReunioesDiarias(), "praticaReunioesDiarias");
					    //<atividadeDesenvolvimentoSimultaneo selecionada=""/>
					  Element atividadeDesenvolvimentoSimultaneo = new Element("praticaDesenvolvimentoSimultaneo");
					  atividadeDesenvolvimentoSimultaneo.setAttribute("selecionada", String.valueOf(cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDesenvolvimentoSimultaneo().isSelecionada()));
					  etapaDesenvolvierIncrementoDoSistema.addContent(atividadeDesenvolvimentoSimultaneo);
					  this.salvarPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDesenvolvimentoSimultaneo(), "praticaDesenvolvimentoSimultaneo");
					    //<atividadeIntegracaoParalela selecionada=""/>
					  Element atividadeIntegracaoParalela = new Element("praticaIntegracaoParalela");
					  atividadeIntegracaoParalela.setAttribute("selecionada", String.valueOf(cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaIntegracaoParalela().isSelecionada()));
					  etapaDesenvolvierIncrementoDoSistema.addContent(atividadeIntegracaoParalela);
					  this.salvarPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaIntegracaoParalela(),"praticaIntegracaoParalela");
					    //<atividadeDocumentacaoDoDesenvolvimento selecionada=""/>
					  Element atividadeDocumentacaoDoDesenvolvimento  = new Element("praticaDocumentacaoDoDesenvolvimento");
					  atividadeDocumentacaoDoDesenvolvimento.setAttribute("selecionada", String.valueOf(cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDocumentacaoDoDesenvolvimento().isSelecionada()));
					  etapaDesenvolvierIncrementoDoSistema.addContent(atividadeDocumentacaoDoDesenvolvimento);
					  this.salvarPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDocumentacaoDoDesenvolvimento(), "praticaDocumentacaoDoDesenvolvimento");
					    //<atividadeControleDeVersoes selecionada=""/>
					  Element atividadeControleDeVersoes = new Element("praticaControleDeVersoes");
					  atividadeControleDeVersoes.setAttribute("selecionada", String.valueOf(cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaControleDeVersoes().isSelecionada()));
					  etapaDesenvolvierIncrementoDoSistema.addContent(atividadeControleDeVersoes);
					  this.salvarPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaControleDeVersoes(), "praticaControleDeVersoes");
				   //</etapaDesenvolvierIncrementoDoSistema>
				  cicloDeDesenvolvimento.addContent(etapaDesenvolvierIncrementoDoSistema);

				   //<etapaValidarIncremento>
				  Element etapaValidarIncremento = new Element("atividadeValidarIncremento");
				  File fileEtapaValidarIncremento = new File(fileCicloDeDesenvolvimento.getCanonicalPath() + File.separator + "atividadeValidarIncremento");
				  fileEtapaValidarIncremento.mkdir();
					    //<atividadeExecucaoDosTestes selecionada=""/>
					  Element atividadeExecucaoDosTestes = new Element("praticaExecucaoDosTestes");
					  atividadeExecucaoDosTestes.setAttribute("selecionada", String.valueOf(cd.getAtividadeValidarIncremento().getPraticaExecucaoDosTestes().isSelecionada()));
					  etapaValidarIncremento.addContent(atividadeExecucaoDosTestes);
					  this.salvarPratica(fileEtapaValidarIncremento, cd.getAtividadeValidarIncremento().getPraticaExecucaoDosTestes(), "praticaExecucaoDosTestes");
					    //<atividadeIntegracaoAntesDaValidacao selecionada=""/>
					  Element atividadeIntegracaoAntesDaValidacao  = new Element("praticaIntegracaoAntesDaValidacao");
					  atividadeIntegracaoAntesDaValidacao.setAttribute("selecionada", String.valueOf(cd.getAtividadeValidarIncremento().getPraticaIntegracaoAntesDaValidacao().isSelecionada()));
					  etapaValidarIncremento.addContent(atividadeIntegracaoAntesDaValidacao);
					  this.salvarPratica(fileEtapaValidarIncremento, cd.getAtividadeValidarIncremento().getPraticaIntegracaoAntesDaValidacao(), "praticaIntegracaoAntesDaValidacao");
					    //<atividadeInspecaoDeCodigo selecionada=""/>
					  Element atividadeInspecaoDeCodigo  = new Element("praticaInspecaoDeCodigo");
					  atividadeInspecaoDeCodigo.setAttribute("selecionada", String.valueOf(cd.getAtividadeValidarIncremento().getPraticaInspecaoDeCodigo().isSelecionada()));
					  etapaValidarIncremento.addContent(atividadeInspecaoDeCodigo);
					  this.salvarPratica(fileEtapaValidarIncremento, cd.getAtividadeValidarIncremento().getPraticaInspecaoDeCodigo(),"praticaInspecaoDeCodigo");
				   //</etapaValidarIncremento>
				  cicloDeDesenvolvimento.addContent(etapaValidarIncremento);

				   //<etapaIntegracaoIncremento>
				  Element etapaIntegracaoIncremento = new Element("atividadeIntegracaoIncremento");
				  File fileEtapaIntegracaoIncremento = new File(fileCicloDeDesenvolvimento.getCanonicalPath() + File.separator + "atividadeIntegracaoIncremento");
				  fileEtapaIntegracaoIncremento.mkdir();
					    //<atividadeIntegracaoDepoisDaValidacao selecionada=""/>
					  Element atividadeIntegracaoDepoisDaValidacao = new Element("praticaIntegracaoDepoisDaValidacao");
					  atividadeIntegracaoDepoisDaValidacao.setAttribute("selecionada", String.valueOf(cd.getAtividadeIntegracaoIncremento().getPraticaIntegracaoDepoisDaValidacao().isSelecionada()));
					  etapaIntegracaoIncremento.addContent(atividadeIntegracaoDepoisDaValidacao);
					  this.salvarPratica(fileEtapaIntegracaoIncremento, cd.getAtividadeIntegracaoIncremento().getPraticaIntegracaoDepoisDaValidacao(), "praticaIntegracaoDepoisDaValidacao");
				   //</etapaIntegracaoIncremento>
				  cicloDeDesenvolvimento.addContent(etapaIntegracaoIncremento);

				   //<etapaValidarSistema>
				  Element etapaValidarSistema = new Element("atividadeValidarSistema");
				  File fileEtapaValidarSistema = new File(fileCicloDeDesenvolvimento.getCanonicalPath() + File.separator + "atividadeValidarSistema");
				  fileEtapaValidarSistema.mkdir();
					    //<atividadeReuniaoDeRevisao selecionada=""/>
					  Element atividadeReuniaoDeRevisao = new Element("praticaReuniaoDeRevisao");
					  atividadeReuniaoDeRevisao.setAttribute("selecionada", String.valueOf(cd.getAtividadeValidarSistema().getPraticaReuniaoDeRevisao().isSelecionada()));
					  etapaValidarSistema.addContent(atividadeReuniaoDeRevisao);
					  this.salvarPratica(fileEtapaValidarSistema, cd.getAtividadeValidarSistema().getPraticaReuniaoDeRevisao(), "praticaReuniaoDeRevisao");
					    //<atividadeColocarSistemaEmOperacao selecionada=""/>
					  Element atividadeColocarSistemaEmOperacao = new Element("praticaColocarSistemaEmOperacao");
					  atividadeColocarSistemaEmOperacao.setAttribute("selecionada", String.valueOf(cd.getAtividadeValidarSistema().getPraticaColocarSistemaEmOperacao().isSelecionada()));
					  etapaValidarSistema.addContent(atividadeColocarSistemaEmOperacao);
					  this.salvarPratica(fileEtapaValidarSistema, cd.getAtividadeValidarSistema().getPraticaColocarSistemaEmOperacao(), "praticaColocarSistemaEmOperacao");
				   //</etapaValidarSistema>
				  cicloDeDesenvolvimento.addContent(etapaValidarSistema);

				  //</cicloDeDesenvolvimento>
				  ciclosDeDesenvolvimento.addContent(cicloDeDesenvolvimento);
			  }
			 //</ciclosDeDesenvolvimento>
			  rootProjeto.addContent(ciclosDeDesenvolvimento);

			 //<etapaEntregaFinal>
			  Element etapaEntregaFinal = new Element("atividadeEntregaFinal");
			  File fileEtapaEntregaFinal = new File (this.fileProjeto.getCanonicalPath()+ File.separator + "atividadeEntregaFinal");
			  fileEtapaEntregaFinal.mkdir();
				  //<atividadeEntregaDoSistema selecionada=""/>
				  Element atividadeEntregaDoSistema  = new Element("praticaEntregaDoSistema");
				  atividadeEntregaDoSistema.setAttribute("selecionada", String.valueOf(projeto.getAtividadeEntregaFinal().getPraticaEntregaDoSistema().isSelecionada()));
				  etapaEntregaFinal.addContent(atividadeEntregaDoSistema);
				  this.salvarPratica(fileEtapaEntregaFinal, projeto.getAtividadeEntregaFinal().getPraticaEntregaDoSistema(), "praticaEntregaDoSistema");
				  //<atividadeBreveDocumentacao selecionada=""/>
				  Element atividadeBreveDocumentacao  = new Element("praticaBreveDocumentacao");
				  atividadeBreveDocumentacao.setAttribute("selecionada", String.valueOf(projeto.getAtividadeEntregaFinal().getPraticaBreveDocumentacao().isSelecionada()));
				  etapaEntregaFinal.addContent(atividadeBreveDocumentacao);
				  this.salvarPratica(fileEtapaEntregaFinal, projeto.getAtividadeEntregaFinal().getPraticaBreveDocumentacao(), "praticaBreveDocumentacao");
				  //<atividadeRefinamentoDaDocumentacao selecionada=""/>
				  Element atividadeRefinamentoDaDocumentacao  = new Element("praticaRefinamentoDaDocumentacao");
				  atividadeRefinamentoDaDocumentacao.setAttribute("selecionada", String.valueOf(projeto.getAtividadeEntregaFinal().getPraticaRefinamentoDaDocumentacao().isSelecionada()));
				  etapaEntregaFinal.addContent(atividadeRefinamentoDaDocumentacao);
				  this.salvarPratica(fileEtapaEntregaFinal, projeto.getAtividadeEntregaFinal().getPraticaRefinamentoDaDocumentacao(), "praticaRefinamentoDaDocumentacao");
				  //<atividadeElaboracaoDoManual selecionada=""/>
				  Element atividadeElaboracaoDoManual  = new Element("praticaElaboracaoDoManual");
				  atividadeElaboracaoDoManual.setAttribute("selecionada", String.valueOf(projeto.getAtividadeEntregaFinal().getPraticaElaboracaoDoManual().isSelecionada()));
				  etapaEntregaFinal.addContent(atividadeElaboracaoDoManual);
				  this.salvarPratica(fileEtapaEntregaFinal, projeto.getAtividadeEntregaFinal().getPraticaElaboracaoDoManual(),"praticaElaboracaoDoManual");
			 //</etapaEntregaFinal>
			  rootProjeto.addContent(etapaEntregaFinal);

			//</projeto>
			  Document doc = new Document(rootProjeto);
			  XMLOutputter outputter = new XMLOutputter();
			  outputter.output(doc, new FileOutputStream(fileProjetoXML));


	}


	public void salvarProjeto(Projeto projeto)throws IOException{
		this.salvarStakeholder(this.fileProjeto, projeto);
		//salvar o arquivo xml Projeto.xml
		File fileProjetoXML = new File(this.fileProjeto.getCanonicalPath()+ File.separator + "projeto.fcama");
		//<projeto nomeProjeto="">
		Element rootProjeto = new Element("projeto");
		rootProjeto.setAttribute("nomeProjeto", projeto.getNomeProjeto());
			// <etapaDefinicaoDosRequisitos>
			Element etapaDefinicaoDosRequisitos = new Element("atividadeDefinicaoDosRequisitos");
			File fileEtapaDefinicaoDosRequisitos = new File(this.fileProjeto.getCanonicalPath()+ File.separator + "atividadeDefinicaoDosRequisitos");
				//<atividadeUserStories selecionada=""/>
				Element atividadeUserStories = new Element("praticaUserStories");
				atividadeUserStories.setAttribute("selecionada", String.valueOf(projeto.getAtividadeDefinicaoDosRequisitos().getPraticaUserStories().isSelecionada()));
				etapaDefinicaoDosRequisitos.addContent(atividadeUserStories);
				this.salvarPratica(fileEtapaDefinicaoDosRequisitos,projeto.getAtividadeDefinicaoDosRequisitos().getPraticaUserStories(), "praticaUserStories" );
				 //<atividadeListaDeRequisitos selecionada=""/>
				Element atividadeListaDeRequisitos = new Element("praticaListaDeRequisitos");
				atividadeListaDeRequisitos.setAttribute("selecionada", String.valueOf(projeto.getAtividadeDefinicaoDosRequisitos().getPraticaListaDeRequisitos().isSelecionada()));
				etapaDefinicaoDosRequisitos.addContent(atividadeListaDeRequisitos);
				this.salvarPratica(fileEtapaDefinicaoDosRequisitos,projeto.getAtividadeDefinicaoDosRequisitos().getPraticaListaDeRequisitos(),"praticaListaDeRequisitos" );
				  //<atividadeDocumentacaoDetalhada selecionada=""/>
				Element atividadeDocumentacaoDetalhada = new Element("praticaDocumentacaoDetalhada");
				atividadeDocumentacaoDetalhada.setAttribute("selecionada",String.valueOf(projeto.getAtividadeDefinicaoDosRequisitos().getPraticaDocumentacaoDetalhada().isSelecionada()));
				etapaDefinicaoDosRequisitos.addContent(atividadeDocumentacaoDetalhada);
				this.salvarPratica(fileEtapaDefinicaoDosRequisitos,projeto.getAtividadeDefinicaoDosRequisitos().getPraticaDocumentacaoDetalhada(), "praticaDocumentacaoDetalhada" );
				  //<atividadeOrganizacaoDaDocumentacao selecionada=""/>
				Element atividadeOrganizacaoDaDocumentacao = new Element("praticaOrganizacaoDaDocumentacao");
				atividadeOrganizacaoDaDocumentacao.setAttribute("selecionada", String.valueOf(projeto.getAtividadeDefinicaoDosRequisitos().getPraticaOrganizacaoDaDocumentacao().isSelecionada()));
				etapaDefinicaoDosRequisitos.addContent(atividadeOrganizacaoDaDocumentacao);
				this.salvarPratica(fileEtapaDefinicaoDosRequisitos,projeto.getAtividadeDefinicaoDosRequisitos().getPraticaOrganizacaoDaDocumentacao(),"praticaOrganizacaoDaDocumentacao" );
			 //</etapaDefinicaoDosRequisitos>
			rootProjeto.addContent(etapaDefinicaoDosRequisitos);

		 //<etapaAtribuicaoDosRequisitos>
			Element etapaAtribuicaoDosRequisitos = new Element("atividadeAtribuicaoDosRequisitos");
			File fileEtapaAtribuicaoDosRequisitos = new File(this.fileProjeto.getCanonicalPath()+ File.separator + "atividadeAtribuicaoDosRequisitos");
				  //<atividadeDistribuicaoDosRequisitos selecionada=""/>
				Element atividadeDistribuicaoDosRequisitos = new Element("praticaDistribuicaoDosRequisitos");
				atividadeDistribuicaoDosRequisitos.setAttribute("selecionada", String.valueOf(projeto.getAtividadeAtribuicaoDosRequisitos().getPraticaDistribuicaoDosRequisitos().isSelecionada()));
				etapaAtribuicaoDosRequisitos.addContent(atividadeDistribuicaoDosRequisitos);
				this.salvarPratica(fileEtapaAtribuicaoDosRequisitos, projeto.getAtividadeAtribuicaoDosRequisitos().getPraticaDistribuicaoDosRequisitos(), "praticaDistribuicaoDosRequisitos");
				  //<atividadePlanejamentoDasIteracoes selecionada=""/>
				Element atividadePlanejamentoDasIteracoes = new Element("praticaPlanejamentoDasIteracoes");
				atividadePlanejamentoDasIteracoes.setAttribute("selecionada", String.valueOf(projeto.getAtividadeAtribuicaoDosRequisitos().getPraticaPlanejamentoDasIteracoes().isSelecionada()));
				etapaAtribuicaoDosRequisitos.addContent(atividadePlanejamentoDasIteracoes);
				this.salvarPratica(fileEtapaAtribuicaoDosRequisitos,projeto.getAtividadeAtribuicaoDosRequisitos().getPraticaPlanejamentoDasIteracoes(), "praticaPlanejamentoDasIteracoes");
				  //<atividadeDuracaoDasIteracoes selecionada=""/>
				Element atividadeDuracaoDasIteracoes = new Element("praticaDuracaoDasIteracoes");
				atividadeDuracaoDasIteracoes.setAttribute("selecionada", String.valueOf(projeto.getAtividadeAtribuicaoDosRequisitos().getPraticaDuracaoDasIteracoes().isSelecionada()));
				etapaAtribuicaoDosRequisitos.addContent(atividadeDuracaoDasIteracoes);
				this.salvarPratica(fileEtapaAtribuicaoDosRequisitos,projeto.getAtividadeAtribuicaoDosRequisitos().getPraticaDuracaoDasIteracoes(), "praticaDuracaoDasIteracoes");
				  //<atividadeAtualizacaoDaDocumentacao selecionada=""/>
				Element atividadeAtualizacaoDaDocumentacao = new Element("praticaAtualizacaoDaDocumentacao");
				atividadeAtualizacaoDaDocumentacao.setAttribute("selecionada", String.valueOf(projeto.getAtividadeAtribuicaoDosRequisitos().getPraticaAtualizacaoDaDocumentacao().isSelecionada()));
				etapaAtribuicaoDosRequisitos.addContent(atividadeAtualizacaoDaDocumentacao);
				this.salvarPratica(fileEtapaAtribuicaoDosRequisitos,projeto.getAtividadeAtribuicaoDosRequisitos().getPraticaAtualizacaoDaDocumentacao(), "praticaAtualizacaoDaDocumentacao");
		 //</etapaAtribuicaoDosRequisitos>
			rootProjeto.addContent(etapaAtribuicaoDosRequisitos);

		 //<etapaProjetoDoSistema>
			Element etapaProjetoDoSistema = new Element("atividadeProjetoDoSistema");
			File fileEtapaProjetoDoSistema = new File (this.fileProjeto.getCanonicalPath()+ File.separator + "atividadeProjetoDoSistema");
				  //<atividadeProjetoGeral selecionada=""/>
				Element atividadeProjetoGeral = new Element("praticaProjetoGeral");
				atividadeProjetoGeral.setAttribute("selecionada", String.valueOf(projeto.getAtividadeProjetoDoSistema().getPraticaProjetoGeral().isSelecionada()));
				etapaProjetoDoSistema.addContent(atividadeProjetoGeral);
				this.salvarPratica(fileEtapaProjetoDoSistema,projeto.getAtividadeProjetoDoSistema().getPraticaProjetoGeral(), "praticaProjetoGeral");
				  //<atividadeProjetoDetalhado selecionada=""/>
				Element atividadeProjetoDetalhado = new Element("praticaProjetoDetalhado");
				atividadeProjetoDetalhado.setAttribute("selecionada", String.valueOf(projeto.getAtividadeProjetoDoSistema().getPraticaProjetoDetalhado().isSelecionada()));
				etapaProjetoDoSistema.addContent(atividadeProjetoDetalhado);
				this.salvarPratica(fileEtapaProjetoDoSistema, projeto.getAtividadeProjetoDoSistema().getPraticaProjetoDetalhado(), "praticaProjetoDetalhado");
				  //<atividadeDocumentacaoDoProjeto selecionada=""/>
				Element atividadeDocumentacaoDoProjeto = new Element("praticaDocumentacaoDoProjeto");
				atividadeDocumentacaoDoProjeto.setAttribute("selecionada", String.valueOf(projeto.getAtividadeProjetoDoSistema().getPraticaDocumentacaoDoProjeto().isSelecionada()));
				etapaProjetoDoSistema.addContent(atividadeDocumentacaoDoProjeto);
				this.salvarPratica(fileEtapaProjetoDoSistema, projeto.getAtividadeProjetoDoSistema().getPraticaDocumentacaoDoProjeto(), "praticaDocumentacaoDoProjeto");
		 //</etapaProjetoDoSistema>
			rootProjeto.addContent(etapaProjetoDoSistema);

		 //<ciclosDeDesenvolvimento>
		  Element ciclosDeDesenvolvimento = new Element("iteracao");
		  List ciclosDeDesenvolvimentoList = projeto.getIteracoes();
		  Iterator it = ciclosDeDesenvolvimentoList.iterator();
		  Iteracao cd = null;
		  while (it.hasNext()){
			  cd = (Iteracao) it.next();

			  //<cicloDeDesenvolvimento numero="">
			  Element cicloDeDesenvolvimento = new Element("iteracao");
			  cicloDeDesenvolvimento.setAttribute("numero", String.valueOf(cd.getNumero()));
			  File fileCicloDeDesenvolvimento = new File(this.fileProjeto.getCanonicalPath()+ File.separator + "iteracao" + cd.getNumero());
			  this.salvarIteracao(fileCicloDeDesenvolvimento, cd);

			   //<etapaDesenvolvierIncrementoDoSistema>
			  Element etapaDesenvolvierIncrementoDoSistema = new Element("atividadeDesenvolvierIncrementoDoSistema");
			  File fileEtapaDesenvolvierIncrementoDoSistema = new File(fileCicloDeDesenvolvimento.getCanonicalPath() + File.separator + "atividadeDesenvolverIncrementoDoSistema");
			      //<atividadeImplementacao selecionada=""/>
				  Element atividadeImplementacao = new Element("praticaImplementacao");
				  atividadeImplementacao.setAttribute("selecionada", String.valueOf(cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaImplementacao().isSelecionada()));
				  etapaDesenvolvierIncrementoDoSistema.addContent(atividadeImplementacao);
				  this.salvarPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaImplementacao(), "praticaImplementacao");
				    //<atividadeEscritaDosTestesAntesDaImplementacao selecionada=""/>
				  Element atividadeEscritaDosTestesAntesDaImplementacao = new Element("praticaEscritaDosTestesAntesDaImplementacao");
				  atividadeEscritaDosTestesAntesDaImplementacao.setAttribute("selecionada", String.valueOf(cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaEscritaDosTestesAntesDaImplementacao().isSelecionada()));
				  etapaDesenvolvierIncrementoDoSistema.addContent(atividadeEscritaDosTestesAntesDaImplementacao);
				  this.salvarPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaEscritaDosTestesAntesDaImplementacao(), "praticaEscritaDosTestesAntesDaImplementacao");
				    //<atividadeDesenvolvimentoColetivo selecionada=""/>
				  Element atividadeDesenvolvimentoColetivo = new Element("praticaDesenvolvimentoColetivo");
				  atividadeDesenvolvimentoColetivo.setAttribute("selecionada", String.valueOf(cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDesenvolvimentoColetivo().isSelecionada()));
				  etapaDesenvolvierIncrementoDoSistema.addContent(atividadeDesenvolvimentoColetivo);
				  this.salvarPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDesenvolvimentoColetivo(), "praticaDesenvolvimentoColetivo");
				    //<atividadeDesenvolvimentoEmDuplas selecionada=""/>
				  Element atividadeDesenvolvimentoEmDuplas = new Element("praticaDesenvolvimentoEmDuplas");
				  atividadeDesenvolvimentoEmDuplas.setAttribute("selecionada", String.valueOf(cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDesenvolvimentoEmDuplas().isSelecionada()));
				  etapaDesenvolvierIncrementoDoSistema.addContent(atividadeDesenvolvimentoEmDuplas);
				  this.salvarPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDesenvolvimentoEmDuplas(), "praticaDesenvolvimentoEmDuplas");
				    //<atividadeDesenvolvimentoLadoALado selecionada=""/>
				  Element atividadeDesenvolvimentoLadoALado = new Element("praticaDesenvolvimentoLadoALado");
				  atividadeDesenvolvimentoLadoALado.setAttribute("selecionada", String.valueOf(cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDesenvolvimentoLadoALado().isSelecionada()));
				  etapaDesenvolvierIncrementoDoSistema.addContent(atividadeDesenvolvimentoLadoALado);
				  this.salvarPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDesenvolvimentoLadoALado(), "praticaDesenvolvimentoLadoALado");
				    //<atividadeRefactoring selecionada=""/>
				  Element atividadeRefactoring = new Element("praticaRefactoring");
				  atividadeRefactoring.setAttribute("selecionada", String.valueOf(cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaRefactoring().isSelecionada()));
				  etapaDesenvolvierIncrementoDoSistema.addContent(atividadeRefactoring);
				  this.salvarPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaRefactoring(), "praticaRefactoring");
				    //<atividadeReunioesDiarias selecionada=""/>
				  Element atividadeReunioesDiarias = new Element("praticaReunioesDiarias");
				  atividadeReunioesDiarias.setAttribute("selecionada", String.valueOf(cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaReunioesDiarias().isSelecionada()));
				  etapaDesenvolvierIncrementoDoSistema.addContent(atividadeReunioesDiarias);
				  this.salvarPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaReunioesDiarias(), "praticaReunioesDiarias");
				    //<atividadeDesenvolvimentoSimultaneo selecionada=""/>
				  Element atividadeDesenvolvimentoSimultaneo = new Element("praticaDesenvolvimentoSimultaneo");
				  atividadeDesenvolvimentoSimultaneo.setAttribute("selecionada", String.valueOf(cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDesenvolvimentoSimultaneo().isSelecionada()));
				  etapaDesenvolvierIncrementoDoSistema.addContent(atividadeDesenvolvimentoSimultaneo);
				  this.salvarPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDesenvolvimentoSimultaneo(), "praticaDesenvolvimentoSimultaneo");
				    //<atividadeIntegracaoParalela selecionada=""/>
				  Element atividadeIntegracaoParalela = new Element("praticaIntegracaoParalela");
				  atividadeIntegracaoParalela.setAttribute("selecionada", String.valueOf(cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaIntegracaoParalela().isSelecionada()));
				  etapaDesenvolvierIncrementoDoSistema.addContent(atividadeIntegracaoParalela);
				  this.salvarPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaIntegracaoParalela(),"praticaIntegracaoParalela");
				    //<atividadeDocumentacaoDoDesenvolvimento selecionada=""/>
				  Element atividadeDocumentacaoDoDesenvolvimento  = new Element("praticaDocumentacaoDoDesenvolvimento");
				  atividadeDocumentacaoDoDesenvolvimento.setAttribute("selecionada", String.valueOf(cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDocumentacaoDoDesenvolvimento().isSelecionada()));
				  etapaDesenvolvierIncrementoDoSistema.addContent(atividadeDocumentacaoDoDesenvolvimento);
				  this.salvarPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDocumentacaoDoDesenvolvimento(), "praticaDocumentacaoDoDesenvolvimento");
				    //<atividadeControleDeVersoes selecionada=""/>
				  Element atividadeControleDeVersoes = new Element("praticaControleDeVersoes");
				  atividadeControleDeVersoes.setAttribute("selecionada", String.valueOf(cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaControleDeVersoes().isSelecionada()));
				  etapaDesenvolvierIncrementoDoSistema.addContent(atividadeControleDeVersoes);
				  this.salvarPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaControleDeVersoes(), "praticaControleDeVersoes");
			   //</etapaDesenvolvierIncrementoDoSistema>
			  cicloDeDesenvolvimento.addContent(etapaDesenvolvierIncrementoDoSistema);

			   //<etapaValidarIncremento>
			  Element etapaValidarIncremento = new Element("atividadeValidarIncremento");
			  File fileEtapaValidarIncremento = new File(fileCicloDeDesenvolvimento.getCanonicalPath() + File.separator + "atividadeValidarIncremento");
			      //<atividadeExecucaoDosTestes selecionada=""/>
				  Element atividadeExecucaoDosTestes = new Element("praticaExecucaoDosTestes");
				  atividadeExecucaoDosTestes.setAttribute("selecionada", String.valueOf(cd.getAtividadeValidarIncremento().getPraticaExecucaoDosTestes().isSelecionada()));
				  etapaValidarIncremento.addContent(atividadeExecucaoDosTestes);
				  this.salvarPratica(fileEtapaValidarIncremento, cd.getAtividadeValidarIncremento().getPraticaExecucaoDosTestes(), "praticaExecucaoDosTestes");
				    //<atividadeIntegracaoAntesDaValidacao selecionada=""/>
				  Element atividadeIntegracaoAntesDaValidacao  = new Element("praticaIntegracaoAntesDaValidacao");
				  atividadeIntegracaoAntesDaValidacao.setAttribute("selecionada", String.valueOf(cd.getAtividadeValidarIncremento().getPraticaIntegracaoAntesDaValidacao().isSelecionada()));
				  etapaValidarIncremento.addContent(atividadeIntegracaoAntesDaValidacao);
				  this.salvarPratica(fileEtapaValidarIncremento, cd.getAtividadeValidarIncremento().getPraticaIntegracaoAntesDaValidacao(), "praticaIntegracaoAntesDaValidacao");
				    //<atividadeInspecaoDeCodigo selecionada=""/>
				  Element atividadeInspecaoDeCodigo  = new Element("praticaInspecaoDeCodigo");
				  atividadeInspecaoDeCodigo.setAttribute("selecionada", String.valueOf(cd.getAtividadeValidarIncremento().getPraticaInspecaoDeCodigo().isSelecionada()));
				  etapaValidarIncremento.addContent(atividadeInspecaoDeCodigo);
				  this.salvarPratica(fileEtapaValidarIncremento, cd.getAtividadeValidarIncremento().getPraticaInspecaoDeCodigo(),"praticaInspecaoDeCodigo");
			   //</etapaValidarIncremento>
			  cicloDeDesenvolvimento.addContent(etapaValidarIncremento);

			   //<etapaIntegracaoIncremento>
			  Element etapaIntegracaoIncremento = new Element("atividadeIntegracaoIncremento");
			  File fileEtapaIntegracaoIncremento = new File(fileCicloDeDesenvolvimento.getCanonicalPath() + File.separator + "atividadeIntegracaoIncremento");
			      //<atividadeIntegracaoDepoisDaValidacao selecionada=""/>
				  Element atividadeIntegracaoDepoisDaValidacao = new Element("praticaIntegracaoDepoisDaValidacao");
				  atividadeIntegracaoDepoisDaValidacao.setAttribute("selecionada", String.valueOf(cd.getAtividadeIntegracaoIncremento().getPraticaIntegracaoDepoisDaValidacao().isSelecionada()));
				  etapaIntegracaoIncremento.addContent(atividadeIntegracaoDepoisDaValidacao);
				  this.salvarPratica(fileEtapaIntegracaoIncremento, cd.getAtividadeIntegracaoIncremento().getPraticaIntegracaoDepoisDaValidacao(), "praticaIntegracaoDepoisDaValidacao");
			   //</etapaIntegracaoIncremento>
			  cicloDeDesenvolvimento.addContent(etapaIntegracaoIncremento);

			   //<etapaValidarSistema>
			  Element etapaValidarSistema = new Element("atividadeValidarSistema");
			  File fileEtapaValidarSistema = new File(fileCicloDeDesenvolvimento.getCanonicalPath() + File.separator + "atividadeValidarSistema");
			      //<atividadeReuniaoDeRevisao selecionada=""/>
				  Element atividadeReuniaoDeRevisao = new Element("praticaReuniaoDeRevisao");
				  atividadeReuniaoDeRevisao.setAttribute("selecionada", String.valueOf(cd.getAtividadeValidarSistema().getPraticaReuniaoDeRevisao().isSelecionada()));
				  etapaValidarSistema.addContent(atividadeReuniaoDeRevisao);
				  this.salvarPratica(fileEtapaValidarSistema, cd.getAtividadeValidarSistema().getPraticaReuniaoDeRevisao(), "praticaReuniaoDeRevisao");
				    //<atividadeColocarSistemaEmOperacao selecionada=""/>
				  Element atividadeColocarSistemaEmOperacao = new Element("praticaColocarSistemaEmOperacao");
				  atividadeColocarSistemaEmOperacao.setAttribute("selecionada", String.valueOf(cd.getAtividadeValidarSistema().getPraticaColocarSistemaEmOperacao().isSelecionada()));
				  etapaValidarSistema.addContent(atividadeColocarSistemaEmOperacao);
				  this.salvarPratica(fileEtapaValidarSistema, cd.getAtividadeValidarSistema().getPraticaColocarSistemaEmOperacao(), "praticaColocarSistemaEmOperacao");
			   //</etapaValidarSistema>
			  cicloDeDesenvolvimento.addContent(etapaValidarSistema);

			  //</cicloDeDesenvolvimento>
			  ciclosDeDesenvolvimento.addContent(cicloDeDesenvolvimento);
		  }
		 //</ciclosDeDesenvolvimento>
		  rootProjeto.addContent(ciclosDeDesenvolvimento);

		 //<etapaEntregaFinal>
		  Element etapaEntregaFinal = new Element("atividadeEntregaFinal");
		  File fileEtapaEntregaFinal = new File (this.fileProjeto.getCanonicalPath()+ File.separator + "atividadeEntregaFinal");
		    //<atividadeEntregaDoSistema selecionada=""/>
			  Element atividadeEntregaDoSistema  = new Element("praticaEntregaDoSistema");
			  atividadeEntregaDoSistema.setAttribute("selecionada", String.valueOf(projeto.getAtividadeEntregaFinal().getPraticaEntregaDoSistema().isSelecionada()));
			  etapaEntregaFinal.addContent(atividadeEntregaDoSistema);
			  this.salvarPratica(fileEtapaEntregaFinal, projeto.getAtividadeEntregaFinal().getPraticaEntregaDoSistema(), "praticaEntregaDoSistema");
			  //<atividadeBreveDocumentacao selecionada=""/>
			  Element atividadeBreveDocumentacao  = new Element("praticaBreveDocumentacao");
			  atividadeBreveDocumentacao.setAttribute("selecionada", String.valueOf(projeto.getAtividadeEntregaFinal().getPraticaBreveDocumentacao().isSelecionada()));
			  etapaEntregaFinal.addContent(atividadeBreveDocumentacao);
			  this.salvarPratica(fileEtapaEntregaFinal, projeto.getAtividadeEntregaFinal().getPraticaBreveDocumentacao(), "praticaBreveDocumentacao");
			  //<atividadeRefinamentoDaDocumentacao selecionada=""/>
			  Element atividadeRefinamentoDaDocumentacao  = new Element("praticaRefinamentoDaDocumentacao");
			  atividadeRefinamentoDaDocumentacao.setAttribute("selecionada", String.valueOf(projeto.getAtividadeEntregaFinal().getPraticaRefinamentoDaDocumentacao().isSelecionada()));
			  etapaEntregaFinal.addContent(atividadeRefinamentoDaDocumentacao);
			  this.salvarPratica(fileEtapaEntregaFinal, projeto.getAtividadeEntregaFinal().getPraticaRefinamentoDaDocumentacao(), "praticaRefinamentoDaDocumentacao");
			  //<atividadeElaboracaoDoManual selecionada=""/>
			  Element atividadeElaboracaoDoManual  = new Element("praticaElaboracaoDoManual");
			  atividadeElaboracaoDoManual.setAttribute("selecionada", String.valueOf(projeto.getAtividadeEntregaFinal().getPraticaElaboracaoDoManual().isSelecionada()));
			  etapaEntregaFinal.addContent(atividadeElaboracaoDoManual);
			  this.salvarPratica(fileEtapaEntregaFinal, projeto.getAtividadeEntregaFinal().getPraticaElaboracaoDoManual(),"praticaElaboracaoDoManual");
		 //</etapaEntregaFinal>
		  rootProjeto.addContent(etapaEntregaFinal);

		//</projeto>
		  Document doc = new Document(rootProjeto);
		  XMLOutputter outputter = new XMLOutputter();
		  outputter.output(doc, new FileOutputStream(fileProjetoXML));


}

	private void salvarIteracao(File fileCaminho, Iteracao  iteracao) throws IOException{
		File fileCicloDeDesenvolvimentoXML = new File(fileCaminho.getCanonicalPath() + File.separator + "iteracao.fcama");

		//<cicloDeDesenvolvimento numero="">
		Element rootCicloDeDesenvolvimento = new Element("iteracao");
		rootCicloDeDesenvolvimento.setAttribute("numero", String.valueOf(iteracao.getNumero()));
			//<dtInicioPrevista></dtInicioPrevista>
			Element dtInicioPrevista = new Element("dtInicioPrevista");
			if(iteracao.getDtInicioPrevista() != null){
				dtInicioPrevista.setText(String.valueOf(iteracao.getDtInicioPrevista().getTime()));
			}
			rootCicloDeDesenvolvimento.addContent(dtInicioPrevista);
			//<dtFimPrevista></dtFimPrevista>
			Element dtFimPrevista = new Element("dtFimPrevista");
			if(iteracao.getDtFimPrevista() != null){
				dtFimPrevista.setText(String.valueOf(iteracao.getDtFimPrevista().getTime()));
			}
			rootCicloDeDesenvolvimento.addContent(dtFimPrevista);
			//<dtInicioEfetiva></dtInicioEfetiva>
			Element dtInicioEfetiva = new Element("dtInicioEfetiva");
			if(iteracao.getDtInicioEfetiva() != null){
				dtInicioEfetiva.setText(String.valueOf(iteracao.getDtInicioEfetiva().getTime()));
			}
			rootCicloDeDesenvolvimento.addContent(dtInicioEfetiva);
			//<dtFimEfetiva></dtFimEfetiva>
			Element dtFimEfetiva = new Element("dtFimEfetiva");
			if(iteracao.getDtFimEfetiva() != null){
				dtFimEfetiva.setText(String.valueOf(iteracao.getDtFimEfetiva().getTime()));
			}
			rootCicloDeDesenvolvimento.addContent(dtFimEfetiva);

			//<requisitos>
			Element requisitos = new Element("requisitos");
			List requisitosList = iteracao.getRequisitos();
			Iterator it = requisitosList.iterator();
			Requisito r = null;
			while (it.hasNext()){
				r = (Requisito) it.next();
				//<requisito tipo="">
				Element requisito = new Element("requisito");
				requisito.setAttribute("tipo", r.getClass().getName());
			    	//<nome></nome>
					Element nome = new Element("nome");
					nome.setText(r.getNome());
					requisito.addContent(nome);
			   //</requisito>
				requisitos.addContent(requisito);
			}
			//</requisitos>
			rootCicloDeDesenvolvimento.addContent(requisitos);

		//</cicloDeDesenvolvimento>
		 Document doc = new Document(rootCicloDeDesenvolvimento);
		 XMLOutputter outputter = new XMLOutputter();
		 outputter.output(doc, new FileOutputStream(fileCicloDeDesenvolvimentoXML));
	}
	private   void salvarPratica(File fileEtapa, Pratica pratica, String nomePratica) throws IOException{
		if(pratica.isSelecionada()){
			File fileAtividadeXML = new File(fileEtapa.getCanonicalPath() + File.separator + nomePratica + ".fcama");

			//<atividade classAtividade="">
			Element rootAtividade = new Element("pratica");
			rootAtividade.setAttribute("classPratica", pratica.getClass().getName());

			 //<observacao></observacao>
			Element observacao = new Element("observacao");
			observacao.setText(pratica.getObservacao());
			rootAtividade.addContent(observacao);

		 //<anexos>
			Element anexos = new Element("anexos");
			List atividadeList = pratica.getAnexos();
			Iterator it = atividadeList.iterator();
			Anexo ax = null;
			while(it.hasNext()){
				ax = (Anexo) it.next();
			  //<anexo>
				Element anexo = new Element("anexo");
				
					//<caminho></caminho>
					Element caminho = new Element("caminho");
					caminho.setText(ax.getCaminho());
					anexo.addContent(caminho);
				   //<descricao></descricao>
					Element descricao = new Element("descricao");
					descricao.setText(ax.getDescricao());
					anexo.addContent(descricao);
				   //<nome></nome>
					Element nome = new Element("nome");
					nome.setText(ax.getNome());
					anexo.addContent(nome);
				   //<dtCriacao></dtCriacao>
					Element dtCriacao = new Element("dtCriacao");
					if(ax.getDtCriacao() != null){
						dtCriacao.setText(String.valueOf(ax.getDtCriacao().getTime()));
					}
					anexo.addContent(dtCriacao);
				   //<dtAlteracao></dtAlteracao>
					Element dtAlteracao = new Element("dtAlteracao");
					if(ax.getDtAlteracao() != null){
						dtAlteracao.setText(String.valueOf(ax.getDtAlteracao().getTime()));
					}
					anexo.addContent(dtAlteracao);
			  //</anexo>
				anexos.addContent(anexo);
			}
			 //</anexos>
			rootAtividade.addContent(anexos);
			
			//<!-- caso seja AtividadeDesenvolvimento em duplas ou desemvolvimentoLadoALado  -->
			if(pratica.getClass() == PraticaDesenvolvimentoEmDuplas.class ||
					pratica.getClass() == PraticaDesenvolvimentoLadoALado.class ){
				List duplasList = null;
				if (pratica.getClass() == PraticaDesenvolvimentoEmDuplas.class ){
					duplasList = ((PraticaDesenvolvimentoEmDuplas)pratica).getDuplas();
				}else {
					duplasList = ((PraticaDesenvolvimentoLadoALado)pratica).getDuplas();
				}

			 //<duplas>
				Element duplas = new Element("duplas");
				Iterator itd = duplasList.iterator();
				DuplaDesenvolvimento dd = null;
				while(itd.hasNext()){
					dd = (DuplaDesenvolvimento)itd.next();
				  //<dupla>
					Element dupla = new Element("dupla");
				   //<stakeholder1>
					Element stakeholder1 = new Element("stakeholder1");
						//<nome></nome>
						Element nome1 = new Element("nome");
						nome1.setText(dd.getStakeholder1().getNome());
						stakeholder1.addContent(nome1);
						//<funcao></funcao>
						Element funcao1 = new Element("funcao");
						funcao1.setText(dd.getStakeholder1().getFuncao());
						stakeholder1.addContent(funcao1);
						//</stakeholder1>
					dupla.addContent(stakeholder1);
				   //<stakeholder2>
					Element stakeholder2 = new Element("stakeholder2");
						//<nome></nome>
						Element nome2 = new Element("nome");
						nome2.setText(dd.getStakeholder2().getNome());
						stakeholder2.addContent(nome2);
						//<funcao></funcao
						Element funcao2 = new Element("funcao");
						funcao2.setText(dd.getStakeholder2().getFuncao());
						stakeholder2.addContent(funcao2);
					//</stakeholder2>
					dupla.addContent(stakeholder2);
				  //</dupla>
					duplas.addContent(dupla);
				}
			 //</duplas>
			rootAtividade.addContent(duplas);
		}



			//<!-- caso seja AtividadeAtividadeListaDeRequisitos ou AtividadeUserStories ou DocumentacaoDetalhada -->
			if (pratica.getClass() == PraticaListaDeRequisitos.class ||
					pratica.getClass() == PraticaUserStories.class ||
					pratica.getClass() == PraticaDocumentacaoDetalhada.class){
				List requisitosList = null;
				if(pratica.getClass() == PraticaListaDeRequisitos.class){
					requisitosList = ((PraticaListaDeRequisitos)pratica).getRequisitos();
				}else if (pratica.getClass() == PraticaUserStories.class){
					requisitosList = ((PraticaUserStories)pratica).getUserStories();
				}else {
					requisitosList = ((PraticaDocumentacaoDetalhada)pratica).getRequisitosAnexos();
				}
			 //<requisitos>
				Element requisitos = new Element("requisitos");
				Iterator itr = requisitosList.iterator();
				Requisito rq = null;
				while(itr.hasNext()){
					rq = (Requisito)itr.next();
				  //<requisito>
					Element requisito = new Element("requisito");
				    //<prioridade></prioridade>
					Element prioridade = new Element("prioridade");
					prioridade.setText(rq.getPrioridade());
					requisito.addContent(prioridade);
				    //<nome></nome>
					Element nome = new Element("nome");
					nome.setText(rq.getNome());
					requisito.addContent(nome);
				    //<ordem></ordem>
					Element ordem = new Element("ordem");
					ordem.setText(String.valueOf(rq.getOrdem()));
					requisito.addContent(ordem);
				    //<descricao></descricao>
					Element descricao = new Element("descricao");
					descricao.setText(rq.getDescricao());
					requisito.addContent(descricao);
				    //<tempoEstimado></tempoEstimado>
					Element tempoEstimado = new Element("tempoEstimado");
					tempoEstimado.setText(String.valueOf(rq.getTempoEstimado()));
					requisito.addContent(tempoEstimado);
				    //<dtInicio></dtInicio>
					Element dtInicio = new Element("dtInicio");
					if (rq.getDtInicio() != null){
						dtInicio.setText(String.valueOf(rq.getDtInicio().getTime()));
					}
					requisito.addContent(dtInicio);
				    //<dtFim></dtFim>
					Element dtFim = new Element("dtFim");
					if (rq.getDtFim() != null){
						dtFim.setText(String.valueOf(rq.getDtFim().getTime()));
					}
					requisito.addContent(dtFim);
					//<dtInicioPrevisto></dtInicioPrevisto>
					Element dtInicioPrevisto = new Element("dtInicioPrevisto");
					if (rq.getDtInicioPrevisto() != null){
						dtInicioPrevisto.setText(String.valueOf(rq.getDtInicioPrevisto().getTime()));
					}
					requisito.addContent(dtInicioPrevisto);
					//<dtInicioPrevisto></dtInicioPrevisto>
					Element dtFimPrevisto = new Element("dtFimPrevisto");
					if (rq.getDtFimPrevisto() != null){
						dtFimPrevisto.setText(String.valueOf(rq.getDtFimPrevisto().getTime()));
					}
					requisito.addContent(dtFimPrevisto);
				    //<responsaveis>
					Element responsaveis = new Element("responsaveis");
					List responsaveisList = rq.getResponsaveis();
					Iterator itres = responsaveisList.iterator();
					Stakeholder stakeholder = null;
					while(itres.hasNext()){
						stakeholder = (Stakeholder)itres.next();
				     //<responsavel>
						Element responsavel = new Element("responsavel");
					  //<nome></nome>
						Element nomeR = new Element("nome");
						nomeR.setText(stakeholder.getNome());
						responsavel.addContent(nomeR);
				      //<funcao></funcao>
						Element funcaoR = new Element("funcao");
						funcaoR.setText(stakeholder.getFuncao());
						responsavel.addContent(funcaoR);
				     //</responsavel>
						responsaveis.addContent(responsavel);
					}
				    //</responsaveis>
					requisito.addContent(responsaveis);
				    //<estado></estado>
					Element estado = new Element("estado");
					estado.setText(rq.getEstado());
					requisito.addContent(estado);
				    //<nuCincloDeDesenvolvimento></nuCincloDeDesenvolvimento>
					Element nuCincloDeDesenvolvimento = new Element("nuIteracao");
					nuCincloDeDesenvolvimento.setText(String.valueOf(rq.getNuCincloDeDesenvolvimento()));
					requisito.addContent(nuCincloDeDesenvolvimento);

				//<!-- caso seja AtividadeUserStories -->
					if (pratica.getClass() == PraticaUserStories.class){
						//<nota></nota>
						Element nota = new Element("nota");
						nota.setText(((UserStory)rq).getNota());
						requisito.addContent(nota);
				    	//<referencias>
						Element referencias = new Element("referencias");
						List referenciasList = ((UserStory)rq).getReferencias();
						Iterator itRe = referenciasList.iterator();
						Requisito rqR = null;
						while(itRe.hasNext()){
							rqR = (Requisito)itRe.next();
				      		//<nome></nome>
							Element nomeRef = new Element("nome");
							nomeRef.setText(rqR.getNome());
							referencias.addContent(nomeRef);
						}
				    	//</referencias>
						requisito.addContent(referencias);
					}
				//<!-- caso seja AtividadeUserStories -->
					
				//caso seja a praticaDocumentacaoDetalhada
				if (pratica.getClass() == PraticaDocumentacaoDetalhada.class){
					//<anexos>
					Element anexosReq = new Element("anexos");
					List rqList = ((RequisitoAnexo)rq).getAnexos();
					Iterator itRq = rqList.iterator();
					Anexo axReq = null;
					while(itRq.hasNext()){
						axReq = (Anexo) itRq.next();
					  //<anexo>
						Element anexo = new Element("anexo");
						
							//<caminho></caminho>
							Element caminho = new Element("caminho");
							caminho.setText(axReq.getCaminho());
							anexo.addContent(caminho);
						   //<descricao></descricao>
							Element descricaoD = new Element("descricao");
							descricaoD.setText(axReq.getDescricao());
							anexo.addContent(descricaoD);
						   //<nome></nome>
							Element nomeD = new Element("nome");
							nomeD.setText(axReq.getNome());
							anexo.addContent(nomeD);
						   //<dtCriacao></dtCriacao>
							Element dtCriacao = new Element("dtCriacao");
							if(axReq.getDtCriacao() != null){
								dtCriacao.setText(String.valueOf(axReq.getDtCriacao().getTime()));
							}
							anexo.addContent(dtCriacao);
						   //<dtAlteracao></dtAlteracao>
							Element dtAlteracao = new Element("dtAlteracao");
							if(axReq.getDtAlteracao() != null){
								dtAlteracao.setText(String.valueOf(axReq.getDtAlteracao().getTime()));
							}
							anexo.addContent(dtAlteracao);
					  //</anexo>
							anexosReq.addContent(anexo);
					}
					 //</anexos>
					requisito.addContent(anexosReq);
				//Fim caso seja a praticaDocumentacaoDetalhada
				}

				  //</requisito>
					requisitos.addContent(requisito);
				}
			 //</requisitos>
				rootAtividade.addContent(requisitos);
			}

			//</atividade>
			Document doc = new Document(rootAtividade);
			XMLOutputter outputter = new XMLOutputter();
			outputter.output(doc, new FileOutputStream(fileAtividadeXML));
		}
	}
	private void salvarStakeholder(File fileProjeto, Projeto projeto) throws IOException{
		File fileStakeholderXML = new File(fileProjeto.getCanonicalPath() + File.separator + "stakeholder.fcama");
		//<stakeholders>
		Element rootStakeholders = new Element("stakeholders");
		List stakeholdersList = projeto.getStakeholders();
		Iterator it = stakeholdersList.iterator();
		Stakeholder sh = null;
		while(it.hasNext()){
			sh =(Stakeholder)it.next();
			//<stakeholder>
			Element stakeholder = new Element("stakeholder");
				  //<nome></nome>
				Element nome = new Element("nome");
				nome.setText(sh.getNome());
				stakeholder.addContent(nome);
				  //<funcao></funcao>
				Element funcao = new Element("funcao");
				funcao.setText(sh.getFuncao());
				stakeholder.addContent(funcao);
			//</stakeholder>
			rootStakeholders.addContent(stakeholder);
		}
		//</stakeholders>
		 Document doc = new Document(rootStakeholders);
		 XMLOutputter outputter = new XMLOutputter();
		 outputter.output(doc, new FileOutputStream(fileStakeholderXML));
	}


	public  Projeto getProjeto() throws IOException, JDOMException, ExceptionPraticaNaoLiberada, ExceptionInclusaoPraticaNaoPermitida, ExceptionExclusaoPraticaNaoPermitida{
		//para colocar os requisitos
		HashMap requisitosHash = new HashMap();
		HashMap stakeholderHash = new HashMap();

		Projeto projeto = new Projeto();
		SAXBuilder parser = new SAXBuilder();
	   	Document bDoc = parser.build(new File(this.fileProjeto.getCanonicalPath()+ File.separator + "projeto.fcama"));

		this.getStakeholder(this.fileProjeto, projeto, stakeholderHash);
		//<projeto nomeProjeto="">
		Element rootProjeto = bDoc.getRootElement();
		projeto.setNomeProjeto(rootProjeto.getAttributeValue("nomeProjeto"));
			// <etapaDefinicaoDosRequisitos>
			Element etapaDefinicaoDosRequisitos = rootProjeto.getChild("atividadeDefinicaoDosRequisitos");
			File fileEtapaDefinicaoDosRequisitos = new File(this.fileProjeto.getCanonicalPath()+ File.separator + "atividadeDefinicaoDosRequisitos");

				//<atividadeUserStories selecionada=""/>
				Element atividadeUserStories = etapaDefinicaoDosRequisitos.getChild("praticaUserStories");
				if (Boolean.valueOf(atividadeUserStories.getAttributeValue("selecionada")).booleanValue()){
					projeto.incluindoExcluindoPratica(PraticaUserStories.class,Constantes.INCLUSAO);
					this.getPratica(fileEtapaDefinicaoDosRequisitos,projeto.getAtividadeDefinicaoDosRequisitos().getPraticaUserStories(), "praticaUserStories", requisitosHash, stakeholderHash);
				}

				 //<atividadeListaDeRequisitos selecionada=""/>
				Element atividadeListaDeRequisitos = etapaDefinicaoDosRequisitos.getChild("praticaListaDeRequisitos");
				if (Boolean.valueOf(atividadeListaDeRequisitos.getAttributeValue("selecionada")).booleanValue()){
					projeto.incluindoExcluindoPratica(PraticaListaDeRequisitos.class,Constantes.INCLUSAO);
					this.getPratica(fileEtapaDefinicaoDosRequisitos,projeto.getAtividadeDefinicaoDosRequisitos().getPraticaListaDeRequisitos(), "praticaListaDeRequisitos", requisitosHash, stakeholderHash);
				}

				//<atividadeDocumentacaoDetalhada selecionada=""/>
				Element atividadeDocumentacaoDetalhada = etapaDefinicaoDosRequisitos.getChild("praticaDocumentacaoDetalhada");
				if (Boolean.valueOf(atividadeDocumentacaoDetalhada.getAttributeValue("selecionada")).booleanValue()){
					projeto.incluindoExcluindoPratica(PraticaDocumentacaoDetalhada.class,Constantes.INCLUSAO);
					this.getPratica(fileEtapaDefinicaoDosRequisitos,projeto.getAtividadeDefinicaoDosRequisitos().getPraticaDocumentacaoDetalhada(), "praticaDocumentacaoDetalhada", requisitosHash, stakeholderHash);
				}

				 //<atividadeOrganizacaoDaDocumentacao selecionada=""/>
				Element atividadeOrganizacaoDaDocumentacao = etapaDefinicaoDosRequisitos.getChild("praticaOrganizacaoDaDocumentacao");
				if (Boolean.valueOf(atividadeOrganizacaoDaDocumentacao.getAttributeValue("selecionada")).booleanValue()){
					projeto.incluindoExcluindoPratica(PraticaOrganizacaoDaDocumentacao.class,Constantes.INCLUSAO);
					this.getPratica(fileEtapaDefinicaoDosRequisitos,projeto.getAtividadeDefinicaoDosRequisitos().getPraticaOrganizacaoDaDocumentacao(), "praticaOrganizacaoDaDocumentacao", null, null);
				}

				 //</etapaDefinicaoDosRequisitos>

		 //<etapaAtribuicaoDosRequisitos>
			Element etapaAtribuicaoDosRequisitos = rootProjeto.getChild("atividadeAtribuicaoDosRequisitos");
			File fileEtapaAtribuicaoDosRequisitos = new File(this.fileProjeto.getCanonicalPath()+ File.separator + "atividadeAtribuicaoDosRequisitos");

				  //<atividadeDistribuicaoDosRequisitos selecionada=""/>
				Element atividadeDistribuicaoDosRequisitos = etapaAtribuicaoDosRequisitos.getChild("praticaDistribuicaoDosRequisitos");
				if (Boolean.valueOf(atividadeDistribuicaoDosRequisitos.getAttributeValue("selecionada")).booleanValue()){
					projeto.incluindoExcluindoPratica(PraticaDistribuicaoDosRequisitos.class,Constantes.INCLUSAO);
					this.getPratica(fileEtapaAtribuicaoDosRequisitos,projeto.getAtividadeAtribuicaoDosRequisitos().getPraticaDistribuicaoDosRequisitos(), "praticaDistribuicaoDosRequisitos", null, null);
				}
				 //<atividadePlanejamentoDasIteracoes selecionada=""/>
				Element atividadePlanejamentoDasIteracoes = etapaAtribuicaoDosRequisitos.getChild("praticaPlanejamentoDasIteracoes");
				if (Boolean.valueOf(atividadePlanejamentoDasIteracoes.getAttributeValue("selecionada")).booleanValue()){
					projeto.incluindoExcluindoPratica(PraticaPlanejamentoDasIteracoes.class,Constantes.INCLUSAO);
					this.getPratica(fileEtapaAtribuicaoDosRequisitos,projeto.getAtividadeAtribuicaoDosRequisitos().getPraticaPlanejamentoDasIteracoes(), "praticaPlanejamentoDasIteracoes", null, null);
				}

				//<atividadeDuracaoDasIteracoes selecionada=""/>
				Element atividadeDuracaoDasIteracoes = etapaAtribuicaoDosRequisitos.getChild("praticaDuracaoDasIteracoes");
				if (Boolean.valueOf(atividadeDuracaoDasIteracoes.getAttributeValue("selecionada")).booleanValue()){
					projeto.incluindoExcluindoPratica(PraticaDuracaoDasIteracoes.class,Constantes.INCLUSAO);
					this.getPratica(fileEtapaAtribuicaoDosRequisitos,projeto.getAtividadeAtribuicaoDosRequisitos().getPraticaDuracaoDasIteracoes(), "praticaDuracaoDasIteracoes", null, null);
				}

				//<atividadeAtualizacaoDaDocumentacao selecionada=""/>
				Element atividadeAtualizacaoDaDocumentacao = etapaAtribuicaoDosRequisitos.getChild("praticaAtualizacaoDaDocumentacao");
				if (Boolean.valueOf(atividadeAtualizacaoDaDocumentacao.getAttributeValue("selecionada")).booleanValue()){
					projeto.incluindoExcluindoPratica(PraticaAtualizacaoDaDocumentacao.class,Constantes.INCLUSAO);
					this.getPratica(fileEtapaAtribuicaoDosRequisitos,projeto.getAtividadeAtribuicaoDosRequisitos().getPraticaAtualizacaoDaDocumentacao(), "praticaAtualizacaoDaDocumentacao", null, null);
				}

		 //</etapaAtribuicaoDosRequisitos>

		 //<etapaProjetoDoSistema>
			Element etapaProjetoDoSistema = rootProjeto.getChild("atividadeProjetoDoSistema");
			File fileEtapaProjetoDoSistema = new File (this.fileProjeto.getCanonicalPath()+ File.separator + "atividadeProjetoDoSistema");

				  //<atividadeProjetoGeral selecionada=""/>
				Element atividadeProjetoGeral = etapaProjetoDoSistema.getChild("praticaProjetoGeral");
				if (Boolean.valueOf(atividadeProjetoGeral.getAttributeValue("selecionada")).booleanValue()){
					projeto.incluindoExcluindoPratica(PraticaProjetoGeral.class,Constantes.INCLUSAO);
					this.getPratica(fileEtapaProjetoDoSistema,projeto.getAtividadeProjetoDoSistema().getPraticaProjetoGeral(), "praticaProjetoGeral", null, null);
				}

				//<atividadeProjetoDetalhado selecionada=""/>
				Element atividadeProjetoDetalhado = etapaProjetoDoSistema.getChild("praticaProjetoDetalhado");
				if (Boolean.valueOf(atividadeProjetoDetalhado.getAttributeValue("selecionada")).booleanValue()){
					projeto.incluindoExcluindoPratica(PraticaProjetoDetalhado.class,Constantes.INCLUSAO);
					this.getPratica(fileEtapaProjetoDoSistema,projeto.getAtividadeProjetoDoSistema().getPraticaProjetoDetalhado(), "praticaProjetoDetalhado", null, null);
				}

				 //<atividadeDocumentacaoDoProjeto selecionada=""/>
				Element atividadeDocumentacaoDoProjeto = etapaProjetoDoSistema.getChild("praticaDocumentacaoDoProjeto");
				if (Boolean.valueOf(atividadeDocumentacaoDoProjeto.getAttributeValue("selecionada")).booleanValue()){
					projeto.incluindoExcluindoPratica(PraticaDocumentacaoDoProjeto.class,Constantes.INCLUSAO);
					this.getPratica(fileEtapaProjetoDoSistema,projeto.getAtividadeProjetoDoSistema().getPraticaDocumentacaoDoProjeto(), "praticaDocumentacaoDoProjeto", null, null);
				}

		 //</etapaProjetoDoSistema>

		 //<ciclosDeDesenvolvimento>
		  Element ciclosDeDesenvolvimento = rootProjeto.getChild("iteracao");
		  List ciclosDeDesenvolvimentoList = ciclosDeDesenvolvimento.getChildren("iteracao");
		  Iterator it = ciclosDeDesenvolvimentoList.iterator();
		  Iteracao cd = null;
		  while (it.hasNext()){
			  if (cd == null){//entra no primeiro ciclo, pois nesse no precisa fazer o add e tem que dizer quais atividades esto selecionadas
				  cd = (Iteracao)projeto.getIteracoes().iterator().next();

				  //<cicloDeDesenvolvimento numero="">
				  Element cicloDeDesenvolvimento = (Element) it.next();
				  cd.setNumero(Integer.valueOf(cicloDeDesenvolvimento.getAttributeValue("numero")).intValue());
				  File fileCicloDeDesenvolvimento = new File(this.fileProjeto.getCanonicalPath()+ File.separator + "iteracao" + cd.getNumero());
				  this.getIteracao(fileCicloDeDesenvolvimento, cd, requisitosHash);

				   //<etapaDesenvolvierIncrementoDoSistema>
				  Element etapaDesenvolvierIncrementoDoSistema = cicloDeDesenvolvimento.getChild("atividadeDesenvolvierIncrementoDoSistema");
				  File fileEtapaDesenvolvierIncrementoDoSistema = new File(fileCicloDeDesenvolvimento.getCanonicalPath() + File.separator + "atividadeDesenvolverIncrementoDoSistema");

				  	//<atividadeImplementacao selecionada=""/>
					  Element atividadeImplementacao = etapaDesenvolvierIncrementoDoSistema.getChild("praticaImplementacao");
					  if (Boolean.valueOf(atividadeImplementacao.getAttributeValue("selecionada")).booleanValue()){
						  projeto.incluindoExcluindoPratica(PraticaImplementacao.class,Constantes.INCLUSAO);
							this.getPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaImplementacao(), "praticaImplementacao", null, null);
					  }
					 //<atividadeEscritaDosTestesAntesDaImplementacao selecionada=""/>
					  Element atividadeEscritaDosTestesAntesDaImplementacao = etapaDesenvolvierIncrementoDoSistema.getChild("praticaEscritaDosTestesAntesDaImplementacao");
					  if (Boolean.valueOf(atividadeEscritaDosTestesAntesDaImplementacao.getAttributeValue("selecionada")).booleanValue()){
						  projeto.incluindoExcluindoPratica(PraticaEscritaDosTestesAntesDaImplementacao.class,Constantes.INCLUSAO);
							this.getPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaEscritaDosTestesAntesDaImplementacao(), "praticaEscritaDosTestesAntesDaImplementacao", null, null);
					  }

					   //<atividadeDesenvolvimentoColetivo selecionada=""/>
					  Element atividadeDesenvolvimentoColetivo = etapaDesenvolvierIncrementoDoSistema.getChild("praticaDesenvolvimentoColetivo");
					  if (Boolean.valueOf(atividadeDesenvolvimentoColetivo.getAttributeValue("selecionada")).booleanValue()){
						  projeto.incluindoExcluindoPratica(PraticaDesenvolvimentoColetivo.class,Constantes.INCLUSAO);
							this.getPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDesenvolvimentoColetivo(), "praticaDesenvolvimentoColetivo", null, null);
					  }

					  //<atividadeDesenvolvimentoEmDuplas selecionada=""/>
					  Element atividadeDesenvolvimentoEmDuplas = etapaDesenvolvierIncrementoDoSistema.getChild("praticaDesenvolvimentoEmDuplas");
					  if (Boolean.valueOf(atividadeDesenvolvimentoEmDuplas.getAttributeValue("selecionada")).booleanValue()){
						  projeto.incluindoExcluindoPratica(PraticaDesenvolvimentoEmDuplas.class,Constantes.INCLUSAO);
							this.getPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDesenvolvimentoEmDuplas(), "praticaDesenvolvimentoEmDuplas", null, stakeholderHash);
					  }

					  //<atividadeDesenvolvimentoLadoALado selecionada=""/>
					  Element atividadeDesenvolvimentoLadoALado = etapaDesenvolvierIncrementoDoSistema.getChild("praticaDesenvolvimentoLadoALado");
					  if (Boolean.valueOf(atividadeDesenvolvimentoLadoALado.getAttributeValue("selecionada")).booleanValue()){
						  projeto.incluindoExcluindoPratica(PraticaDesenvolvimentoLadoALado.class,Constantes.INCLUSAO);
							this.getPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDesenvolvimentoLadoALado(), "praticaDesenvolvimentoLadoALado", null, stakeholderHash);
					  }

					  //<atividadeRefactoring selecionada=""/>
					  Element atividadeRefactoring = etapaDesenvolvierIncrementoDoSistema.getChild("praticaRefactoring");
					  if (Boolean.valueOf(atividadeRefactoring.getAttributeValue("selecionada")).booleanValue()){
						  projeto.incluindoExcluindoPratica(PraticaRefactoring.class,Constantes.INCLUSAO);
							this.getPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaRefactoring(), "praticaRefactoring", null, null);
					  }

					   //<atividadeReunioesDiarias selecionada=""/>
					  Element atividadeReunioesDiarias = etapaDesenvolvierIncrementoDoSistema.getChild("praticaReunioesDiarias");
					  if (Boolean.valueOf(atividadeReunioesDiarias.getAttributeValue("selecionada")).booleanValue()){
						  projeto.incluindoExcluindoPratica(PraticaReunioesDiarias.class,Constantes.INCLUSAO);
							this.getPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaReunioesDiarias(), "praticaReunioesDiarias", null, null);
					  }

					  //<atividadeDesenvolvimentoSimultaneo selecionada=""/>
					  Element atividadeDesenvolvimentoSimultaneo = etapaDesenvolvierIncrementoDoSistema.getChild("praticaDesenvolvimentoSimultaneo");
					  if (Boolean.valueOf(atividadeDesenvolvimentoSimultaneo.getAttributeValue("selecionada")).booleanValue()){
						  projeto.incluindoExcluindoPratica(PraticaDesenvolvimentoSimultaneo.class,Constantes.INCLUSAO);
							this.getPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDesenvolvimentoSimultaneo(), "praticaDesenvolvimentoSimultaneo", null, null);
					  }

					  //<atividadeIntegracaoParalela selecionada=""/>
					  Element atividadeIntegracaoParalela = etapaDesenvolvierIncrementoDoSistema.getChild("praticaIntegracaoParalela");
					  if (Boolean.valueOf(atividadeIntegracaoParalela.getAttributeValue("selecionada")).booleanValue()){
						  projeto.incluindoExcluindoPratica(PraticaIntegracaoParalela.class,Constantes.INCLUSAO);
							this.getPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaIntegracaoParalela(), "praticaIntegracaoParalela", null, null);
					  }

					   //<atividadeDocumentacaoDoDesenvolvimento selecionada=""/>
					  Element atividadeDocumentacaoDoDesenvolvimento = etapaDesenvolvierIncrementoDoSistema.getChild("praticaDocumentacaoDoDesenvolvimento");
					  if (Boolean.valueOf(atividadeDocumentacaoDoDesenvolvimento.getAttributeValue("selecionada")).booleanValue()){
						  projeto.incluindoExcluindoPratica(PraticaDocumentacaoDoDesenvolvimento.class,Constantes.INCLUSAO);
							this.getPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDocumentacaoDoDesenvolvimento(), "praticaDocumentacaoDoDesenvolvimento", null, null);
					  }

					  //<atividadeControleDeVersoes selecionada=""/>
					  Element atividadeControleDeVersoes = etapaDesenvolvierIncrementoDoSistema.getChild("praticaControleDeVersoes");
					  if (Boolean.valueOf(atividadeControleDeVersoes.getAttributeValue("selecionada")).booleanValue()){
						  projeto.incluindoExcluindoPratica(PraticaControleDeVersoes.class,Constantes.INCLUSAO);
							this.getPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaControleDeVersoes(), "praticaControleDeVersoes", null, null);
					  }

				//</etapaDesenvolvierIncrementoDoSistema>

				   //<etapaValidarIncremento>
				  Element etapaValidarIncremento = cicloDeDesenvolvimento.getChild("atividadeValidarIncremento");
				  File fileEtapaValidarIncremento = new File(fileCicloDeDesenvolvimento.getCanonicalPath() + File.separator + "atividadeValidarIncremento");

					    //<atividadeExecucaoDosTestes selecionada=""/>
					  Element atividadeExecucaoDosTestes = etapaValidarIncremento.getChild("praticaExecucaoDosTestes");
					  if (Boolean.valueOf(atividadeExecucaoDosTestes.getAttributeValue("selecionada")).booleanValue()){
						  projeto.incluindoExcluindoPratica(PraticaExecucaoDosTestes.class,Constantes.INCLUSAO);
							this.getPratica(fileEtapaValidarIncremento, cd.getAtividadeValidarIncremento().getPraticaExecucaoDosTestes(), "praticaExecucaoDosTestes", null, null);
					  }

					   //<atividadeIntegracaoAntesDaValidacao selecionada=""/>
					  Element atividadeIntegracaoAntesDaValidacao = etapaValidarIncremento.getChild("praticaIntegracaoAntesDaValidacao");
					  if (Boolean.valueOf(atividadeIntegracaoAntesDaValidacao.getAttributeValue("selecionada")).booleanValue()){
						  projeto.incluindoExcluindoPratica(PraticaIntegracaoAntesDaValidacao.class,Constantes.INCLUSAO);
							this.getPratica(fileEtapaValidarIncremento, cd.getAtividadeValidarIncremento().getPraticaIntegracaoAntesDaValidacao(), "praticaIntegracaoAntesDaValidacao", null, null);
					  }

					 //<atividadeInspecaoDeCodigo selecionada=""/>
					  Element atividadeInspecaoDeCodigo = etapaValidarIncremento.getChild("praticaInspecaoDeCodigo");
					  if (Boolean.valueOf(atividadeInspecaoDeCodigo.getAttributeValue("selecionada")).booleanValue()){
						  projeto.incluindoExcluindoPratica(PraticaInspecaoDeCodigo.class,Constantes.INCLUSAO);
							this.getPratica(fileEtapaValidarIncremento, cd.getAtividadeValidarIncremento().getPraticaInspecaoDeCodigo(), "praticaInspecaoDeCodigo", null, null);
					  }
					//</etapaValidarIncremento>

				   //<etapaIntegracaoIncremento>
				  Element etapaIntegracaoIncremento = cicloDeDesenvolvimento.getChild("atividadeIntegracaoIncremento");
				  File fileEtapaIntegracaoIncremento = new File(fileCicloDeDesenvolvimento.getCanonicalPath() + File.separator + "atividadeIntegracaoIncremento");

					    //<atividadeIntegracaoDepoisDaValidacao selecionada=""/>
					  Element atividadeIntegracaoDepoisDaValidacao = etapaIntegracaoIncremento.getChild("praticaIntegracaoDepoisDaValidacao");
					  if (Boolean.valueOf(atividadeIntegracaoDepoisDaValidacao.getAttributeValue("selecionada")).booleanValue()){
						  projeto.incluindoExcluindoPratica(PraticaIntegracaoDepoisDaValidacao.class,Constantes.INCLUSAO);
						  this.getPratica(fileEtapaIntegracaoIncremento, cd.getAtividadeIntegracaoIncremento().getPraticaIntegracaoDepoisDaValidacao(), "praticaIntegracaoDepoisDaValidacao", null, null);
					  }
					 //</etapaIntegracaoIncremento>

				   //<etapaValidarSistema>
				  Element etapaValidarSistema = cicloDeDesenvolvimento.getChild("atividadeValidarSistema");
				  File fileEtapaValidarSistema = new File(fileCicloDeDesenvolvimento.getCanonicalPath() + File.separator + "atividadeValidarSistema");

					    //<atividadeReuniaoDeRevisao selecionada=""/>
					  Element atividadeReuniaoDeRevisao = etapaValidarSistema.getChild("praticaReuniaoDeRevisao");
					  if (Boolean.valueOf(atividadeReuniaoDeRevisao.getAttributeValue("selecionada")).booleanValue()){
						  projeto.incluindoExcluindoPratica(PraticaReuniaoDeRevisao.class,Constantes.INCLUSAO);
						  this.getPratica(fileEtapaValidarSistema, cd.getAtividadeValidarSistema().getPraticaReuniaoDeRevisao(), "praticaReuniaoDeRevisao", null, null);
					  }
					  //<atividadeColocarSistemaEmOperacao selecionada=""/>
					  Element atividadeColocarSistemaEmOperacao = etapaValidarSistema.getChild("praticaColocarSistemaEmOperacao");
					  if (Boolean.valueOf(atividadeColocarSistemaEmOperacao.getAttributeValue("selecionada")).booleanValue()){
						  projeto.incluindoExcluindoPratica(PraticaColocarSistemaEmOperacao.class,Constantes.INCLUSAO);
						  this.getPratica(fileEtapaValidarSistema, cd.getAtividadeValidarSistema().getPraticaColocarSistemaEmOperacao(), "praticaColocarSistemaEmOperacao", null, null);
					  }
				 //</etapaValidarSistema>

				  //</cicloDeDesenvolvimento>




			  }else{
				  cd = cd.copiaCicloDeDesenvolvimento();

				  //<cicloDeDesenvolvimento numero="">
				  Element cicloDeDesenvolvimento = (Element) it.next();
				  cd.setNumero(Integer.valueOf(cicloDeDesenvolvimento.getAttributeValue("numero")).intValue());
				  File fileCicloDeDesenvolvimento = new File(this.fileProjeto.getCanonicalPath()+ File.separator + "iteracao" + cd.getNumero());
				  this.getIteracao(fileCicloDeDesenvolvimento, cd, requisitosHash);

				   //<etapaDesenvolvierIncrementoDoSistema>
				  Element etapaDesenvolvierIncrementoDoSistema = cicloDeDesenvolvimento.getChild("atividadeDesenvolvierIncrementoDoSistema");
				  File fileEtapaDesenvolvierIncrementoDoSistema = new File(fileCicloDeDesenvolvimento.getCanonicalPath() + File.separator + "atividadeDesenvolverIncrementoDoSistema");

				  	//<atividadeImplementacao selecionada=""/>
					  Element atividadeImplementacao = etapaDesenvolvierIncrementoDoSistema.getChild("praticaImplementacao");
					  if (Boolean.valueOf(atividadeImplementacao.getAttributeValue("selecionada")).booleanValue()){
						  this.getPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaImplementacao(), "praticaImplementacao", null, null);
					  }
					 //<atividadeEscritaDosTestesAntesDaImplementacao selecionada=""/>
					  Element atividadeEscritaDosTestesAntesDaImplementacao = etapaDesenvolvierIncrementoDoSistema.getChild("praticaEscritaDosTestesAntesDaImplementacao");
					  if (Boolean.valueOf(atividadeEscritaDosTestesAntesDaImplementacao.getAttributeValue("selecionada")).booleanValue()){
						  this.getPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaEscritaDosTestesAntesDaImplementacao(), "praticaEscritaDosTestesAntesDaImplementacao", null, null);
					  }

					   //<atividadeDesenvolvimentoColetivo selecionada=""/>
					  Element atividadeDesenvolvimentoColetivo = etapaDesenvolvierIncrementoDoSistema.getChild("praticaDesenvolvimentoColetivo");
					  if (Boolean.valueOf(atividadeDesenvolvimentoColetivo.getAttributeValue("selecionada")).booleanValue()){
						  this.getPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDesenvolvimentoColetivo(), "praticaDesenvolvimentoColetivo", null, null);
					  }

					  //<atividadeDesenvolvimentoEmDuplas selecionada=""/>
					  Element atividadeDesenvolvimentoEmDuplas = etapaDesenvolvierIncrementoDoSistema.getChild("praticaDesenvolvimentoEmDuplas");
					  if (Boolean.valueOf(atividadeDesenvolvimentoEmDuplas.getAttributeValue("selecionada")).booleanValue()){
						  this.getPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDesenvolvimentoEmDuplas(), "praticaDesenvolvimentoEmDuplas", null, stakeholderHash);
					  }

					  //<atividadeDesenvolvimentoLadoALado selecionada=""/>
					  Element atividadeDesenvolvimentoLadoALado = etapaDesenvolvierIncrementoDoSistema.getChild("praticaDesenvolvimentoLadoALado");
					  if (Boolean.valueOf(atividadeDesenvolvimentoLadoALado.getAttributeValue("selecionada")).booleanValue()){
						  this.getPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDesenvolvimentoLadoALado(), "praticaDesenvolvimentoLadoALado", null, stakeholderHash);
					  }

					  //<atividadeRefactoring selecionada=""/>
					  Element atividadeRefactoring = etapaDesenvolvierIncrementoDoSistema.getChild("praticaRefactoring");
					  if (Boolean.valueOf(atividadeRefactoring.getAttributeValue("selecionada")).booleanValue()){
						  this.getPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaRefactoring(), "praticaRefactoring", null, null);
					  }

					   //<atividadeReunioesDiarias selecionada=""/>
					  Element atividadeReunioesDiarias = etapaDesenvolvierIncrementoDoSistema.getChild("praticaReunioesDiarias");
					  if (Boolean.valueOf(atividadeReunioesDiarias.getAttributeValue("selecionada")).booleanValue()){
						  this.getPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaReunioesDiarias(), "praticaReunioesDiarias", null, null);
					  }

					  //<atividadeDesenvolvimentoSimultaneo selecionada=""/>
					  Element atividadeDesenvolvimentoSimultaneo = etapaDesenvolvierIncrementoDoSistema.getChild("praticaDesenvolvimentoSimultaneo");
					  if (Boolean.valueOf(atividadeDesenvolvimentoSimultaneo.getAttributeValue("selecionada")).booleanValue()){
						  this.getPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDesenvolvimentoSimultaneo(), "praticaDesenvolvimentoSimultaneo", null, null);
					  }

					  //<atividadeIntegracaoParalela selecionada=""/>
					  Element atividadeIntegracaoParalela = etapaDesenvolvierIncrementoDoSistema.getChild("praticaIntegracaoParalela");
					  if (Boolean.valueOf(atividadeIntegracaoParalela.getAttributeValue("selecionada")).booleanValue()){
						  this.getPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaIntegracaoParalela(), "praticaIntegracaoParalela", null, null);
					  }

					   //<atividadeDocumentacaoDoDesenvolvimento selecionada=""/>
					  Element atividadeDocumentacaoDoDesenvolvimento = etapaDesenvolvierIncrementoDoSistema.getChild("praticaDocumentacaoDoDesenvolvimento");
					  if (Boolean.valueOf(atividadeDocumentacaoDoDesenvolvimento.getAttributeValue("selecionada")).booleanValue()){
						  this.getPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDocumentacaoDoDesenvolvimento(), "praticaDocumentacaoDoDesenvolvimento", null, null);
					  }

					  //<atividadeControleDeVersoes selecionada=""/>
					  Element atividadeControleDeVersoes = etapaDesenvolvierIncrementoDoSistema.getChild("praticaControleDeVersoes");
					  if (Boolean.valueOf(atividadeControleDeVersoes.getAttributeValue("selecionada")).booleanValue()){
						  this.getPratica(fileEtapaDesenvolvierIncrementoDoSistema, cd.getAtividadeDesenvolverIncrementoDoSistema().getPraticaControleDeVersoes(), "praticaControleDeVersoes", null, null);
					  }

				//</etapaDesenvolvierIncrementoDoSistema>

				   //<etapaValidarIncremento>
				  Element etapaValidarIncremento = cicloDeDesenvolvimento.getChild("atividadeValidarIncremento");
				  File fileEtapaValidarIncremento = new File(fileCicloDeDesenvolvimento.getCanonicalPath() + File.separator + "atividadeValidarIncremento");

					    //<atividadeExecucaoDosTestes selecionada=""/>
					  Element atividadeExecucaoDosTestes = etapaValidarIncremento.getChild("praticaExecucaoDosTestes");
					  if (Boolean.valueOf(atividadeExecucaoDosTestes.getAttributeValue("selecionada")).booleanValue()){
						  this.getPratica(fileEtapaValidarIncremento, cd.getAtividadeValidarIncremento().getPraticaExecucaoDosTestes(), "praticaExecucaoDosTestes", null, null);
					  }

					   //<atividadeIntegracaoAntesDaValidacao selecionada=""/>
					  Element atividadeIntegracaoAntesDaValidacao = etapaValidarIncremento.getChild("praticaIntegracaoAntesDaValidacao");
					  if (Boolean.valueOf(atividadeIntegracaoAntesDaValidacao.getAttributeValue("selecionada")).booleanValue()){
						  this.getPratica(fileEtapaValidarIncremento, cd.getAtividadeValidarIncremento().getPraticaIntegracaoAntesDaValidacao(), "praticaIntegracaoAntesDaValidacao", null, null);
					  }

					 //<atividadeInspecaoDeCodigo selecionada=""/>
					  Element atividadeInspecaoDeCodigo = etapaValidarIncremento.getChild("praticaInspecaoDeCodigo");
					  if (Boolean.valueOf(atividadeInspecaoDeCodigo.getAttributeValue("selecionada")).booleanValue()){
						 this.getPratica(fileEtapaValidarIncremento, cd.getAtividadeValidarIncremento().getPraticaInspecaoDeCodigo(), "praticaInspecaoDeCodigo", null, null);
					  }
					//</etapaValidarIncremento>

				   //<etapaIntegracaoIncremento>
				  Element etapaIntegracaoIncremento = cicloDeDesenvolvimento.getChild("atividadeIntegracaoIncremento");
				  File fileEtapaIntegracaoIncremento = new File(fileCicloDeDesenvolvimento.getCanonicalPath() + File.separator + "atividadeIntegracaoIncremento");

					    //<atividadeIntegracaoDepoisDaValidacao selecionada=""/>
					  Element atividadeIntegracaoDepoisDaValidacao = etapaIntegracaoIncremento.getChild("praticaIntegracaoDepoisDaValidacao");
					  if (Boolean.valueOf(atividadeIntegracaoDepoisDaValidacao.getAttributeValue("selecionada")).booleanValue()){
						 this.getPratica(fileEtapaIntegracaoIncremento, cd.getAtividadeIntegracaoIncremento().getPraticaIntegracaoDepoisDaValidacao(), "praticaIntegracaoDepoisDaValidacao", null, null);
					  }
					 //</etapaIntegracaoIncremento>

				   //<etapaValidarSistema>
				  Element etapaValidarSistema = cicloDeDesenvolvimento.getChild("atividadeValidarSistema");
				  File fileEtapaValidarSistema = new File(fileCicloDeDesenvolvimento.getCanonicalPath() + File.separator + "atividadeValidarSistema");

					    //<atividadeReuniaoDeRevisao selecionada=""/>
					  Element atividadeReuniaoDeRevisao = etapaValidarSistema.getChild("praticaReuniaoDeRevisao");
					  if (Boolean.valueOf(atividadeReuniaoDeRevisao.getAttributeValue("selecionada")).booleanValue()){
						 this.getPratica(fileEtapaValidarSistema, cd.getAtividadeValidarSistema().getPraticaReuniaoDeRevisao(), "praticaReuniaoDeRevisao", null, null);
					  }
					  //<atividadeColocarSistemaEmOperacao selecionada=""/>
					  Element atividadeColocarSistemaEmOperacao = etapaValidarSistema.getChild("praticaColocarSistemaEmOperacao");
					  if (Boolean.valueOf(atividadeColocarSistemaEmOperacao.getAttributeValue("selecionada")).booleanValue()){
						 this.getPratica(fileEtapaValidarSistema, cd.getAtividadeValidarSistema().getPraticaColocarSistemaEmOperacao(), "praticaColocarSistemaEmOperacao", null, null);
					  }
				 //</etapaValidarSistema>

				  //</cicloDeDesenvolvimento>
					  projeto.addIteracao(cd);
			  }


		  }
		 //</ciclosDeDesenvolvimento>

		 //<etapaEntregaFinal>
		  Element etapaEntregaFinal = rootProjeto.getChild("atividadeEntregaFinal");
		  File fileEtapaEntregaFinal = new File (this.fileProjeto.getCanonicalPath()+ File.separator + "atividadeEntregaFinal");

			  //<atividadeEntregaDoSistema selecionada=""/>
			  Element atividadeEntregaDoSistema  = etapaEntregaFinal.getChild("praticaEntregaDoSistema");
			  if (Boolean.valueOf(atividadeEntregaDoSistema.getAttributeValue("selecionada")).booleanValue()){
					projeto.incluindoExcluindoPratica(PraticaEntregaDoSistema.class,Constantes.INCLUSAO);
					this.getPratica(fileEtapaEntregaFinal,projeto.getAtividadeEntregaFinal().getPraticaEntregaDoSistema(), "praticaEntregaDoSistema", null, null);
				}

			  //<atividadeBreveDocumentacao selecionada=""/>
			  Element atividadeBreveDocumentacao  = etapaEntregaFinal.getChild("praticaBreveDocumentacao");
			  if (Boolean.valueOf(atividadeBreveDocumentacao.getAttributeValue("selecionada")).booleanValue()){
					projeto.incluindoExcluindoPratica(PraticaBreveDocumentacao.class,Constantes.INCLUSAO);
					this.getPratica(fileEtapaEntregaFinal,projeto.getAtividadeEntregaFinal().getPraticaBreveDocumentacao(), "praticaBreveDocumentacao", null, null);
				}

			  //<atividadeRefinamentoDaDocumentacao selecionada=""/>
			  Element atividadeRefinamentoDaDocumentacao  = etapaEntregaFinal.getChild("praticaRefinamentoDaDocumentacao");
			  if (Boolean.valueOf(atividadeRefinamentoDaDocumentacao.getAttributeValue("selecionada")).booleanValue()){
					projeto.incluindoExcluindoPratica(PraticaRefinamentoDaDocumentacao.class,Constantes.INCLUSAO);
					this.getPratica(fileEtapaEntregaFinal,projeto.getAtividadeEntregaFinal().getPraticaRefinamentoDaDocumentacao(), "praticaRefinamentoDaDocumentacao", null, null);
				}

			 //<atividadeElaboracaoDoManual selecionada=""/>
			  Element atividadeElaboracaoDoManual  = etapaEntregaFinal.getChild("praticaElaboracaoDoManual");
			  if (Boolean.valueOf(atividadeElaboracaoDoManual.getAttributeValue("selecionada")).booleanValue()){
					projeto.incluindoExcluindoPratica(PraticaElaboracaoDoManual.class,Constantes.INCLUSAO);
					this.getPratica(fileEtapaEntregaFinal,projeto.getAtividadeEntregaFinal().getPraticaElaboracaoDoManual(), "praticaElaboracaoDoManual", null, null);
				}

		//</etapaEntregaFinal>

		//</projeto>

		return projeto;
	}


	private void getIteracao(File fileCaminho, Iteracao  iteracao, HashMap requisitosHash) throws IOException, JDOMException{
		SAXBuilder parser = new SAXBuilder();
	   	Document bDoc = parser.build(new File(fileCaminho.getCanonicalPath() + File.separator + "iteracao.fcama"));

		//<cicloDeDesenvolvimento numero="">
		Element rootCicloDeDesenvolvimento = bDoc.getRootElement();
		iteracao.setNumero(Integer.valueOf(rootCicloDeDesenvolvimento.getAttribute("numero").getValue()).intValue());
			//<dtInicioPrevista></dtInicioPrevista>
			Element dtInicioPrevista = rootCicloDeDesenvolvimento.getChild("dtInicioPrevista");
			iteracao.setDtInicioPrevista(dtInicioPrevista.getValue().equals("")? null : new Date(Long.valueOf(dtInicioPrevista.getValue()).longValue()));
			//<dtFimPrevista></dtFimPrevista>
			Element dtFimPrevista = rootCicloDeDesenvolvimento.getChild("dtFimPrevista");
			iteracao.setDtFimPrevista(dtFimPrevista.getValue().equals("")? null : new Date(Long.valueOf(dtFimPrevista.getValue()).longValue()));

			//<dtInicioEfetiva></dtInicioEfetiva>
			Element dtInicioEfetiva = rootCicloDeDesenvolvimento.getChild("dtInicioEfetiva");
			iteracao.setDtInicioEfetiva(dtInicioEfetiva.getValue().equals("")? null : new Date(Long.valueOf(dtInicioEfetiva.getValue()).longValue()));

			//<dtFimEfetiva></dtFimEfetiva>
			Element dtFimEfetiva = rootCicloDeDesenvolvimento.getChild("dtFimEfetiva");
			iteracao.setDtFimEfetiva(dtFimEfetiva.getValue().equals("")? null : new Date(Long.valueOf(dtFimEfetiva.getValue()).longValue()));

			//<requisitos>
			Element requisitos = rootCicloDeDesenvolvimento.getChild("requisitos");
			List requisitosList = requisitos.getChildren("requisito");
			Iterator it = requisitosList.iterator();
			Requisito rq = null;
			while (it.hasNext()){
				//<requisito tipo="">
				Element requisito = (Element) it.next();
					//<nome></nome>
					Element nome = requisito.getChild("nome");
					rq = (Requisito) requisitosHash.get(nome.getValue());
					if (rq != null){
						iteracao.addRequisito(rq);
					}
					//</requisito>
			}
			//</requisitos>

		//</cicloDeDesenvolvimento>

	}
	private void getPratica(File fileAtividade, Pratica pratica, String nomeAtividade, HashMap hashMap, HashMap stakeholderHash) throws IOException, JDOMException{
		if(pratica.isSelecionada()){
			SAXBuilder parser = new SAXBuilder();
		   	Document bDoc = parser.build(new File(fileAtividade.getCanonicalPath() + File.separator + nomeAtividade + ".fcama"));

			//<atividade classAtividade="">
		   	Element rootAtividade = bDoc.getRootElement();

			 //<observacao></observacao>
			Element observacao = rootAtividade.getChild("observacao");
			pratica.setObservacao(observacao.getValue().equals("")? null : observacao.getValue());

			//<anexos>
			Element anexos = rootAtividade.getChild("anexos");
			List anexosList = anexos.getChildren("anexo");
			Iterator it = anexosList.iterator();
			while(it.hasNext()){
				Anexo ax = new Anexo();
			  //<anexo>
				Element anexo = (Element) it.next();
				
						//<caminho></caminho>
					Element caminho = anexo.getChild("caminho");
					ax.setCaminho(caminho.getValue().equals("")? null :caminho.getValue() );
				   //<descricao></descricao>
					Element descricao = anexo.getChild("descricao");
					ax.setDescricao(descricao.getValue().equals("") ? null : descricao.getValue());
				   //<nome></nome>
					Element nome = anexo.getChild("nome");
					ax.setNome(nome.getValue().equals("") ? null : nome.getValue());

				   //<dtCriacao></dtCriacao>
					Element dtCriacao = anexo.getChild("dtCriacao");
					ax.setDtCriacao(dtCriacao.getValue().equals("")? null : new Date(new Long(dtCriacao.getValue()).longValue()));
				   //<dtAlteracao></dtAlteracao>
					Element dtAlteracao = anexo.getChild("dtAlteracao");
					ax.setDtAlteracao(dtAlteracao.getValue().equals("")? null : new Date(new Long(dtAlteracao.getValue()).longValue()));
			   //</anexo>
				pratica.addAnexo(ax);
			}
			 //</anexos>

			//<!-- caso seja AtividadeDesenvolvimento em duplas ou desemvolvimentoLadoALado -->
			if(pratica.getClass() == PraticaDesenvolvimentoEmDuplas.class ||
					pratica.getClass() == PraticaDesenvolvimentoLadoALado.class ){


			 //<duplas>
				Element duplas = rootAtividade.getChild("duplas");
				List duplasList = duplas.getChildren("dupla");
				Iterator itd = duplasList.iterator();
				while(itd.hasNext()){
					Stakeholder sh1 = new Stakeholder();
					Stakeholder sh2 = new Stakeholder();
				  //<dupla>
					Element dupla = (Element)itd.next();
				   //<stakeholder1>
					Element stakeholder1 = dupla.getChild("stakeholder1");
						//<nome></nome>
						Element nome1 = stakeholder1.getChild("nome");
						sh1.setNome(nome1.getValue().equals("")? null : nome1.getValue());
						//<funcao></funcao>
						Element funcao1 = stakeholder1.getChild("funcao");
						sh1.setFuncao(funcao1.getValue().equals("")? null : funcao1.getValue());
						//</stakeholder1>
						sh1 = (Stakeholder)stakeholderHash.get(sh1.getNome() + " " + sh1.getFuncao());
				   //<stakeholder2>
					Element stakeholder2 = dupla.getChild("stakeholder2");
						//<nome></nome>
						Element nome2 = stakeholder2.getChild("nome");
						sh2.setNome(nome2.getValue().equals("")? null : nome2.getValue());
						//<funcao></funcao
						Element funcao2 = stakeholder2.getChild("funcao");
						sh2.setFuncao(funcao2.getValue().equals("")? null : funcao2.getValue());
					//</stakeholder2>
						sh2 = (Stakeholder)stakeholderHash.get(sh2.getNome() + " " + sh2.getFuncao());
				  //</dupla>
					if (pratica.getClass() == PraticaDesenvolvimentoEmDuplas.class){
						((PraticaDesenvolvimentoEmDuplas)pratica).addDupla(new DuplaDesenvolvimento(sh1,sh2));
					}else{
						((PraticaDesenvolvimentoLadoALado)pratica).addDupla(new DuplaDesenvolvimento(sh1,sh2));
					}
				}
			 //</duplas>
		}



			//<!-- caso seja AtividadeAtividadeListaDeRequisitos ou AtividadeUserStories ou PraticaDocumentacaoDetallhada -->
			if (pratica.getClass() == PraticaListaDeRequisitos.class ||
					pratica.getClass() == PraticaUserStories.class ||
					pratica.getClass() == PraticaDocumentacaoDetalhada.class){

			 //<requisitos>
				Element requisitos = rootAtividade.getChild("requisitos");
				List requisitosList = requisitos.getChildren("requisito");
				Iterator itr = requisitosList.iterator();
				if (pratica.getClass() == PraticaListaDeRequisitos.class){
					while(itr.hasNext()){
						Requisito rq = new Requisito();
					  //<requisito>
						Element requisito = (Element) itr.next();
					    //<prioridade></prioridade>
						Element prioridade = requisito.getChild("prioridade");
						rq.setPrioridade(prioridade.getValue().equals("")? null : prioridade.getValue());
					    //<nome></nome>
						Element nome = requisito.getChild("nome");
						rq.setNome(nome.getValue().equals("")? null : nome.getValue());

						//<ordem></ordem>
						Element ordem = requisito.getChild("ordem");
						if(!ordem.getValue().equals("")){
							rq.setOrdem(Integer.valueOf(ordem.getValue()).intValue());
						}

						//<descricao></descricao>
						Element descricao = requisito.getChild("descricao");
						rq.setDescricao(descricao.getValue().equals("")? null : descricao.getValue());

						//<tempoEstimado></tempoEstimado>
						Element tempoEstimado = requisito.getChild("tempoEstimado");
						if(!tempoEstimado.getValue().equals("")){
							rq.setTempoEstimado(Float.valueOf(tempoEstimado.getValue()).floatValue());
						}

						//<dtInicio></dtInicio>
						Element dtInicio = requisito.getChild("dtInicio");
						rq.setDtInicio(dtInicio.getValue().equals("")? null : new Date(Long.valueOf(dtInicio.getValue()).longValue()));

						//<dtFim></dtFim>
						Element dtFim = requisito.getChild("dtFim");
						rq.setDtFim(dtFim.getValue().equals("")? null : new Date(Long.valueOf(dtFim.getValue()).longValue()));

						//<dtInicioPrevisto></dtInicioPrevisto>
						Element dtInicioPrevisto = requisito.getChild("dtInicioPrevisto");
						rq.setDtInicioPrevisto(dtInicioPrevisto.getValue().equals("")? null : new Date(Long.valueOf(dtInicioPrevisto.getValue()).longValue()));
						
						//<dtInicioPrevisto></dtInicioPrevisto>
						Element dtFimPrevisto2 = requisito.getChild("dtFimPrevisto");
						rq.setDtFimPrevisto(dtFimPrevisto2.getValue().equals("")? null : new Date(Long.valueOf(dtFimPrevisto2.getValue()).longValue()));
						
						//<responsaveis>
						Element responsaveis = requisito.getChild("responsaveis");
						List responsaveisList = responsaveis.getChildren("responsavel");
						Iterator itres = responsaveisList.iterator();
						while(itres.hasNext()){
							Stakeholder stakeholder = new Stakeholder();
					     //<responsavel>
							Element responsavel = (Element) itres.next();
						  //<nome></nome>
							Element nomeR = responsavel.getChild("nome");
							stakeholder.setNome(nomeR.getValue().equals("")? null : nomeR.getValue());
						  //<funcao></funcao>
							Element funcaoR = responsavel.getChild("funcao");
							stakeholder.setFuncao(funcaoR.getValue().equals("")? null : funcaoR.getValue());
					     //</responsavel>
							stakeholder = (Stakeholder)stakeholderHash.get(stakeholder.getNome() + " " + stakeholder.getFuncao());
							rq.addResponsavel(stakeholder);
						}
					    //</responsaveis>
					    //<estado></estado>
						Element estado = requisito.getChild("estado");
						rq.setEstado(estado.getValue().equals("")? null : estado.getValue());

						//<nuCincloDeDesenvolvimento></nuCincloDeDesenvolvimento>
						Element nuCincloDeDesenvolvimento = requisito.getChild("nuIteracao");
						rq.setNuCincloDeDesenvolvimento(nuCincloDeDesenvolvimento.getValue().equals("")? 0 : Integer.valueOf(nuCincloDeDesenvolvimento.getValue()).intValue());

					  //</requisito>
						((PraticaListaDeRequisitos)pratica).addRequisito(rq);
						//para usar na recuperao dos ciclos de desenvolvimento
						hashMap.put(rq.getNome(), rq);
					}
			}else if(pratica.getClass() == PraticaUserStories.class){
				while(itr.hasNext()){
					UserStory rq = new UserStory();
				  //<requisito>
					Element requisito = (Element) itr.next();
				    //<prioridade></prioridade>
					Element prioridade = requisito.getChild("prioridade");
					rq.setPrioridade(prioridade.getValue().equals("")? null : prioridade.getValue());
				    //<nome></nome>
					Element nome = requisito.getChild("nome");
					rq.setNome(nome.getValue().equals("")? null : nome.getValue());

					//<ordem></ordem>
					Element ordem = requisito.getChild("ordem");
					if(!ordem.getValue().equals("")){
						rq.setOrdem(Integer.valueOf(ordem.getValue()).intValue());
					}

					//<descricao></descricao>
					Element descricao = requisito.getChild("descricao");
					rq.setDescricao(descricao.getValue().equals("")? null : descricao.getValue());

					//<tempoEstimado></tempoEstimado>
					Element tempoEstimado = requisito.getChild("tempoEstimado");
					if(!tempoEstimado.getValue().equals("")){
						rq.setTempoEstimado(Float.valueOf(tempoEstimado.getValue()).floatValue());
					}

					//<dtInicio></dtInicio>
					Element dtInicio = requisito.getChild("dtInicio");
					rq.setDtInicio(dtInicio.getValue().equals("")? null : new Date(Long.valueOf(dtInicio.getValue()).longValue()));

					//<dtFim></dtFim>
					Element dtFim = requisito.getChild("dtFim");
					rq.setDtFim(dtFim.getValue().equals("")? null : new Date(Long.valueOf(dtFim.getValue()).longValue()));

					//<dtInicioPrevisto></dtInicioPrevisto>
					Element dtInicioPrevisto = requisito.getChild("dtInicioPrevisto");
					rq.setDtInicioPrevisto(dtInicioPrevisto.getValue().equals("")? null : new Date(Long.valueOf(dtInicioPrevisto.getValue()).longValue()));
					
					//<dtInicioPrevisto></dtInicioPrevisto>
					Element dtFimPrevisto2 = requisito.getChild("dtFimPrevisto");
					rq.setDtFimPrevisto(dtFimPrevisto2.getValue().equals("")? null : new Date(Long.valueOf(dtFimPrevisto2.getValue()).longValue()));
					
					
					//<responsaveis>
					Element responsaveis = requisito.getChild("responsaveis");
					List responsaveisList = responsaveis.getChildren("responsavel");
					Iterator itres = responsaveisList.iterator();
					while(itres.hasNext()){
						Stakeholder stakeholder = new Stakeholder();
				     //<responsavel>
						Element responsavel = (Element) itres.next();
					  //<nome></nome>
						Element nomeR = responsavel.getChild("nome");
						stakeholder.setNome(nomeR.getValue().equals("")? null : nomeR.getValue());
					  //<funcao></funcao>
						Element funcaoR = responsavel.getChild("funcao");
						stakeholder.setFuncao(funcaoR.getValue().equals("")? null : funcaoR.getValue());
				     //</responsavel>
						stakeholder = (Stakeholder)stakeholderHash.get(stakeholder.getNome() + " " + stakeholder.getFuncao());
						rq.addResponsavel(stakeholder);
					}
				    //</responsaveis>
				    //<estado></estado>
					Element estado = requisito.getChild("estado");
					rq.setEstado(estado.getValue().equals("")? null : estado.getValue());

					//<nuCincloDeDesenvolvimento></nuCincloDeDesenvolvimento>
					Element nuCincloDeDesenvolvimento = requisito.getChild("nuIteracao");
					rq.setNuCincloDeDesenvolvimento(nuCincloDeDesenvolvimento.getValue().equals("")? 0 : Integer.valueOf(nuCincloDeDesenvolvimento.getValue()).intValue());

					//<nota></nota>
					Element nota = requisito.getChild("nota");
					rq.setNota(nota.getValue().equals("")? null : nota.getValue());
					//<referencias>
					Element referencias = requisito.getChild("referencias");
					List referenciasList = referencias.getChildren("nome");
					Iterator itRe = referenciasList.iterator();
					while(itRe.hasNext()){
						UserStory rqR = new UserStory();
			      		//<nome></nome>
						Element nomeRef = (Element) itRe.next();
						rqR.setNome(nomeRef.getValue());
						rq.addReferencia(rqR);
					}
			    	//</referencias>
				  //</requisito>
					((PraticaUserStories)pratica).addUserStory(rq);
					//para usar na recuperao dos ciclos de desenvolvimento
					hashMap.put(rq.getNome(), rq);
				}
				
				
			}else{
				while(itr.hasNext()){
					RequisitoAnexo rq = new RequisitoAnexo();
				  //<requisito>
					Element requisito = (Element) itr.next();
				    //<prioridade></prioridade>
					Element prioridade = requisito.getChild("prioridade");
					rq.setPrioridade(prioridade.getValue().equals("")? null : prioridade.getValue());
				    //<nome></nome>
					Element nome = requisito.getChild("nome");
					rq.setNome(nome.getValue().equals("")? null : nome.getValue());

					//<ordem></ordem>
					Element ordem = requisito.getChild("ordem");
					if(!ordem.getValue().equals("")){
						rq.setOrdem(Integer.valueOf(ordem.getValue()).intValue());
					}

					//<descricao></descricao>
					Element descricao = requisito.getChild("descricao");
					rq.setDescricao(descricao.getValue().equals("")? null : descricao.getValue());

					//<tempoEstimado></tempoEstimado>
					Element tempoEstimado = requisito.getChild("tempoEstimado");
					if(!tempoEstimado.getValue().equals("")){
						rq.setTempoEstimado(Float.valueOf(tempoEstimado.getValue()).floatValue());
					}

					//<dtInicio></dtInicio>
					Element dtInicio = requisito.getChild("dtInicio");
					rq.setDtInicio(dtInicio.getValue().equals("")? null : new Date(Long.valueOf(dtInicio.getValue()).longValue()));

					//<dtFim></dtFim>
					Element dtFim = requisito.getChild("dtFim");
					rq.setDtFim(dtFim.getValue().equals("")? null : new Date(Long.valueOf(dtFim.getValue()).longValue()));

					//<dtInicioPrevisto></dtInicioPrevisto>
					Element dtInicioPrevisto = requisito.getChild("dtInicioPrevisto");
					rq.setDtInicioPrevisto(dtInicioPrevisto.getValue().equals("")? null : new Date(Long.valueOf(dtInicioPrevisto.getValue()).longValue()));
					
					//<dtInicioPrevisto></dtInicioPrevisto>
					Element dtFimPrevisto2 = requisito.getChild("dtFimPrevisto");
					rq.setDtFimPrevisto(dtFimPrevisto2.getValue().equals("")? null : new Date(Long.valueOf(dtFimPrevisto2.getValue()).longValue()));
					
					//<responsaveis>
					Element responsaveis = requisito.getChild("responsaveis");
					List responsaveisList = responsaveis.getChildren("responsavel");
					Iterator itres = responsaveisList.iterator();
					while(itres.hasNext()){
						Stakeholder stakeholder = new Stakeholder();
				     //<responsavel>
						Element responsavel = (Element) itres.next();
					  //<nome></nome>
						Element nomeR = responsavel.getChild("nome");
						stakeholder.setNome(nomeR.getValue().equals("")? null : nomeR.getValue());
					  //<funcao></funcao>
						Element funcaoR = responsavel.getChild("funcao");
						stakeholder.setFuncao(funcaoR.getValue().equals("")? null : funcaoR.getValue());
				     //</responsavel>
						stakeholder = (Stakeholder)stakeholderHash.get(stakeholder.getNome() + " " + stakeholder.getFuncao());
						rq.addResponsavel(stakeholder);
					}
				    //</responsaveis>
				    //<estado></estado>
					Element estado = requisito.getChild("estado");
					rq.setEstado(estado.getValue().equals("")? null : estado.getValue());

					//<nuCincloDeDesenvolvimento></nuCincloDeDesenvolvimento>
					Element nuCincloDeDesenvolvimento = requisito.getChild("nuIteracao");
					rq.setNuCincloDeDesenvolvimento(nuCincloDeDesenvolvimento.getValue().equals("")? 0 : Integer.valueOf(nuCincloDeDesenvolvimento.getValue()).intValue());

					
					 //<anexos>
					Element anexosD = requisito.getChild("anexos");
					List anexosDList = anexosD.getChildren("anexo");
					Iterator itD = anexosDList.iterator();
					while(itD.hasNext()){
						Anexo ax = new Anexo();
					  //<anexo>
						Element anexo = (Element) itD.next();
						
								//<caminho></caminho>
							Element caminho = anexo.getChild("caminho");
							ax.setCaminho(caminho.getValue().equals("")? null :caminho.getValue() );
						   //<descricao></descricao>
							Element descricaoD = anexo.getChild("descricao");
							ax.setDescricao(descricaoD.getValue().equals("") ? null : descricaoD.getValue());
						   //<nome></nome>
							Element nomeD = anexo.getChild("nome");
							ax.setNome(nomeD.getValue().equals("") ? null : nomeD.getValue());

						   //<dtCriacao></dtCriacao>
							Element dtCriacao = anexo.getChild("dtCriacao");
							ax.setDtCriacao(dtCriacao.getValue().equals("")? null : new Date(new Long(dtCriacao.getValue()).longValue()));
						   //<dtAlteracao></dtAlteracao>
							Element dtAlteracao = anexo.getChild("dtAlteracao");
							ax.setDtAlteracao(dtAlteracao.getValue().equals("")? null : new Date(new Long(dtAlteracao.getValue()).longValue()));
					   //</anexo>
							rq.addAnexo(ax);
					}
					 //</anexos>
					
					
					
				  //</requisito>
					((PraticaDocumentacaoDetalhada)pratica).addRequisitosAnexos(rq);
					//para usar na recuperao dos ciclos de desenvolvimento
					hashMap.put(rq.getNome(), rq);
				}
				
			}
			 //</requisitos>
			}

			//</atividade>

		}
	}
	private void getStakeholder(File fileProjeto, Projeto projeto, HashMap requisitosHash) throws IOException, JDOMException{
		SAXBuilder parser = new SAXBuilder();
	   	Document bDoc = parser.build(new File(fileProjeto.getCanonicalPath() + File.separator + "stakeholder.fcama"));
		//<stakeholders>
		Element rootStakeholders = bDoc.getRootElement();
		List stakeholdersList = rootStakeholders.getChildren("stakeholder");
		Iterator it = stakeholdersList.iterator();
		while(it.hasNext()){
			Stakeholder sh = new Stakeholder();
			//<stakeholder>
			Element stakeholder = (Element)it.next();
				  //<nome></nome>
				Element nome = stakeholder.getChild("nome");
				sh.setNome(nome.getValue());
				  //<funcao></funcao>
				Element funcao = stakeholder.getChild("funcao");
				sh.setFuncao(funcao.getValue());
			//</stakeholder>
			//coloca no hahsh para ser recuperado pelas atividades
			requisitosHash.put(sh.getNome() + " " + sh.getFuncao(), sh);
			try {
				projeto.addStakeholder(sh);
			} catch (ExceptionStakeholderJaCadastrado e) {
			}
		}
		//</stakeholders>
	}

	public void deleteIteracao(Iteracao iteracao) throws IOException{
		File fileIteracao = new File(this.fileProjeto.getCanonicalPath()+ File.separator + "iteracao" + iteracao.getNumero());
		fileIteracao.delete(); 
	}
	
	public void addIteracao(Iteracao iteracao) throws IOException{
		  //<cicloDeDesenvolvimento numero="">
		  File fileCicloDeDesenvolvimento = new File(this.fileProjeto.getCanonicalPath()+ File.separator + "iteracao" + iteracao.getNumero());
		  fileCicloDeDesenvolvimento.mkdir();
		  this.salvarIteracao(fileCicloDeDesenvolvimento, iteracao);

		   //<etapaDesenvolverIncrementoDoSistema>
		  File fileEtapaDesenvolvierIncrementoDoSistema = new File(fileCicloDeDesenvolvimento.getCanonicalPath() + File.separator + "atividadeDesenvolverIncrementoDoSistema");
		  fileEtapaDesenvolvierIncrementoDoSistema.mkdir();
			    //<atividadeImplementacao selecionada=""/>
			  this.salvarPratica(fileEtapaDesenvolvierIncrementoDoSistema, iteracao.getAtividadeDesenvolverIncrementoDoSistema().getPraticaImplementacao(), "praticaImplementacao");
			    //<atividadeEscritaDosTestesAntesDaImplementacao selecionada=""/>
			  this.salvarPratica(fileEtapaDesenvolvierIncrementoDoSistema, iteracao.getAtividadeDesenvolverIncrementoDoSistema().getPraticaEscritaDosTestesAntesDaImplementacao(), "praticaEscritaDosTestesAntesDaImplementacao");
			    //<atividadeDesenvolvimentoColetivo selecionada=""/>
			  this.salvarPratica(fileEtapaDesenvolvierIncrementoDoSistema, iteracao.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDesenvolvimentoColetivo(), "praticaDesenvolvimentoColetivo");
			    //<atividadeDesenvolvimentoEmDuplas selecionada=""/>
			  this.salvarPratica(fileEtapaDesenvolvierIncrementoDoSistema, iteracao.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDesenvolvimentoEmDuplas(), "praticaDesenvolvimentoEmDuplas");
			    //<atividadeDesenvolvimentoLadoALado selecionada=""/>
			  this.salvarPratica(fileEtapaDesenvolvierIncrementoDoSistema, iteracao.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDesenvolvimentoLadoALado(), "praticaDesenvolvimentoLadoALado");
			    //<atividadeRefactoring selecionada=""/>
			  this.salvarPratica(fileEtapaDesenvolvierIncrementoDoSistema, iteracao.getAtividadeDesenvolverIncrementoDoSistema().getPraticaRefactoring(), "praticaRefactoring");
			    //<atividadeReunioesDiarias selecionada=""/>
			  this.salvarPratica(fileEtapaDesenvolvierIncrementoDoSistema, iteracao.getAtividadeDesenvolverIncrementoDoSistema().getPraticaReunioesDiarias(), "praticaReunioesDiarias");
			    //<atividadeDesenvolvimentoSimultaneo selecionada=""/>
			  this.salvarPratica(fileEtapaDesenvolvierIncrementoDoSistema, iteracao.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDesenvolvimentoSimultaneo(), "praticaDesenvolvimentoSimultaneo");
			    //<atividadeIntegracaoParalela selecionada=""/>
			  this.salvarPratica(fileEtapaDesenvolvierIncrementoDoSistema, iteracao.getAtividadeDesenvolverIncrementoDoSistema().getPraticaIntegracaoParalela(),"praticaIntegracaoParalela");
			    //<atividadeDocumentacaoDoDesenvolvimento selecionada=""/>
			  this.salvarPratica(fileEtapaDesenvolvierIncrementoDoSistema, iteracao.getAtividadeDesenvolverIncrementoDoSistema().getPraticaDocumentacaoDoDesenvolvimento(), "praticaDocumentacaoDoDesenvolvimento");
			    //<atividadeControleDeVersoes selecionada=""/>
			  this.salvarPratica(fileEtapaDesenvolvierIncrementoDoSistema, iteracao.getAtividadeDesenvolverIncrementoDoSistema().getPraticaControleDeVersoes(), "praticaControleDeVersoes");
		   //</etapaDesenvolvierIncrementoDoSistema>
		  
		   //<etapaValidarIncremento>
		  File fileEtapaValidarIncremento = new File(fileCicloDeDesenvolvimento.getCanonicalPath() + File.separator + "atividadeValidarIncremento");
		  fileEtapaValidarIncremento.mkdir();
			    //<atividadeExecucaoDosTestes selecionada=""/>
			  this.salvarPratica(fileEtapaValidarIncremento, iteracao.getAtividadeValidarIncremento().getPraticaExecucaoDosTestes(), "praticaExecucaoDosTestes");
			    //<atividadeIntegracaoAntesDaValidacao selecionada=""/>
			  this.salvarPratica(fileEtapaValidarIncremento, iteracao.getAtividadeValidarIncremento().getPraticaIntegracaoAntesDaValidacao(), "praticaIntegracaoAntesDaValidacao");
			    //<atividadeInspecaoDeCodigo selecionada=""/>
			  this.salvarPratica(fileEtapaValidarIncremento, iteracao.getAtividadeValidarIncremento().getPraticaInspecaoDeCodigo(),"praticaInspecaoDeCodigo");
		   //</etapaValidarIncremento>
		  
		   //<etapaIntegracaoIncremento>
		  File fileEtapaIntegracaoIncremento = new File(fileCicloDeDesenvolvimento.getCanonicalPath() + File.separator + "atividadeIntegracaoIncremento");
		  fileEtapaIntegracaoIncremento.mkdir();
			    //<atividadeIntegracaoDepoisDaValidacao selecionada=""/>
			  this.salvarPratica(fileEtapaIntegracaoIncremento, iteracao.getAtividadeIntegracaoIncremento().getPraticaIntegracaoDepoisDaValidacao(), "praticaIntegracaoDepoisDaValidacao");
		   //</etapaIntegracaoIncremento>
		  
		   //<etapaValidarSistema>
		  File fileEtapaValidarSistema = new File(fileCicloDeDesenvolvimento.getCanonicalPath() + File.separator + "atividadeValidarSistema");
		  fileEtapaValidarSistema.mkdir();
			    //<atividadeReuniaoDeRevisao selecionada=""/>
			  this.salvarPratica(fileEtapaValidarSistema, iteracao.getAtividadeValidarSistema().getPraticaReuniaoDeRevisao(), "praticaReuniaoDeRevisao");
			    //<atividadeColocarSistemaEmOperacao selecionada=""/>
			  this.salvarPratica(fileEtapaValidarSistema, iteracao.getAtividadeValidarSistema().getPraticaColocarSistemaEmOperacao(), "praticaColocarSistemaEmOperacao");
		   //</etapaValidarSistema>
		  
		  //</cicloDeDesenvolvimento>
	
	}
	
	public void visualizarAnexo(Anexo anexo) throws IOException{
	    Runtime.getRuntime().exec ("rundll32 SHELL32.DLL,ShellExec_RunDLL " 
	    		+ this.fileProjeto.getCanonicalPath() + File.separator +  anexo.getCaminho());
	}
	
	public void visualizarAnexoNaoSalvo(Anexo anexo) throws IOException{
	    Runtime.getRuntime().exec ("rundll32 SHELL32.DLL,ShellExec_RunDLL " 
	    		+  anexo.getCaminho());
	}
	
	public String copiarAnexo(File fileAnexoOrigem, Object[] obj) throws IOException{
	    String caminhoDestino = "";
	    //percorre o arrei para montar o caminho do destino
	    for (int i = 0; i < obj.length; i++){
	        if (obj[i].getClass().getSuperclass() == Atividade.class ||
	                obj[i].getClass().getSuperclass() == Iteracao.class){
	            String aux = obj[i].getClass().toString();
	            aux = aux.substring((aux.lastIndexOf(".")+ 1), aux.length());
	            caminhoDestino = caminhoDestino + File.separator + aux;
	            if (obj[i] instanceof Iteracao){
	               caminhoDestino = caminhoDestino + ((Iteracao)obj[i]).getNumero();
	            }
	        }
	    }
	    caminhoDestino = caminhoDestino + File.separator + fileAnexoOrigem.getName();
	    File fileAnexoDestino = new File(this.fileProjeto.getCanonicalPath() + caminhoDestino);
	    fileAnexoDestino.createNewFile();
	    FileInputStream fis = new FileInputStream(fileAnexoOrigem);
	    FileOutputStream fos = new FileOutputStream(fileAnexoDestino);
	    byte[] buf = new byte[256];
	    int i = 0;
	    while((i=fis.read(buf))!=-1)
	    {
	       fos.write(buf, 0, i);
	    }
	    fis.close();
	    fos.close();
	    
	    //retorna o caminho para ser setado no anexo
	    return caminhoDestino;
	}
	
	public String criarAnexo(File fileModelo,Object[] obj, Anexo anexo) throws IOException, ExceptionArquivoJaExiste{
		String caminho = "";
	    //percorre o arrei para montar o caminho do destino
	    for (int i = 0; i < obj.length; i++){
	        if (  obj[i].getClass().getSuperclass() == Atividade.class ||
	                obj[i].getClass() == Iteracao.class){
	            String aux = obj[i].getClass().toString();
	            aux = aux.substring((aux.lastIndexOf(".")+ 1), aux.length());
	            caminho = caminho + File.separator + aux;
	            if (obj[i] instanceof Iteracao){
	               caminho = caminho + ((Iteracao)obj[i]).getNumero();
	            }
	        }
	    }
	    caminho = caminho + File.separator + anexo.getNome();
	    File fileAnexo = new File(this.fileProjeto.getCanonicalPath() + caminho);
	    if (!fileAnexo.createNewFile()){
	    	throw new ExceptionArquivoJaExiste(anexo.getNome());
	    }
	    
	    FileInputStream fis = new FileInputStream(fileModelo);
	    FileOutputStream fos = new FileOutputStream(fileAnexo);
	    byte[] buf = new byte[256];
	    int i = 0;
	    while((i=fis.read(buf))!=-1)
	    {
	       fos.write(buf, 0, i);
	    }
	    fis.close();
	    fos.close();
	    
	    return caminho;
	}
	
	public boolean excluir(Anexo anexo) throws SecurityException, IOException {
	    File file = new File(this.fileProjeto.getCanonicalPath() + File.separator +anexo.getCaminho());
	    return file.delete();
	}

	
}
